@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,7 +15,7 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
-* This file is part of Skrooge and defines classes SKGObjectModel.
+* This file defines classes SKGObjectModel.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -54,164 +54,6 @@ SKGObjectModel::SKGObjectModel ( SKGDocumentBank* iDocument,
 {
         SKGTRACEIN ( 1, "SKGObjectModel::SKGObjectModel" );
 
-        //Build schemas
-        if ( getRealTable() =="operation" ) {
-                SKGModelTemplate def;
-                def.id="default";
-                def.name=i18nc("Noun, the default value of an item","Default");
-                def.icon="edit-undo";
-                def.schema="d_date;i_NBRECURRENT;t_bookmarked;t_ACCOUNT;i_number;t_mode;t_payee;t_comment;t_REALCOMMENT;t_CATEGORY;t_REALCATEGORY;t_status;"
-                           "f_REALCURRENTAMOUNT;f_REALCURRENTAMOUNT_EXPENSE|N;f_REALCURRENTAMOUNT_INCOME|N;"
-                           "f_CURRENTAMOUNT;f_CURRENTAMOUNT_EXPENSE|N;f_CURRENTAMOUNT_INCOME|N;"
-                           "f_QUANTITY|N;f_QUANTITY_EXPENSE|N;f_QUANTITY_INCOME|N;f_REALQUANTITY|N;f_REALQUANTITY_EXPENSE|N;f_REALQUANTITY_INCOME|N;"
-                           "t_imported|N;t_REFUND|N";
-                listSchema.push_back(def);
-
-                SKGModelTemplate minimum;
-                minimum.id="minimum";
-                minimum.name= i18nc("Noun, the minimum value of an item", "Minimum" );
-                minimum.icon="";
-                minimum.schema="d_date;i_NBRECURRENT|N;t_bookmarked|N;t_ACCOUNT;i_number|N;t_mode|N;t_payee|N;t_comment|N;t_REALCOMMENT|N;t_CATEGORY|N;t_REALCATEGORY|N;t_status;"
-                               "f_REALCURRENTAMOUNT;f_REALCURRENTAMOUNT_EXPENSE|N;f_REALCURRENTAMOUNT_INCOME|N;"
-                               "f_CURRENTAMOUNT;f_CURRENTAMOUNT_EXPENSE|N;f_CURRENTAMOUNT_INCOME|N;"
-                               "f_QUANTITY|N;f_QUANTITY_EXPENSE|N;f_QUANTITY_INCOME|N;f_REALQUANTITY|N;f_REALQUANTITY_EXPENSE|N;f_REALQUANTITY_INCOME|N;"
-                               "t_imported|N;t_REFUND|N";
-                listSchema.push_back ( minimum );
-
-                SKGModelTemplate doubleColumn;
-                doubleColumn.id="doublecolumn";
-                doubleColumn.name= i18n( "Amount in 2 columns" );
-                doubleColumn.icon="";
-                doubleColumn.schema="d_date;i_NBRECURRENT;t_bookmarked;t_ACCOUNT;i_number;t_mode;t_payee;t_comment;t_REALCOMMENT;t_CATEGORY;t_REALCATEGORY;t_status;"
-                                    "f_REALCURRENTAMOUNT|N;f_REALCURRENTAMOUNT_EXPENSE|Y;f_REALCURRENTAMOUNT_INCOME|Y;"
-                                    "f_CURRENTAMOUNT|N;f_CURRENTAMOUNT_EXPENSE|Y;f_CURRENTAMOUNT_INCOME|Y;"
-                                    "f_QUANTITY|N;f_QUANTITY_EXPENSE|N;f_QUANTITY_INCOME|N;f_REALQUANTITY|N;f_REALQUANTITY_EXPENSE|N;f_REALQUANTITY_INCOME|N;"
-                                    "t_imported|N;t_REFUND|N";
-                listSchema.push_back ( doubleColumn );
-
-                SKGModelTemplate amountEntered;
-                amountEntered.id="amountentered";
-                amountEntered.name= i18n( "Amount entered" );
-                amountEntered.icon="";
-                amountEntered.schema="d_date;i_NBRECURRENT;t_bookmarked;t_ACCOUNT;i_number;t_mode;t_payee;t_comment;t_REALCOMMENT;t_CATEGORY;t_REALCATEGORY;t_status;"
-                                     "f_REALCURRENTAMOUNT|N;f_REALCURRENTAMOUNT_EXPENSE|N;f_REALCURRENTAMOUNT_INCOME|N;"
-                                     "f_CURRENTAMOUNT|N;f_CURRENTAMOUNT_EXPENSE|N;f_CURRENTAMOUNT_INCOME|N;"
-                                     "f_QUANTITY|Y;f_QUANTITY_EXPENSE|N;f_QUANTITY_INCOME|N;f_REALQUANTITY|Y;f_REALQUANTITY_EXPENSE|N;f_REALQUANTITY_INCOME|N;"
-                                     "t_imported|N;t_REFUND|N";
-                listSchema.push_back ( amountEntered );
-
-                SKGModelTemplate doubleColumnEntered;
-                doubleColumnEntered.id="doublecolumnentered";
-                doubleColumnEntered.name= i18n( "Amount entered in 2 columns" );
-                doubleColumnEntered.icon="";
-                doubleColumnEntered.schema="d_date;i_NBRECURRENT;t_bookmarked;t_ACCOUNT;i_number;t_mode;t_payee;t_comment;t_REALCOMMENT;t_CATEGORY;t_REALCATEGORY;t_status;"
-                                           "f_REALCURRENTAMOUNT|N;f_REALCURRENTAMOUNT_EXPENSE|N;f_REALCURRENTAMOUNT_INCOME|N;"
-                                           "f_CURRENTAMOUNT|N;f_CURRENTAMOUNT_EXPENSE|N;f_CURRENTAMOUNT_INCOME|N;"
-                                           "f_QUANTITY|N;f_QUANTITY_EXPENSE|Y;f_QUANTITY_INCOME|Y;f_REALQUANTITY|N;f_REALQUANTITY_EXPENSE|Y;f_REALQUANTITY_INCOME|Y;"
-                                           "t_imported|N;t_REFUND|N";
-                listSchema.push_back ( doubleColumnEntered );
-        } else if ( getRealTable() =="recurrentoperation" ) {
-                SKGModelTemplate def;
-                def.id="default";
-                def.name= i18nc("Noun, the default value of an item", "Default" );
-                def.icon="edit-undo";
-                def.schema="d_date;t_PERIODNLS;i_nb_times;i_auto_write_days;i_warn_days;t_ACCOUNT;i_number;t_mode;t_payee;t_comment;t_CATEGORY;"
-                           "t_status;f_CURRENTAMOUNT";
-                listSchema.push_back ( def );
-
-                SKGModelTemplate minimum;
-                minimum.id="minimum";
-                minimum.name= i18nc("Noun, the minimum value of an item", "Minimum" );
-                minimum.icon="";
-                minimum.schema="d_date;t_PERIODNLS;i_nb_times;i_auto_write_days;i_warn_days;t_ACCOUNT;i_number|N;t_mode|N;t_payee;t_comment|N;t_CATEGORY|N;"
-                               "t_status;f_CURRENTAMOUNT";
-                listSchema.push_back ( minimum );
-        } else if ( getRealTable() =="account" ) {
-                SKGModelTemplate def;
-                def.id="default";
-                def.name= i18nc("Noun, the default value of an item", "Default" );
-                def.icon="edit-undo";
-                def.schema="t_BANK;t_close;t_name;t_type;t_BANK_NUMBER;t_agency_number;t_number;t_agency_address;t_comment;f_CURRENTAMOUNT;f_CHECKED;f_COMING_SOON;i_NBOPERATIONS";
-                listSchema.push_back ( def );
-
-                SKGModelTemplate minimum;
-                minimum.id="minimum";
-                minimum.name= i18nc("Noun, the minimum value of an item", "Minimum" );
-                minimum.icon="";
-                minimum.schema="t_BANK;t_close;t_name;t_type|N;t_BANK_NUMBER|N;t_agency_number|N;t_number|N;t_agency_address|N;t_comment|N;f_CURRENTAMOUNT|N;f_CHECKED|N;f_COMING_SOON|N;i_NBOPERATIONS|N";
-                listSchema.push_back ( minimum );
-
-                SKGModelTemplate intermediate;
-                intermediate.id="intermediate";
-                intermediate.name= i18nc("Noun, an intermediate value between two extremums", "Intermediate" );
-                intermediate.icon="";
-                intermediate.schema="t_BANK;t_close;t_name;t_type|N;t_BANK_NUMBER|N;t_agency_number|N;t_number|N;t_agency_address|N;t_comment|N;f_CURRENTAMOUNT;f_CHECKED;f_COMING_SOON;i_NBOPERATIONS|N";
-                listSchema.push_back ( intermediate );
-        } else if ( getRealTable() =="category" ) {
-                SKGModelTemplate def;
-                def.id="default";
-                def.name=i18nc("Noun, the default value of an item","Default");
-                def.icon="edit-undo";
-                def.schema="t_name;i_NBOPERATIONS;f_REALCURRENTAMOUNT;i_SUMNBOPERATIONS;f_SUMCURRENTAMOUNT";
-                listSchema.push_back(def);
-
-                SKGModelTemplate minimum;
-                minimum.id="minimum";
-                minimum.name= i18nc("Noun, the minimum value of an item", "Minimum" );
-                minimum.icon="";
-                minimum.schema="t_name;i_NBOPERATIONS|N;f_REALCURRENTAMOUNT|N;i_SUMNBOPERATIONS|N;f_SUMCURRENTAMOUNT|N";
-                listSchema.push_back ( minimum );
-
-                SKGModelTemplate op;
-                op.id="with_operations";
-                op.name= i18n( "With operations" );
-                op.icon="";
-                op.schema="t_name;i_NBOPERATIONS;f_REALCURRENTAMOUNT;i_SUMNBOPERATIONS|N;f_SUMCURRENTAMOUNT|N";
-                listSchema.push_back ( op );
-
-                SKGModelTemplate op2;
-                op2.id="with_cumulative_operations";
-                op2.name= i18n( "With cumulative operations" );
-                op2.icon="";
-                op2.schema="t_name;i_NBOPERATIONS|N;f_REALCURRENTAMOUNT|N;i_SUMNBOPERATIONS;f_SUMCURRENTAMOUNT";
-                listSchema.push_back ( op2 );
-        } else if ( getRealTable() =="unit" ) {
-                SKGModelTemplate def;
-                def.id="default";
-                def.name=i18nc("Noun, the default value of an item","Default");
-                def.icon="edit-undo";
-                def.schema="t_name;t_symbol;t_country;t_type;t_internet_code;f_CURRENTAMOUNT;t_UNIT";
-                listSchema.push_back(def);
-
-
-                SKGModelTemplate minimum;
-                minimum.id="minimum";
-                minimum.name= i18nc("Noun, the minimum value of an item", "Minimum" );
-                minimum.icon="";
-                minimum.schema="t_name;t_symbol;t_country|N;t_type;t_internet_code|N;f_CURRENTAMOUNT|N;t_UNIT|N";
-                listSchema.push_back ( minimum );
-        } else if ( getRealTable() =="unitvalue" ) {
-                SKGModelTemplate def;
-                def.id="default";
-                def.name=i18nc("Noun, the default value of an item","Default");
-                def.icon="edit-undo";
-                def.schema="d_date;f_quantity;t_UNIT|N";
-                listSchema.push_back(def);;
-        } else if ( getRealTable() =="refund" ) {
-                SKGModelTemplate def;
-                def.id="default";
-                def.name=i18nc("Noun, the default value of an item","Default");
-                def.icon="edit-undo";
-                def.schema="t_name;t_comment;t_close;f_CURRENTAMOUNT";
-                listSchema.push_back(def);;
-        } else if ( getRealTable() =="rule" ) {
-                SKGModelTemplate def;
-                def.id="default";
-                def.name=i18nc("Noun, the default value of an item","Default");
-                def.icon="edit-undo";
-                def.schema="i_ORDER;t_action_type;t_description;t_action_description";
-                listSchema.push_back(def);;
-        }
 
         isResetRealyNeeded=iResetOnCreation;
         refresh();
@@ -229,6 +71,7 @@ void SKGObjectModel::buidCache()
         suboperationTable= ( getTable() =="v_operation_consolidated" );
         ruleTable= ( getRealTable() =="rule" );
         categoryTable= ( getRealTable() =="category" );
+        interestTable= ( getRealTable() =="interest" );
 
         if ( unitvalueTable ) {
                 SKGUnitValueObject unitValObject=getObject ( index ( 0,0 ) );
@@ -236,7 +79,18 @@ void SKGObjectModel::buidCache()
                 unitValObject.getUnit ( unitObject );
                 SKGUnitObject parent;
                 unitObject.getUnit ( parent );
-                if ( parent.exist() ) cacheUnit=parent.getSymbol();
+                if ( parent.exist() ) {
+                        cacheUnit.Name=parent.getSymbol();
+                        cacheUnit.Value=1;
+                        cacheUnit.NbDecimal=parent.getNumberDecimal();
+                }
+
+                //Bug 209672 vvvv
+                if (unitObject.getType()==SKGUnitObject::INDEX) {
+                        cacheUnit.Name=' ';
+                }
+                //Bug 209672 ^^^^
+
         }
 
         if ( operationTable ) {
@@ -251,10 +105,13 @@ void SKGObjectModel::buidCache()
                 fontSubOperationsColor = qVariantFromValue (pref.readEntry ( "fontSubOperationColor",QColor ( Qt::green ) ));
         }
 
+	if ( operationTable || recurrentoperationTable || accountTable || ruleTable) {
+                icon_favorite=KIcon ( "rating" );
+	}
+
         if ( operationTable || recurrentoperationTable ) {
                 icon_skrooge_transfer=KIcon ( "skrooge_transfer" );
                 icon_skrooge_split=KIcon ( "skrooge_split" );
-                icon_favorite=KIcon ( "rating" );
                 icon_imported=KIcon ( "utilities-file-archiver" );
                 {
                         QStringList overlay;
@@ -334,7 +191,7 @@ QVariant SKGObjectModel::data ( const QModelIndex &index, int role ) const
                 SKGObjectBase* obj = getObjectPointer ( index );
                 QString att=listAttibutes[index.column() ];
                 QString val=obj->getAttribute ( att );
-                if ( ( ( operationTable || recurrentoperationTable || trackerTable) &&
+                if ( ( ( operationTable || recurrentoperationTable || trackerTable || accountTable || ruleTable) &&
                                 ( att=="t_bookmarked" || att=="t_status" || att=="i_NBRECURRENT" || att=="t_imported" ) )
                                 || ( att=="t_close" )
                                 || ( att=="t_action_type")
@@ -352,41 +209,80 @@ QVariant SKGObjectModel::data ( const QModelIndex &index, int role ) const
                                 return val;
                         } else return "";
                 } else if ( accountTable && att=="t_type" ) {
-                        if ( val=="C" ) return i18n ( "Current" );
-                        else if ( val=="D" ) return i18n ( "Credit card" );
-                        else if ( val=="A" ) return i18n ( "Assets" );
-                        else if ( val=="I" ) return i18n ( "Investment" );
-                        else return i18n ( "Other" );
+                        if ( val=="C" ) return i18nc ( "Noun, a type of account", "Current" );
+                        else if ( val=="D" ) return i18nc ( "Noun, a type of account","Credit card" );
+                        else if ( val=="A" ) return i18nc ( "Noun, a type of account","Assets" );
+                        else if ( val=="I" ) return i18nc ( "Noun, a type of account", "Investment" );
+                        else return i18nc ( "Noun", "Other" );
                 } else if ( unitTable && att=="t_type" ) {
-                        if ( val=="1" ) return i18n ( "Primary currency" );
-                        else if ( val=="2" ) return i18n ( "Secondary currency" );
-                        else if ( val=="C" ) return i18n ( "Currency" );
-                        else if ( val=="S" ) return i18n ( "Share" );
-                        else if ( val=="I" ) return i18n ( "Index" );
-                        else return i18n ( "Object" );
-                } else if ( getAttributeType ( index.column() ) ==SKGObjectModelBase::DOUBLE ) {
+                        if ( val=="1" ) return i18nc ( "Noun", "Primary currency" );
+                        else if ( val=="2" ) return i18nc ( "Noun", "Secondary currency" );
+                        else if ( val=="C" ) return i18nc ( "Noun", "Currency" );
+                        else if ( val=="S" ) return i18nc ( "Noun", "Share" );
+                        else if ( val=="I" ) return i18nc ( "Noun, example CAC40, DOWJONES", "Index" );
+                        else return i18nc ( "Noun","Object" );
+                } else if ( interestTable && att=="t_expenditure_value_date_mode" ) {
+                        if ( val=="0" ) return i18nc ( "Noun","Day -0" );
+                        else if ( val=="1" ) return i18nc ( "Noun","Day -1" );
+                        else if ( val=="2" ) return i18nc ( "Noun","Day -2" );
+                        else if ( val=="3" ) return i18nc ( "Noun","Day -3" );
+                        else if ( val=="4" ) return i18nc ( "Noun","Day -4" );
+                        else if ( val=="5" ) return i18nc ( "Noun","Day -5" );
+                        else return i18nc ( "Noun","Fifteen" );
+                } else if ( interestTable && att=="t_income_value_date_mode" ) {
+                        if ( val=="0" ) return i18nc ( "Noun","Day +0" );
+                        else if ( val=="1" ) return i18nc ( "Noun","Day +1" );
+                        else if ( val=="2" ) return i18nc ( "Noun","Day +2" );
+                        else if ( val=="3" ) return i18nc ( "Noun","Day +3" );
+                        else if ( val=="4" ) return i18nc ( "Noun","Day +4" );
+                        else if ( val=="5" ) return i18nc ( "Noun","Day +5" );
+                        else return i18nc ( "Noun","Fifteen" );
+                } else if ( getAttributeType ( index.column() ) ==SKGServices::FLOAT ) {
                         double dval=SKGServices::stringToDouble ( val );
                         if ( role == Qt::DisplayRole ) {
-                                if ( att.endsWith(QLatin1String("_INCOME")) || att.endsWith(QLatin1String("_EXPENSE")) ||
-                                                (categoryTable && (att=="f_REALCURRENTAMOUNT" || att=="f_SUMCURRENTAMOUNT"))) {
+                                if ( att.endsWith(QLatin1String("_INCOME")) ||
+                                                att.endsWith(QLatin1String("_EXPENSE")) ||
+                                                (categoryTable && (att=="f_REALCURRENTAMOUNT" ||
+                                                                   att=="f_SUMCURRENTAMOUNT"))) {
                                         double dval=SKGServices::stringToDouble ( val );
                                         if ( dval==0 ) return "";
                                 }
 
-                                QString unit=QString(' ');
+                                SKGServices::SKGUnitInfo unit;
+                                unit.Name=QString(' ');
+                                unit.NbDecimal=2;
                                 if ( !att.contains("QUANTITY")) {
                                         unit= ( ( SKGDocumentBank* ) getDocument() )->getPrimaryUnit();
-                                        if ( unitvalueTable && !cacheUnit.isEmpty() ) {
+                                        if ( unitvalueTable && !cacheUnit.Name.isEmpty() ) {
                                                 unit=cacheUnit;
                                         }
                                 } else {
-                                        unit=obj->getAttribute ("t_UNIT");
+                                        if (att=="f_QUANTITYOWNED") {
+                                                unit.NbDecimal=SKGServices::stringToInt(obj->getAttribute ("i_nbdecimal"));
+                                        } else {
+                                                unit.Name=obj->getAttribute ("t_UNIT");
+                                        }
                                 }
-                                return KGlobal::locale()->formatMoney ( dval, unit, 2 );
+
+                                //Bug 209672 vvvv
+                                if (unitTable) {
+                                        if (obj->getAttribute ("t_type")=="I") unit.Name=' ';
+                                }
+                                //Bug 209672 ^^^
+
+                                if (att=="f_rate") {
+                                        unit.Name='%';
+                                        unit.NbDecimal=2;
+                                } else if (att=="f_coef") {
+                                        unit.Name=' ';
+                                        unit.NbDecimal=2;
+                                }
+
+                                return KGlobal::locale()->formatMoney ( dval, unit.Name, unit.NbDecimal );
                         } else {
                                 return dval;
                         }
-                } else if ( getAttributeType ( index.column() ) ==SKGObjectModelBase::INTEGER ) {
+                } else if ( getAttributeType ( index.column() ) ==SKGServices::INTEGER ) {
                         if ( recurrentoperationTable && att=="i_nb_times" ) {
                                 QString t_times=obj->getAttribute ( "t_times" );
                                 if ( t_times!="Y" ) return QChar(8734);
@@ -401,28 +297,17 @@ QVariant SKGObjectModel::data ( const QModelIndex &index, int role ) const
                 //decoration
                 SKGObjectBase* obj = getObjectPointer ( index );
                 QString att=listAttibutes[index.column() ];
-                if ( accountTable && att=="t_BANK" ) {
-                        QString t_icon=obj->getAttribute ( "t_icon" );
-                        if ( t_icon.isEmpty() ) t_icon=obj->getAttribute ( "t_ICON" );
-                        if ( !t_icon.isEmpty() ) {
-                                QDir dirLogo ( KStandardDirs::locate ( "data", QString::fromLatin1 ( "skrooge/images/logo/" ) ) );
-                                return qVariantFromValue ( QIcon ( dirLogo.absoluteFilePath ( t_icon ) ) );
-                        }
-                } else if ( categoryTable && index.column() == 0 ) {
-                        QString t_TYPEEXPENSE=obj->getAttribute ( "t_TYPEEXPENSE" );
-                        if ( t_TYPEEXPENSE=="-" ) return icon_category_moins;
-                        else if ( t_TYPEEXPENSE=="+" ) return icon_category_plus;
-                        return icon_category;
-                } else if ( operationTable || recurrentoperationTable ) {
+                if ( operationTable || recurrentoperationTable ) {
                         if ( att=="t_mode" ) {
                                 if ( obj->getAttribute ( "i_group_id" ) !="0" ) return icon_skrooge_transfer;
-                        } else if ( att=="t_CATEGORY" ) {
+                        } else if ( att=="t_bookmarked") {
+			        if(obj->getAttribute ( "t_bookmarked" ) =="Y" )  return icon_favorite;
+			} else if ( att=="t_CATEGORY" ) {
                                 if ( SKGServices::stringToInt ( obj->getAttribute ( "i_NBSUBCATEGORY" ) ) >1 ) return icon_skrooge_split;
                         } else if ( att=="i_NBRECURRENT" && operationTable ) {
                                 if ( obj->getAttribute ( "i_NBRECURRENT" ) !="0" ) return icon_recurrent_master;
                                 else if ( obj->getAttribute ( "r_recurrentoperation_id" ) !="0" ) return icon_recurrent;
-                        } else if ( att=="t_bookmarked" && obj->getAttribute ( "t_bookmarked" ) =="Y" ) return icon_favorite;
-                        else if ( att=="t_imported") {
+                        } else if ( att=="t_imported") {
                                 QString impStatus=obj->getAttribute ( "t_imported" );
                                 if (impStatus=="Y") return icon_imported;
                                 else if (impStatus=="P")  return icon_imported_checked;
@@ -444,7 +329,9 @@ QVariant SKGObjectModel::data ( const QModelIndex &index, int role ) const
                                 if ( val=="S" ) return icon_search;
                                 else if ( val=="U" ) return icon_update;
                                 else return icon_alarm;
-                        }
+                        } else if ( att=="t_bookmarked") {
+			        if(obj->getAttribute ( "t_bookmarked" ) =="Y" )  return icon_favorite;
+			}
                 } else if ( unitTable ) {
                         if ( att=="f_CURRENTAMOUNT" ) {
                                 SKGUnitObject unit=*obj;
@@ -454,6 +341,25 @@ QVariant SKGObjectModel::data ( const QModelIndex &index, int role ) const
                                 else if ( annualchange>=5 ) return icon_skrooge_more;
                                 else if ( annualchange<=-5 ) return icon_skrooge_less;
                         }
+                } else if ( accountTable ) {
+		        if(att=="t_BANK" ) {
+				QString t_icon=obj->getAttribute ( "t_icon" );
+				if ( t_icon.isEmpty() ) t_icon=obj->getAttribute ( "t_ICON" );
+				if ( !t_icon.isEmpty() ) {
+					QDir dirLogo ( KStandardDirs::locate ( "data", QString::fromLatin1 ( "skrooge/images/logo/" ) ) );
+					return qVariantFromValue ( QIcon ( dirLogo.absoluteFilePath ( t_icon ) ) );
+				}
+                        } else if ( att=="t_bookmarked") {
+			        if(obj->getAttribute ( "t_bookmarked" ) =="Y" )  return icon_favorite;
+			}
+                } else if ( categoryTable) {
+			if(index.column() == 0 )
+			{
+				QString t_TYPEEXPENSE=obj->getAttribute ( "t_TYPEEXPENSE" );
+				if ( t_TYPEEXPENSE=="-" ) return icon_category_moins;
+				else if ( t_TYPEEXPENSE=="+" ) return icon_category_plus;
+				return icon_category;
+			}
                 }
                 break;
         }
@@ -465,7 +371,7 @@ QVariant SKGObjectModel::data ( const QModelIndex &index, int role ) const
                         if ( att=="d_date" && SKGServices::stringToTime ( obj->getAttribute ( "d_date" ) ).date() <=QDate::currentDate() ) return fontRedColor;
                 } else if ( operationTable ) {
                         if ( SKGServices::stringToTime ( obj->getAttribute ( "d_date" ) ).date() >QDate::currentDate() ) return fontFutureOperationsColor;
-                        else if (getAttributeType(index.column())!=SKGObjectModelBase::DOUBLE) {
+                        else if (getAttributeType(index.column())!=SKGServices::FLOAT) {
                                 if ( obj->getAttribute ( "t_imported" )=="P") return  fontNotValidatedOperationsColor;
                                 else if (suboperationTable) return fontSubOperationsColor;
                         }
@@ -527,19 +433,18 @@ QVariant SKGObjectModel::data ( const QModelIndex &index, int role ) const
         case Qt::ToolTipRole: {
                 //Tooltip
                 QString att=listAttibutes[index.column() ];
-                if (getAttributeType ( index.column() ) ==SKGObjectModelBase::DOUBLE) {
+                if (getAttributeType ( index.column() ) ==SKGServices::FLOAT) {
                         SKGObjectBase* obj = getObjectPointer ( index );
                         if ( obj ) {
                                 QString toolTipString;
 
                                 //Add secondary unit
                                 if (!att.contains("QUANTITY")) {
-                                        QString secondaryUnit= ( ( SKGDocumentBank* ) getDocument() )->getSecondaryUnit();
-                                        if ( !secondaryUnit.isEmpty() ) {
+                                        SKGServices::SKGUnitInfo secondaryUnit= ( ( SKGDocumentBank* ) getDocument() )->getSecondaryUnit();
+                                        if ( !secondaryUnit.Name.isEmpty() ) {
                                                 double val=SKGServices::stringToDouble ( obj->getAttribute ( att ) );
                                                 if ((!att.endsWith(QLatin1String("_INCOME")) && !att.endsWith(QLatin1String("_EXPENSE"))) ||val!=0) {
-                                                        double unitval= ( ( SKGDocumentBank* ) getDocument() )->getSecondaryUnitValue();
-                                                        if ( unitval )  toolTipString=KGlobal::locale()->formatMoney ( val/unitval, secondaryUnit, 2 );
+                                                        if ( secondaryUnit.Value )  toolTipString=KGlobal::locale()->formatMoney ( val/secondaryUnit.Value, secondaryUnit.Name, secondaryUnit.NbDecimal );
 
                                                 }
 
@@ -553,8 +458,9 @@ QVariant SKGObjectModel::data ( const QModelIndex &index, int role ) const
                                         double val1=SKGServices::stringToDouble ( obj->getAttribute ( "f_CURRENTAMOUNT" ) );
                                         double val2=SKGServices::stringToDouble ( originalAmount );
                                         double gain= ( val2!=0 ? 100.0* ( val1-val2 ) /val2 : 0 );
-                                        toolTipString+=i18n ( "Original amount=%1 (%2 %)",
-                                                              KGlobal::locale()->formatMoney ( val2, ( ( SKGDocumentBank* ) getDocument() )->getPrimaryUnit(), 2 ),
+                                        SKGServices::SKGUnitInfo primaryUnit=( ( SKGDocumentBank* ) getDocument() )->getPrimaryUnit();
+                                        toolTipString+=i18nc ( "Noun","Original amount=%1 (%2 %)",
+                                                              KGlobal::locale()->formatMoney ( val2, primaryUnit.Name, primaryUnit.NbDecimal ),
                                                               gain );
                                 }
 
@@ -563,8 +469,9 @@ QVariant SKGObjectModel::data ( const QModelIndex &index, int role ) const
                                         SKGOperationObject op=*obj;
                                         if (!op.isTemplate()) {
                                                 if ( !toolTipString.isEmpty() ) toolTipString+="\n\n";
-                                                toolTipString+=i18n ( "Account balance=%1",
-                                                                      KGlobal::locale()->formatMoney ( op.getBalance(), ( ( SKGDocumentBank* ) getDocument() )->getPrimaryUnit(), 2 ));
+                                                SKGServices::SKGUnitInfo primaryUnit=( ( SKGDocumentBank* ) getDocument() )->getPrimaryUnit();
+                                                toolTipString+=i18nc ( "Noun","Account balance=%1",
+                                                                      KGlobal::locale()->formatMoney ( op.getBalance(), primaryUnit.Name, primaryUnit.NbDecimal));
                                         }
                                 }
                                 if ( !toolTipString.isEmpty() ) return toolTipString;
@@ -582,11 +489,11 @@ QVariant SKGObjectModel::data ( const QModelIndex &index, int role ) const
                                 QString trackerName;
                                 if ( obj ) trackerName=obj->getAttribute(att);
                                 if (!trackerName.isEmpty()) {
-                                        SKGTrackerObject tracker=SKGObjectBase(getDocument(), "refund"); //Better performance if v_refund is not used
+                                        SKGTrackerObject tracker=SKGObjectBase(getDocument(), "v_refund");
                                         tracker.setName(trackerName);
                                         tracker.load();
-                                        QString unit= ( ( SKGDocumentBank* ) getDocument() )->getPrimaryUnit();
-                                        return KGlobal::locale()->formatMoney ( tracker.getCurrentAmount(), unit, 2 );
+                                        SKGServices::SKGUnitInfo unit= ( ( SKGDocumentBank* ) getDocument() )->getPrimaryUnit();
+                                        return KGlobal::locale()->formatMoney ( tracker.getCurrentAmount(), unit.Name, unit.NbDecimal );
                                 }
                         } else if ( att=="t_CATEGORY" ) {
                                 SKGOperationObject op=*(getObjectPointer ( index ));
@@ -623,8 +530,32 @@ QVariant SKGObjectModel::data ( const QModelIndex &index, int role ) const
                                         }
                                         return toolTip;
                                 }
-                        } else if ( att=="t_status" ) {
-                                return i18n("Ctrl+click to force checked status");
+                        } else if ( operationTable ) {
+                                SKGOperationObject op=*(getObjectPointer ( index ));
+				QString message;
+				if(op.getStatus()==SKGOperationObject::POINTED)
+				{
+				  message=i18nc("A tool tip", "This operation is pointed but not checked yet.");
+				  message+='\n';
+				  message+=i18nc("A tool tip", "You can use the reconciliation mode to validate pointed operations.");
+				  message+='\n';
+				  message+=i18nc("A tool tip", "Click to switch back status.");
+				  message+='\n';
+				  message+=i18nc("A tool tip", "Ctrl+click to force checked status.");
+				}
+				else if(op.getStatus()==SKGOperationObject::CHECKED)
+				{
+				  message=i18nc("A tool tip", "This operation is already checked.");
+				}
+				else if(op.getStatus()==SKGOperationObject::NONE)
+				{
+				  message=i18nc("A tool tip", "This operation is not pointed yet.");
+				  message+='\n';
+				  message+=i18nc("A tool tip", "Click to set pointed status.");
+				  message+='\n';
+				  message+=i18nc("A tool tip", "Ctrl+click to force checked status.");
+				}
+                                return message;
                         }
                 } else if ( ruleTable && att=="t_action_type" ) {
                         SKGObjectBase* obj = getObjectPointer ( index );
@@ -652,18 +583,18 @@ bool SKGObjectModel::setData ( const QModelIndex & index, const QVariant& value,
                 if ( accountTable ) {
                         SKGAccountObject obj=getObject ( index );
                         SKGBEGINTRANSACTION ( *getDocument(),
-                                              ( ( Qt::CheckState ) value.toInt() == Qt::Checked ? i18n ( "Close account [%1]", obj.getName() ) : i18n ( "Open account [%1]", obj.getName() ) ), err );
+                                              ( ( Qt::CheckState ) value.toInt() == Qt::Checked ? i18nc("Noun, name of the user action", "Close account [%1]", obj.getName() ) : i18nc("Noun, name of the user action", "Open account [%1]", obj.getName() ) ), err );
                         err=obj.setClosed ( ( Qt::CheckState ) value.toInt() == Qt::Checked );
                         if ( err.isSucceeded() ) err=obj.save();
                 } else if ( trackerTable ) {
                         SKGTrackerObject obj=getObject ( index );
                         SKGBEGINTRANSACTION ( *getDocument(),
-                                              ( ( Qt::CheckState ) value.toInt() == Qt::Checked ? i18n ( "Close tracker [%1]", obj.getName() ) : i18n ( "Open tracker [%1]", obj.getName() ) ), err );
+                                              ( ( Qt::CheckState ) value.toInt() == Qt::Checked ? i18nc("Noun, name of the user action", "Close tracker [%1]", obj.getName() ) : i18nc("Noun, name of the user action", "Open tracker [%1]", obj.getName() ) ), err );
                         err=obj.setClosed ( ( Qt::CheckState ) value.toInt() == Qt::Checked );
                         if ( err.isSucceeded() ) err=obj.save();
                 } else if ( operationTable ) {
                         SKGOperationObject obj=getObject ( index );
-                        SKGBEGINTRANSACTION ( *getDocument(), i18n ( "Change operation status" ), err );
+                        SKGBEGINTRANSACTION ( *getDocument(), i18nc("Noun, name of the user action", "Change operation status" ), err );
                         SKGOperationObject::OperationStatus statusinitial=obj.getStatus();
                         SKGOperationObject::OperationStatus t_status=statusinitial;
                         if ( QApplication::keyboardModifiers() &Qt::ControlModifier ) {
@@ -687,7 +618,7 @@ bool SKGObjectModel::setData ( const QModelIndex & index, const QVariant& value,
                         if ( objtmp ) {
                                 SKGRecurrentOperationObject obj=SKGRecurrentOperationObject ( objtmp->getDocument(), objtmp->getID() );
 
-                                SKGBEGINTRANSACTION ( *getDocument(), i18n ( "Recurrent operation update" ), err );
+                                SKGBEGINTRANSACTION ( *getDocument(), i18nc("Noun, name of the user action", "Recurrent operation update" ), err );
                                 if ( att=="i_warn_days" ) {
                                         err=obj.warnEnabled ( !obj.isWarnEnabled() );
                                         if ( err.isSucceeded() ) err=obj.save();
@@ -718,7 +649,7 @@ Qt::ItemFlags SKGObjectModel::flags ( const QModelIndex &index ) const
                 else flags|=Qt::ItemIsDropEnabled;
         } else if ( index.isValid() && operationTable ) {
                 QString att=listAttibutes[index.column() ];
-                if ( att=="t_status" ) flags|=Qt::ItemIsUserCheckable;
+                if ( att=="t_status" && !suboperationTable ) flags|=Qt::ItemIsUserCheckable;
         } else if ( index.isValid() && recurrentoperationTable ) {
                 QString att=listAttibutes[index.column() ];
                 if ( att=="i_warn_days" || att=="i_auto_write_days" || att=="i_nb_times" ) flags|=Qt::ItemIsUserCheckable;
@@ -760,7 +691,7 @@ bool SKGObjectModel::dropMimeData ( const QMimeData *data,
         SKGCategoryObject parentCategory;
         if ( parent.isValid() ) parentCategory=getObject ( parent );
         {
-                SKGBEGINTRANSACTION ( *getDocument(), i18n ( "Move category" ), err );
+                SKGBEGINTRANSACTION ( *getDocument(), i18nc("Noun, name of the user action", "Move category" ), err );
 
                 while ( !stream.atEnd() && err.isSucceeded() ) {
                         int o_id;
