@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -17,7 +17,7 @@
 #ifndef SKGACCOUNTOBJECT_H
 #define SKGACCOUNTOBJECT_H
 /** @file
- * This file is part of Skrooge and defines classes SKGAccountObject.
+ * This file defines classes SKGAccountObject.
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -28,6 +28,7 @@ class SKGBankObject;
 class SKGOperationObject;
 class SKGDocumentBank;
 class SKGUnitObject;
+class SKGInterestObject;
 
 /**
  * This class manages account object
@@ -35,10 +36,28 @@ class SKGUnitObject;
 class SKGBANKMODELER_EXPORT SKGAccountObject : public SKGNamedObject
 {
         Q_OBJECT;
-
+        /**
+         * This enumerate defines type of account
+         */
+        Q_ENUMS(AccountType);
 public:
         /**
-        * This structure defines type of account
+         * Describe a interest item
+         */
+        struct SKGInterestItem {
+                SKGObjectBase object; 	/**< The object (an operation, an interest or nothing for initial balance) */
+                QDate date; 	        /**< The date */
+                QDate valueDate; 	/**< The valueDate */
+                int base; 	        /**< Base */
+                double amount; 	        /**< Amount */
+                double coef; 	        /**< Coef */
+                double rate; 	        /**< Rate */
+                double annualInterest; 	/**< Annual Interest */
+                double accruedInterest; /**< Accrued Interest */
+        } ;
+
+        /**
+         * This enumerate defines type of account
          */
         enum AccountType {CURRENT, 	/**< to define a bank account*/
                           CREDITCARD, 	/**< to define a credit card account*/
@@ -163,6 +182,12 @@ public:
          */
         virtual SKGError addOperation(SKGOperationObject& oOperation);
 
+        /**
+         * Get number of operations
+         * @return the number of operations
+         */
+        virtual int getNbOperation() const;
+
         /**
          * Get the current amount
          * @return the current amount
@@ -205,6 +230,21 @@ public:
          */
         virtual bool isClosed() const;
 
+        /**
+         * To bookmark or not an account
+         * @param iBookmark the bookmark: true or false
+         * @return an object managing the error
+         *   @see SKGError
+         */
+        virtual SKGError bookmark(bool iBookmark);
+
+        /**
+         * To know if the account is bookmarked
+         * @return an object managing the error
+         *   @see SKGError
+         */
+        virtual bool isBookmarked() const;
+
         /**
          * Get the unit
          * @param oUnit the unit
@@ -212,6 +252,51 @@ public:
          *   @see SKGError
          */
         virtual SKGError getUnit(SKGUnitObject& oUnit) const;
+
+        /**
+         * Add an interest
+         * @param oInterest the created interest
+         * @return an object managing the error.
+         *   @see SKGError
+         */
+        virtual SKGError addInterest(SKGInterestObject& oInterest);
+
+        /**
+         * Get interests
+         * @param oInterestList the list of interest in this account
+         * @return an object managing the error
+         *   @see SKGError
+         */
+        virtual SKGError getInterests(SKGListSKGObjectBase& oInterestList) const;
+
+        /**
+         * Get interest object at a given date
+         * @param iDate the date
+         * @param oInterest the interest object
+         * @return an object managing the error
+         *   @see SKGError
+         */
+        virtual SKGError getInterest(const QDate& iDate, SKGInterestObject& oInterest) const;
+
+        /**
+         * Get and compute interest items
+         * @param oInterestList interest items
+         * @param oInterests sum of annual interests
+         * @param iYear the year of computation (default=current year)
+         * @return an object managing the error
+         *   @see SKGError
+         */
+        virtual SKGError getInterestItems(QList<SKGAccountObject::SKGInterestItem>& oInterestList, double& oInterests, int iYear=0) const;
+
+        /**
+         * Compute all items
+         * @param ioInterestList interest items
+         * @param oInterests sum of annual interests
+         * @param iYear the year of computation (default=current year)
+         * @return an object managing the error
+         *   @see SKGError
+         */
+        virtual SKGError computeInterestItems(QList<SKGAccountObject::SKGInterestItem>& ioInterestList, double& oInterests, int iYear=0) const;
 };
 
 #endif
