@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,7 +15,7 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
- * This file is part of Skrooge and implements classes SKGBankObject.
+ * This file implements classes SKGBankObject.
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -47,7 +47,7 @@ const SKGBankObject& SKGBankObject::operator= (const SKGObjectBase& iObject)
 SKGError SKGBankObject::addAccount(SKGAccountObject& oAccount)
 {
         SKGError err;
-        if (getID() == 0) err=SKGError(ERR_FAIL, i18n("%1 failed because linked object is not yet saved in the database.",QString("SKGBankObject::addAccount")));
+        if (getID() == 0) err=SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.",QString("SKGBankObject::addAccount")));
         else {
                 oAccount = SKGAccountObject((SKGDocumentBank*) getDocument());
                 err = oAccount.setAttribute("rd_bank_id", SKGServices::intToString(getID()));
