@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,7 +15,7 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
- * This file is part of Skrooge and implements classes SKGCategoryObject.
+ * This file implements classes SKGCategoryObject.
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -57,7 +57,7 @@ const SKGCategoryObject& SKGCategoryObject::operator= ( const SKGObjectBase& iOb
 SKGError SKGCategoryObject::setName ( const QString& iName )
 {
         SKGError err;
-        if ( iName.contains ( OBJECTSEPARATOR ) ) err=SKGError ( ERR_FAIL,  i18n( "The name can not contain [%1]" , QString(OBJECTSEPARATOR) ) );
+        if ( iName.contains ( OBJECTSEPARATOR ) ) err=SKGError ( ERR_FAIL,  i18nc("Error message", "The name can not contain [%1]" , QString(OBJECTSEPARATOR) ) );
         else err=SKGNamedObject::setName ( iName );
         return err;
 }
@@ -92,50 +92,57 @@ SKGError SKGCategoryObject::createPathCategory ( const SKGDocumentBank* iDocumen
         SKGTRACEINRC ( 10, "SKGCategoryObject::createPathCategory", err );
 
         //Check if category is already existing
-        SKGObjectBase::getObject ( iDocument, "v_category", "t_fullname='"+SKGServices::stringToSqlString ( iFullPath ) +'\'', oCategory );
-        if ( oCategory.getID() ==0 ) {
-                //No, we have to create it
-                //Search category separator
-                int posSeparator=iFullPath.lastIndexOf ( OBJECTSEPARATOR );
-                if ( posSeparator==-1 ) {
-                        //Not found, so it's only a single category
-                        //Search if object already exist
-                        //We don't catch the error because it's just to know
-                        //if the object exists
-                        SKGObjectBase::getObject ( iDocument, "v_category", "t_name='"+SKGServices::stringToSqlString ( iFullPath ) +
-                                                   "' AND (r_category_id=0 OR r_category_id IS NULL)", oCategory );
+	if(iFullPath.isEmpty())
+	{
+	  oCategory=SKGCategoryObject(NULL, 0);
+	}
+	else
+	{
+	    SKGObjectBase::getObject ( iDocument, "v_category", "t_fullname='"+SKGServices::stringToSqlString ( iFullPath ) +'\'', oCategory );
+	    if ( oCategory.getID() ==0 ) {
+		    //No, we have to create it
+		    //Search category separator
+		    int posSeparator=iFullPath.lastIndexOf ( OBJECTSEPARATOR );
+		    if ( posSeparator==-1 ) {
+			    //Not found, so it's only a single category
+			    //Search if object already exist
+			    //We don't catch the error because it's just to know
+			    //if the object exists
+			    SKGObjectBase::getObject ( iDocument, "v_category", "t_name='"+SKGServices::stringToSqlString ( iFullPath ) +
+						      "' AND (r_category_id=0 OR r_category_id IS NULL)", oCategory );
 
-                        if ( oCategory.getID() ==0 ) {
-                                //Doesn't exist, we have to create it
-                                oCategory = SKGCategoryObject ( ( SKGDocumentBank* ) iDocument );
-                                err=oCategory.setName ( iFullPath );
-                                if ( err.isSucceeded() ) err=oCategory.save();
-                        }
-                } else {
-                        //Get first and second parts of the branch
-                        QString first = iFullPath.mid ( 0,posSeparator );
-                        QString second = iFullPath.mid ( posSeparator+strlen ( OBJECTSEPARATOR ), iFullPath.length()-posSeparator-strlen ( OBJECTSEPARATOR ) );
+			    if ( oCategory.getID() ==0 ) {
+				    //Doesn't exist, we have to create it
+				    oCategory = SKGCategoryObject ( ( SKGDocumentBank* ) iDocument );
+				    err=oCategory.setName ( iFullPath );
+				    if ( err.isSucceeded() ) err=oCategory.save();
+			    }
+		    } else {
+			    //Get first and second parts of the branch
+			    QString first = iFullPath.mid ( 0,posSeparator );
+			    QString second = iFullPath.mid ( posSeparator+strlen ( OBJECTSEPARATOR ), iFullPath.length()-posSeparator-strlen ( OBJECTSEPARATOR ) );
 
-                        //Get first category
-                        SKGCategoryObject FirstCategory;
-                        err=SKGCategoryObject::createPathCategory ( iDocument, first, FirstCategory );
+			    //Get first category
+			    SKGCategoryObject FirstCategory;
+			    err=SKGCategoryObject::createPathCategory ( iDocument, first, FirstCategory );
 
-                        if ( err.isSucceeded() ) {
-                                //Get second category
-                                err=FirstCategory.addCategory ( oCategory );
+			    if ( err.isSucceeded() ) {
+				    //Get second category
+				    err=FirstCategory.addCategory ( oCategory );
 
-                                //Add second under first
-                                if ( err.isSucceeded() ) err = oCategory.setName ( second );
+				    //Add second under first
+				    if ( err.isSucceeded() ) err = oCategory.setName ( second );
 
-                                //save
-                                if ( err.isSucceeded() ) err = oCategory.save();
-                        }
-                }
+				    //save
+				    if ( err.isSucceeded() ) err = oCategory.save();
+			    }
+		    }
 
-                if ( err.isSucceeded() && iSendPopupMessageOnCreation && iDocument ) {
-                        ( ( SKGDocumentBank* ) iDocument )->sendMessage (  i18n( "Category [%1] has been created" , iFullPath ), true );
-                }
-        }
+		    if ( err.isSucceeded() && iSendPopupMessageOnCreation && iDocument ) {
+			    ( ( SKGDocumentBank* ) iDocument )->sendMessage (  i18nc( "Information message", "Category [%1] has been created" , iFullPath ), true );
+		    }
+	    }
+	}
 
         return err;
 }
@@ -144,7 +151,7 @@ SKGError SKGCategoryObject::addCategory ( SKGCategoryObject& oCategory )
 {
         SKGError err;
         SKGTRACEINRC ( 10, "SKGCategoryObject::addCategory", err );
-	if ( getID() == 0 )  err=SKGError ( ERR_FAIL,  i18n( "%1 failed because linked object is not yet saved in the database." , QString("SKGCategoryObject::addCategory") ) );
+	if ( getID() == 0 )  err=SKGError ( ERR_FAIL,  i18nc("Error message", "%1 failed because linked object is not yet saved in the database." , QString("SKGCategoryObject::addCategory") ) );
         else {
                 oCategory = SKGCategoryObject ( ( SKGDocumentBank* ) getDocument() );
                 err = oCategory.setAttribute ( "r_category_id", SKGServices::intToString ( getID() ) );
@@ -156,13 +163,13 @@ SKGError SKGCategoryObject::setParentCategory ( const SKGCategoryObject& iCatego
 {
         SKGError err;
         SKGTRACEINRC ( 10, "SKGCategoryObject::setParentCategory", err );
-	if ( iCategory.getID() ==0 ) err=SKGError ( ERR_FAIL,  i18n( "%1 failed because linked object is not yet saved in the database." , QString("SKGCategoryObject::setParentCategory") ) );
+	if ( iCategory.getID() ==0 ) err=SKGError ( ERR_FAIL,  i18nc("Error message", "%1 failed because linked object is not yet saved in the database." , QString("SKGCategoryObject::setParentCategory") ) );
         else {
                 //Check if it's a loop
                 SKGCategoryObject current=iCategory;
                 do {
                         if ( current==*this ) {
-                                err=SKGError ( ERR_FAIL,  i18n( "You can not create a loop." ) );
+                                err=SKGError ( ERR_FAIL,  i18nc("Error message", "You cannot create a loop." ) );
                         } else {
                                 SKGCategoryObject parent;
                                 current.getParentCategory ( parent );
