@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -17,7 +17,7 @@
 #ifndef SKGDOCUMENTBANK_H
 #define SKGDOCUMENTBANK_H
 /** @file
- * This file is part of Skrooge and defines classes SKGDocumentBank.
+ * This file defines classes SKGDocumentBank.
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -101,7 +101,7 @@ public:
         /**
          * Update unit's attributes
          * @param iUnitName unit name
-         * @param iInternetCode new internet code
+         * @param iInternetCode new Internet code
          * @return an object managing the error.
          *   @see SKGError
          */
@@ -124,23 +124,32 @@ public:
          */
         virtual SKGError deleteUnit(const QString& iUnitName) const;
 
+        /**
+         * Get formated money
+         * @param iValue value
+         * @param iUnit unit
+         * @return formated value in red or black
+         */
+        virtual QString formatMoney(double iValue, SKGServices::SKGUnitInfo iUnit) const;
+
+	 /**
+         * Get formated percentage
+         * @param iValue value
+         * @return formated value in red or black
+         */
+        virtual QString formatPercentage(double iValue) const;
+
         /**
          * Get Primary unit. WARNING: This value can be not uptodated in a transaction.
          * @return Primary unit.
          */
-        virtual QString getPrimaryUnit();
+        virtual SKGServices::SKGUnitInfo getPrimaryUnit();
 
         /**
          * Get Secondary unit. WARNING: This value can be not uptodated in a transaction.
          * @return Secondary unit.
          */
-        virtual QString getSecondaryUnit();
-
-        /**
-         * Get Secondary unit value. WARNING: This value can be not uptodated in a transaction.
-         * @return Secondary unit value.
-         */
-        virtual double getSecondaryUnitValue();
+        virtual SKGServices::SKGUnitInfo getSecondaryUnit();
 
         /**
          * Refresh all views and indexes in the database
@@ -155,6 +164,13 @@ public:
          */
         virtual QString getViewsIndexesAndTriggersVersion() const;
 
+        /**
+         * Get display schemas
+        * @param iRealTable the real table name
+         * @return list of schemas
+         */
+        virtual QList<SKGDocument::SKGModelTemplate> getDisplaySchemas(const QString& iRealTable) const;
+
         /**
          * Get the display string for any modeler object (table, attribute)
          * @param iString the name of the object (example: v_operation, v_unit.t_name)
@@ -174,7 +190,7 @@ public:
          * @param iAttributeName the name of an attribute
          * @return the type
          */
-        virtual SKGServices::AttibuteType getAttibuteType(const QString& iAttributeName) const;
+        virtual SKGServices::AttributeType getAttributeType(const QString& iAttributeName) const;
 
 protected:
         /**
