@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -17,7 +17,7 @@
 #ifndef SKGOPERATIONOBJECT_H
 #define SKGOPERATIONOBJECT_H
 /** @file
- * This file is part of Skrooge and defines classes SKGOperationObject.
+ * This file defines classes SKGOperationObject.
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -35,12 +35,14 @@ class SKGRecurrentOperationObject;
 class SKGBANKMODELER_EXPORT SKGOperationObject : public SKGObjectBase
 {
         Q_OBJECT;
+        /**
+         * This enumerate defines status for operations
+         */
         Q_ENUMS(OperationStatus);
-
 public:
 
         /**
-         * This structure defines status for operations
+         * This enumerate defines status for operations
          */
         enum OperationStatus {NONE, /**< no status */
                               POINTED, /**< pointed */
@@ -210,9 +212,16 @@ public:
          */
         virtual bool isInGroup() const;
 
+        /**
+         * To know if the current operation is a transfer of the other one
+         * @param oOperation the other operation
+         * @return true or false
+         */
+        virtual bool isTransfer(SKGOperationObject& oOperation) const;
+
         /**
          * Set the group operation
-         * @param iOperation the unit
+         * @param iOperation the operation (itself to remove from group)
          * @return an object managing the error
          *   @see SKGError
          */
@@ -349,6 +358,14 @@ public:
          *   @see SKGError
          */
         virtual SKGError getRecurrentOperations(SKGListSKGObjectBase& oRecurrentOperation) const;
+
+        /**
+         * Merge current operation with an other one
+         * @param iDeletedOne after merge this operation will be deleted
+         * @return an object managing the error
+         *   @see SKGError
+         */
+        virtual SKGError merge(const SKGOperationObject& iDeletedOne);
 };
 
 #endif
