@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,7 +15,7 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
- * This file is part of Skrooge and implements classes SKGRecurrentOperationObject.
+ * This file implements classes SKGRecurrentOperationObject.
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -177,7 +177,7 @@ SKGError SKGRecurrentOperationObject::getRecurredOperations(SKGListSKGObjectBase
         return SKGObjectBase::getObjects(getDocument(), "v_operation", "r_recurrentoperation_id="+ SKGServices::intToString(getID()), oOperations);
 }
 
-SKGError SKGRecurrentOperationObject::process(int& oNbInserted, bool iForce)
+SKGError SKGRecurrentOperationObject::process(int& oNbInserted, bool iForce, const QDate& iDate)
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGRecurrentOperationObject::process", err);
@@ -186,7 +186,7 @@ SKGError SKGRecurrentOperationObject::process(int& oNbInserted, bool iForce)
         if (!hasTimeLimit() || getTimeLimit()>0) {
                 if (isAutoWriteEnabled() || iForce) {
                         QDate nextDate=getDate();
-                        if (QDate::currentDate()>=nextDate.addDays(-getAutoWriteDays())) {
+                        if (iDate>=nextDate.addDays(-getAutoWriteDays())) {
                                 SKGOperationObject op;
                                 err=getParentOperation(op);
                                 if (err.isSucceeded()) {
@@ -214,13 +214,13 @@ SKGError SKGRecurrentOperationObject::process(int& oNbInserted, bool iForce)
 
                                         //Process again in case of multi insert needed
                                         int nbi=0;
-                                        if (err.isSucceeded()) err=process(nbi);
+                                        if (err.isSucceeded()) err=process(nbi, iForce, iDate);
                                         oNbInserted=oNbInserted+1+nbi;
 
                                         //Send message
                                         if (err.isSucceeded()) err=newOp.load();
                                         if (err.isSucceeded()) {
-                                                err=((SKGDocument*) getDocument())->sendMessage(i18n("Operation [%1] has been inserted",newOp.getDisplayName()));
+                                                err=((SKGDocument*) getDocument())->sendMessage(i18nc("An information message", "Operation [%1] has been inserted",newOp.getDisplayName()));
                                         }
                                 }
                         }
@@ -235,7 +235,7 @@ SKGError SKGRecurrentOperationObject::process(int& oNbInserted, bool iForce)
                                         int nbdays=QDate::currentDate().daysTo(nextDate);
                                         if (nbdays>0) {
                                                 QString objname=op.getDisplayName();
-                                                err=((SKGDocument*) getDocument())->sendMessage(i18np("Operation [%1] will be inserted in %2 days", "Operation [%1] will be inserted in %2 day", objname, nbdays));
+                                                err=((SKGDocument*) getDocument())->sendMessage(i18np("Operation [%2] will be inserted in one day", "Operation [%2] will be inserted in %1 days", nbdays, objname));
                                         }
                                 }
                         }
@@ -244,7 +244,7 @@ SKGError SKGRecurrentOperationObject::process(int& oNbInserted, bool iForce)
         return err;
 }
 
-SKGError SKGRecurrentOperationObject::process(const SKGDocument* iDocument, int& oNbInserted)
+SKGError SKGRecurrentOperationObject::process(const SKGDocument* iDocument, int& oNbInserted, const QDate& iDate)
 {
         SKGError err;
         oNbInserted=0;
@@ -257,7 +257,7 @@ SKGError SKGRecurrentOperationObject::process(const SKGDocument* iDocument, int&
         for (int i=0; err.isSucceeded() && i<nb; ++i) {
                 SKGRecurrentOperationObject recu=recuOps.at(i);
                 int nbi=0;
-                err=recu.process(nbi);
+                err=recu.process(nbi, false, iDate);
                 oNbInserted+=nbi;
         }
 
