@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -17,7 +17,7 @@
 #ifndef SKGRECURRENTOPERATIONOBJECT_H
 #define SKGRECURRENTOPERATIONOBJECT_H
 /** @file
- * This file is part of Skrooge and defines classes SKGRecurrentOperationObject.
+ * This file defines classes SKGRecurrentOperationObject.
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -32,12 +32,15 @@ class SKGOperationObject;
 class SKGBANKMODELER_EXPORT SKGRecurrentOperationObject : public SKGObjectBase
 {
         Q_OBJECT;
+        /**
+         * This enumerate defines the period unit
+         */
         Q_ENUMS(PeriodUnit);
 
 public:
 
         /**
-         * This structure defines status for operations
+         * This enumerate defines the period unit
          */
         enum PeriodUnit {DAY=0, 	/**< day */
                          MONTH=1, 	/**< month */
@@ -237,19 +240,21 @@ public:
          * Warn and/or create operations for this recurrent operation
          * @param oNbInserted number of operations inserted
          * @param iForce to force the insertion even if autowrite is not enable
+         * @param iDate date limite for insertion
          * @return an object managing the error
          *   @see SKGError
          */
-        virtual SKGError process(int& oNbInserted, bool iForce=false);
+        virtual SKGError process(int& oNbInserted, bool iForce=false, const QDate& iDate=QDate::currentDate());
 
         /**
          * Warn and/or create operations for all recurrent operations of the document
          * @param iDocument the document containing the object
          * @param oNbInserted number of operations inserted
+         * @param iDate date limite for insertion
          * @return an object managing the error
          *   @see SKGError
          */
-        static SKGError process(const SKGDocument* iDocument, int& oNbInserted);
+        static SKGError process(const SKGDocument* iDocument, int& oNbInserted, const QDate& iDate=QDate::currentDate());
 };
 
 #endif
