@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,7 +15,7 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
- * This file is part of Skrooge and defines classes SKGRuleObject.
+ * This file defines classes SKGRuleObject.
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -56,6 +56,17 @@ SKGRuleObject::~SKGRuleObject()
 {
 }
 
+SKGError SKGRuleObject::bookmark ( bool iBookmark )
+{
+    return setAttribute ( "t_bookmarked", iBookmark ? "Y" :"N" );
+
+}
+
+bool SKGRuleObject::isBookmarked() const
+{
+    return ( getAttribute ( "t_bookmarked" ) =="Y" ? true : false );
+}
+
 SKGError SKGRuleObject::save(bool iInsertOrUpdate, bool iReloadAfterSave)
 {
         //Do the save
@@ -182,52 +193,57 @@ SKGError SKGRuleObject::execute(ProcessMode iMode)
                 QString addSql;
                 if (iMode==IMPORTED) addSql="t_imported!='N'";
                 else if (iMode==IMPORTEDNOTVALIDATE) addSql="t_imported='P'";
+                else if (iMode==IMPORTING) addSql="t_imported='T'";
 
                 QString wc=getSelectSqlOrder(addSql);
                 if (wc.isEmpty()) wc="1=1";
 
                 SKGDocument* doc=(SKGDocument*) getDocument();
+		if(doc)
+		{
+		    QStringList list=SKGRuleObject::getFromXML(doc, getXMLActionDefinition(), true, UPDATE, true); //SQL + SET clause
+		    int nb=list.count();
+		    err=doc->beginTransaction("#INTERNAL#", nb);
+		    for (int i=0; err.isSucceeded() && i<nb; ++i) {
+			    QString sql=list.at(i);
+			    sql.replace("#WC#", wc);
+			    err=SKGServices::executeSqliteOrder(doc, sql);
+			    if (err.isSucceeded()) err=doc->stepForward(i+1);
+		    }
 
-                QStringList list=SKGRuleObject::getFromXML(doc, getXMLActionDefinition(), true, UPDATE, true); //SQL + SET clause
-                int nb=list.count();
-                err=doc->beginTransaction("#INTERNAL#", nb);
-                for (int i=0; err.isSucceeded() && i<nb; ++i) {
-                        QString sql=list.at(i);
-                        sql.replace("#WC#", wc);
-                        err=SKGServices::executeSqliteOrder(doc, sql);
-                        if (err.isSucceeded()) err=doc->stepForward(i+1);
-                }
+		    if (err.isSucceeded()) {
+			    SKGStringListList result;
+			    err=SKGServices::executeSelectSqliteOrder(doc, "SELECT changes()", result);
+			    if (err.isSucceeded() && result.count()==2) {
+				    int nb=SKGServices::stringToInt(result.at(1).at(0));
+				    if (nb) doc->sendMessage(i18np("1 operation modified by %2", "%1 operations modified by %2", nb, getAttribute("i_ORDER")));
+			    }
+		    }
 
-                if (err.isSucceeded()) {
-                        SKGStringListList result;
-                        err=SKGServices::executeSelectSqliteOrder(doc, "SELECT changes()", result);
-                        if (err.isSucceeded() && result.count()==2) {
-                                int nb=SKGServices::stringToInt(result.at(1).at(0));
-                                if (nb) doc->sendMessage(i18np("1 operation modified by %2", "%1 operations modified by %2", nb, getAttribute("i_ORDER")));
-                        }
-                }
-
-                if (err.isSucceeded()) err=doc->endTransaction(true);
-                else doc->endTransaction(false);
+		    if (err.isSucceeded()) err=doc->endTransaction(true);
+		    else doc->endTransaction(false);
+		}
         } else if (getActionType()==SKGRuleObject::ALARM) {
                 //Alarm mode
                 QString wc=getSelectSqlOrder();
                 if (wc.isEmpty()) wc="1=1";
 
                 SKGDocument* doc=(SKGDocument*) getDocument();
+		if(doc)
+		{
+		    QStringList list=SKGRuleObject::getFromXML(doc, getXMLActionDefinition(), true, ALARM, false);
+		    if (list.count()) {
+			    QString sql=list.at(0);
+			    sql.replace("#WC#", wc);
 
-                QStringList list=SKGRuleObject::getFromXML(doc, getXMLActionDefinition(), true, ALARM, false);
-                if (list.count()) {
-                        QString sql=list.at(0);
-                        sql.replace("#WC#", wc);
-
-                        SKGStringListList result;
-                        err=SKGServices::executeSelectSqliteOrder(doc, sql, result);
-                        if (err.isSucceeded() && result.count()==2) {
-                                //Is alarm raised ?
-                                if (result.at(1).at(0)=="1") doc->sendMessage(result.at(1).at(3));
-                        }
-                }
+			    SKGStringListList result;
+			    err=SKGServices::executeSelectSqliteOrder(doc, sql, result);
+			    if (err.isSucceeded() && result.count()==2) {
+				    //Is alarm raised ?
+				    if (result.at(1).at(0)=="1") doc->sendMessage(result.at(1).at(3));
+			    }
+		    }
+		}
         }
         return err;
 }
@@ -240,56 +256,92 @@ double SKGRuleObject::getOrder() const
 QString SKGRuleObject::getDisplayForOperator(const QString& iOperator, const QString& iParam1, const QString& iParam2, const QString& iAtt2)
 {
         QString output=iOperator;
-        if (output=="#ATT# LIKE '%#V1S#%'") output=i18n("contains '#V1S#'").replace("#V1S#", iParam1);
-        else if (output=="#ATT# LIKE '#V1S#%'") output=i18n("starts with '#V1S#'").replace( "#V1S#", iParam1);
-        else if (output=="#ATT# LIKE '%#V1S#'") output=i18n("ends with '#V1S#'").replace( "#V1S#", iParam1);
-        else if (output=="#ATT#=''") output=i18n("is empty");
-        else if (output=="#ATT#!=''") output=i18n("is not empty");
+        if (output=="#ATT# LIKE '%#V1S#%'")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "contains '#V1S#'").replace("#V1S#", iParam1);
+        else if (output=="#ATT# LIKE '#V1S#%'")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "starts with '#V1S#'").replace( "#V1S#", iParam1);
+        else if (output=="#ATT# LIKE '%#V1S#'")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "ends with '#V1S#'").replace( "#V1S#", iParam1);
+        else if (output=="#ATT#=''")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is empty");
+        else if (output=="#ATT#!=''")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is not empty");
 
-        else if (output=="#ATT#=#V1#") output=i18n("=#V1#").replace( "#V1#", iParam1);
-        else if (output=="#ATT#!=#V1#") output=i18n("!=#V1#").replace( "#V1#", iParam1);
-        else if (output=="#ATT#>#V1#") output=i18n(">#V1#").replace( "#V1#", iParam1);
-        else if (output=="#ATT#<#V1#") output=i18n("<#V1#").replace( "#V1#", iParam1);
-        else if (output=="#ATT#>=#V1#") output=i18n(">=#V1#").replace( "#V1#", iParam1);
-        else if (output=="#ATT#<=#V1#") output=i18n("<=#V1#").replace( "#V1#", iParam1);
+        else if (output=="#ATT#=#V1#")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=#V1#").replace( "#V1#", iParam1);
+        else if (output=="#ATT#!=#V1#")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "!=#V1#").replace( "#V1#", iParam1);
+        else if (output=="#ATT#>#V1#")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", ">#V1#").replace( "#V1#", iParam1);
+        else if (output=="#ATT#<#V1#")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "<#V1#").replace( "#V1#", iParam1);
+        else if (output=="#ATT#>=#V1#")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", ">=#V1#").replace( "#V1#", iParam1);
+        else if (output=="#ATT#<=#V1#")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "<=#V1#").replace( "#V1#", iParam1);
 
-        else if (output=="#ATT#='#V1S#'") output=i18n("='#V1S#'").replace( "#V1S#", iParam1);
-        else if (output=="#ATT#!='#V1S#'") output=i18n("!='#V1S#'").replace( "#V1S#", iParam1);
-        else if (output=="#ATT#>'#V1S#'") output=i18n(">'#V1S#'").replace( "#V1S#", iParam1);
-        else if (output=="#ATT#<'#V1S#'") output=i18n("<'#V1S#'").replace( "#V1S#", iParam1);
-        else if (output=="#ATT#>='#V1S#'") output=i18n(">='#V1S#'").replace( "#V1S#", iParam1);
-        else if (output=="#ATT#<='#V1S#'") output=i18n("<='#V1S#'").replace( "#V1S#", iParam1);
+        else if (output=="#ATT#='#V1S#'")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "='#V1S#'").replace( "#V1S#", iParam1);
+        else if (output=="#ATT#!='#V1S#'")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "!='#V1S#'").replace( "#V1S#", iParam1);
+        else if (output=="#ATT#>'#V1S#'")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", ">'#V1S#'").replace( "#V1S#", iParam1);
+        else if (output=="#ATT#<'#V1S#'")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "<'#V1S#'").replace( "#V1S#", iParam1);
+        else if (output=="#ATT#>='#V1S#'")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", ">='#V1S#'").replace( "#V1S#", iParam1);
+        else if (output=="#ATT#<='#V1S#'")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "<='#V1S#'").replace( "#V1S#", iParam1);
 
-        else if (output=="#ATT#>=#V1# AND #ATT#<=#V2#") output=i18n("is between #V1# and #V2#").replace( "#V1#", iParam1).replace( "#V2#", iParam2);
-        else if (output=="#ATT#>='#V1S#' AND #ATT#<='#V2S#'") output=i18n("is between '#V1S#' and '#V2S#'").replace( "#V1S#", iParam1).replace( "#V2S#", iParam2);
+        else if (output=="#ATT#>=#V1# AND #ATT#<=#V2#")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is between #V1# and #V2#").replace( "#V1#", iParam1).replace( "#V2#", iParam2);
+        else if (output=="#ATT#>='#V1S#' AND #ATT#<='#V2S#'")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is between '#V1S#' and '#V2S#'").replace( "#V1S#", iParam1).replace( "#V2S#", iParam2);
+        else if (output=="#ATT#=lower(#ATT#)")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is set to lower");
+        else if (output=="#ATT#=upper(#ATT#)")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is set to upper");
+        else if (output=="#ATT#!=lower(#ATT#)")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is not lower");
+        else if (output=="#ATT#!=upper(#ATT#)")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is not upper");
 
-        else if (output=="#ATT#=lower(#ATT#)") output=i18n("is set to lower");
-        else if (output=="#ATT#=upper(#ATT#)") output=i18n("is set to upper");
+        else if (output=="#ATT#=replace(#ATT2#,'#V1S#','#V2S#')")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=#ATT2# with '#V1S#' replaced by '#V2S#'").replace( "#V1S#", iParam1).replace( "#V2S#", iParam2).replace( "#ATT2#", iAtt2);
+        else if (output=="#ATT#=substr(#ATT2#,'#V1#','#V2#')")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=substring of #ATT2# from #V1# to #V2#").replace( "#V1#", iParam1).replace( "#V2#", iParam2).replace( "#ATT2#", iAtt2);
+        else if (output=="#ATT#=#ATT2#")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=#ATT2#").replace( "#ATT2#", iAtt2);
 
-        else if (output=="#ATT#!=lower(#ATT#)") output=i18n("is not lower");
-        else if (output=="#ATT#!=upper(#ATT#)") output=i18n("is not upper");
-
-        else if (output=="#ATT#=replace(#ATT2#,'#V1S#','#V2S#')") output=i18n("=#ATT2# with '#V1S#' replaced by '#V2S#'").replace( "#V1S#", iParam1).replace( "#V2S#", iParam2).replace( "#ATT2#", iAtt2);
-        else if (output=="#ATT#=substr(#ATT2#,'#V1#','#V2#')") output=i18n("=substring of #ATT2# from #V1# to #V2#").replace( "#V1#", iParam1).replace( "#V2#", iParam2).replace( "#ATT2#", iAtt2);
-        else if (output=="#ATT#=#ATT2#") output=i18n("=#ATT2#").replace( "#ATT2#", iAtt2);
-
-        else if (output=="STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now'))") output=i18n("is in current month");
-        else if (output=="STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now','-1 month'))") output=i18n("is in previous month");
-        else if (output=="STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now'))") output=i18n("is in current year");
-        else if (output=="STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now','-1 year'))") output=i18n("is in previous year");
-        else if (output=="#ATT#>date('now','-30 day') AND #ATT#<=date('now')") output=i18n("is in last 30 days");
-        else if (output=="#ATT#>date('now','-3 month') AND #ATT#<=date('now')") output=i18n("is in last 3 months");
-        else if (output=="#ATT#>date('now','-6 month') AND #ATT#<=date('now')") output=i18n("is in last 6 months");
-        else if (output=="#ATT#>date('now','-12 month') AND #ATT#<=date('now')") output=i18n("is in last 12 months");
-        else if (output=="#ATT#>date('now','-2 year') AND #ATT#<=date('now')") output=i18n("is in last 2 years");
-        else if (output=="#ATT#>date('now','-3 year') AND #ATT#<=date('now')") output=i18n("is in last 3 years");
-        else if (output=="#ATT#>date('now','-5 year') AND #ATT#<=date('now')") output=i18n("is in last 5 years");
-        else if (output=="ABS(TOTAL(#ATT#))#OP##V1#,ABS(TOTAL(#ATT#)), #V1#, '#V2S#'") output=i18n("If total(#ATT#)#OP##V1# then send '#V2S#'").replace("#V1#", iParam1).replace("#V2S#", iParam2).replace("#OP#", iAtt2);
+        else if (output=="STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now'))")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in current month");
+        else if (output=="STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now','-1 month'))")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in previous month");
+        else if (output=="STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now'))")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in current year");
+        else if (output=="STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now','-1 year'))")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in previous year");
+        else if (output=="#ATT#>date('now','-30 day') AND #ATT#<=date('now')")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 30 days");
+        else if (output=="#ATT#>date('now','-3 month') AND #ATT#<=date('now')")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 3 months");
+        else if (output=="#ATT#>date('now','-6 month') AND #ATT#<=date('now')")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 6 months");
+        else if (output=="#ATT#>date('now','-12 month') AND #ATT#<=date('now')")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 12 months");
+        else if (output=="#ATT#>date('now','-2 year') AND #ATT#<=date('now')")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 2 years");
+        else if (output=="#ATT#>date('now','-3 year') AND #ATT#<=date('now')")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 3 years");
+        else if (output=="#ATT#>date('now','-5 year') AND #ATT#<=date('now')")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 5 years");
+        else if (output=="ABS(TOTAL(#ATT#))#OP##V1#,ABS(TOTAL(#ATT#)), #V1#, '#V2S#'")
+	  output=i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "If total(#ATT#)#OP##V1# then send '#V2S#'").replace("#V1#", iParam1).replace("#V2S#", iParam2).replace("#OP#", iAtt2);
 
         return output;
 }
 
-QStringList SKGRuleObject::getListOfOperators(SKGServices::AttibuteType iAttributeType, SKGRuleObject::ActionType iType)
+QStringList SKGRuleObject::getListOfOperators(SKGServices::AttributeType iAttributeType, SKGRuleObject::ActionType iType)
 {
         QStringList output;
         if (iType==UPDATE) {
