@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -17,7 +17,7 @@
 #ifndef SKGSUBOPERATIONOBJECT_H
 #define SKGSUBOPERATIONOBJECT_H
 /** @file
- * This file is part of Skrooge and defines classes SKGSubOperationObject.
+ * This file defines classes SKGSubOperationObject.
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -127,13 +127,6 @@ public:
          */
         virtual SKGError getTracker(SKGTrackerObject& oTracker) const;
 
-        /**
-         * Remove the tracker
-         * @return an object managing the error
-         *   @see SKGError
-         */
-        virtual SKGError removeTracker();
-
         /**
          * Set the quantity of the suboperation
          * @param iValue the value
