@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,7 +15,7 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
- * This file is part of Skrooge and defines classes SKGUnitObject.
+ * This file defines classes SKGUnitObject.
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -89,19 +89,20 @@ QStringList SKGUnitObject::getListofKnownCurrencies()
 {
         QStringList output;
         output
-        << i18n("Euro (EUR)")
-        << i18n("United States Dollar (USD)")
-        << i18n("French Franc (FRF)")
-        << i18n("Belgium Franc (BEF)")
-        << i18n("Deutsche Mark (DEM)")
-        << i18n("Espana Peseta (ESP)")
-        << i18n("Italian Lira (ITL)")
-        << i18n("Pound Sterling (GBP)")
-        << i18n("Canadian Dollar (CAD)")
-        << i18n("CAC 40")
-        << i18n("Dow Jones (DJIA)")
-        << i18n("NASDAQ")
-        << i18n("SBF 120")
+        << i18nc("Noun, a currency", "Euro (EUR)")
+        << i18nc("Noun, a currency", "United States Dollar (USD)")
+        << i18nc("Noun, a currency", "French Franc (FRF)")
+        << i18nc("Noun, a currency", "Belgium Franc (BEF)")
+        << i18nc("Noun, a currency", "Deutsche Mark (DEM)")
+        << i18nc("Noun, a currency", "Espana Peseta (ESP)")
+        << i18nc("Noun, a currency", "Italian Lira (ITL)")
+        << i18nc("Noun, a currency", "Pound Sterling (GBP)")
+        << i18nc("Noun, a currency", "Swedish krona (SEK)")
+        << i18nc("Noun, a currency", "Canadian Dollar (CAD)")
+        << i18nc("Noun, a currency", "CAC 40")
+        << i18nc("Noun, a currency", "Dow Jones (DJIA)")
+        << i18nc("Noun, a currency", "NASDAQ")
+        << i18nc("Noun, a currency", "SBF 120")
         ;
         return output;
 }
@@ -125,153 +126,166 @@ SKGError SKGUnitObject::createCurrencyUnit(const SKGDocumentBank* iDocument, con
                 QString name;
                 QString symbol;
                 QString country;
-                QString internet;
+                QString Internet;
                 SKGUnitObject parentUnit;
+                int decimal=2;
                 QDate date;
                 double value=0;
                 SKGUnitObject::UnitType type=SKGUnitObject::CURRENCY;
-                QString prim=((SKGDocumentBank*) iDocument)->getPrimaryUnit();
-                QString seco=((SKGDocumentBank*) iDocument)->getSecondaryUnit();
+                SKGServices::SKGUnitInfo prim=((SKGDocumentBank*) iDocument)->getPrimaryUnit();
+                SKGServices::SKGUnitInfo seco=((SKGDocumentBank*) iDocument)->getSecondaryUnit();
 
                 //Principal units
-                if (iUnitName==i18n("Euro (EUR)") || iUnitName=="EUR" || iUnitName==QString::fromUtf8("€")) {
+                if (iUnitName==i18nc("Noun, a currency", "Euro (EUR)") || iUnitName=="EUR" || iUnitName==QString::fromUtf8("€")) {
                         //Euro
-                        name=i18n("Euro (EUR)");
+                        name=i18nc("Noun, a currency", "Euro (EUR)");
                         symbol=QString::fromUtf8("€");
-                        country=i18n("Europe");
+                        country=i18nc("Noun, a country", "Europe");
                         date=QDate(2002,1,1);
                         value=1;
-                        type=(prim.isEmpty() || prim==symbol ? SKGUnitObject::PRIMARY : SKGUnitObject::CURRENCY);
-                } else if (iUnitName==i18n("United States Dollar (USD)") || iUnitName=="USD" || iUnitName==QString::fromUtf8("$")) {
+                        type=(prim.Name.isEmpty() || prim.Name==symbol ? SKGUnitObject::PRIMARY : SKGUnitObject::CURRENCY);
+                } else if (iUnitName==i18nc("Noun, a currency", "United States Dollar (USD)") || iUnitName=="USD" || iUnitName==QString::fromUtf8("$")) {
                         //US Dollar
-                        name=i18n("United States dollar (USD)");
+                        name=i18nc("Noun, a currency", "United States dollar (USD)");
                         symbol=QString::fromUtf8("$");
-                        country=i18n("United States");
+                        country=i18nc("Noun, a country", "United States");
                         date=QDate(1959,1,1);
                         value=1;
-                        type=(prim.isEmpty() || prim==symbol ? SKGUnitObject::PRIMARY : SKGUnitObject::CURRENCY);
-                } else if (iUnitName==i18n("Canadian Dollar (CAD)") || iUnitName=="CAD" || iUnitName==QString::fromUtf8("C$")) {
+                        type=(prim.Name.isEmpty() || prim.Name==symbol ? SKGUnitObject::PRIMARY : SKGUnitObject::CURRENCY);
+                } else if (iUnitName==i18nc("Noun, a currency", "Canadian Dollar (CAD)") || iUnitName=="CAD" || iUnitName==QString::fromUtf8("C$")) {
                         //US Dollar
-                        name=i18n("Canadian dollar (CAD)");
+                        name=i18nc("Noun, a currency", "Canadian dollar (CAD)");
                         symbol=QString::fromUtf8("C$");
-                        country=i18n("Canada");
+                        country=i18nc("Noun, a country", "Canada");
                         date=QDate(1858,1,1);
                         value=1;
-                        type=(prim.isEmpty() || prim==symbol ? SKGUnitObject::PRIMARY : SKGUnitObject::CURRENCY);
-                } else if (iUnitName==i18n("Pound Sterling (GBP)") || iUnitName=="GBP" || iUnitName==QString::fromUtf8("£")) {
+                        type=(prim.Name.isEmpty() || prim.Name==symbol ? SKGUnitObject::PRIMARY : SKGUnitObject::CURRENCY);
+                } else if (iUnitName==i18nc("Noun, a currency", "Pound Sterling (GBP)") || iUnitName=="GBP" || iUnitName==QString::fromUtf8("£")) {
                         //Lyre
-                        name=i18n("Pound sterling (GBP)");
+                        name=i18nc("Noun, a currency", "Pound sterling (GBP)");
                         symbol=QString::fromUtf8("£");
-                        country=i18n("United Kingdom");
+                        country=i18nc("Noun, a country", "United Kingdom");
                         date=QDate(1990,9,8);
                         value=1;
-                        type=(prim.isEmpty() || prim==symbol  ? SKGUnitObject::PRIMARY : SKGUnitObject::CURRENCY);
+                        type=(prim.Name.isEmpty() || prim.Name==symbol  ? SKGUnitObject::PRIMARY : SKGUnitObject::CURRENCY);
                 }
                 //Europeen units
-                else if (iUnitName==i18n("French Franc (FRF)") || iUnitName=="FRF" || iUnitName=="F") {
+                else if (iUnitName==i18nc("Noun, a currency", "French Franc (FRF)") || iUnitName=="FRF" || iUnitName=="F") {
                         //Franc
-                        name=i18n("French Franc (FRF)");
+                        name=i18nc("Noun, a currency", "French Franc (FRF)");
                         symbol='F';
-                        country=i18n("France");
+                        country=i18nc("Noun, a country", "France");
                         date=QDate(1963,1,1);
                         value=1.0/6.55957;
-                        type=(seco.isEmpty() || seco==symbol  ? SKGUnitObject::SECONDARY : SKGUnitObject::CURRENCY);
+                        type=(seco.Name.isEmpty() || seco.Name==symbol  ? SKGUnitObject::SECONDARY : SKGUnitObject::CURRENCY);
 
                         err=SKGUnitObject::createCurrencyUnit(iDocument, "EUR", parentUnit);
-                } else if (iUnitName==i18n("Deutsche Mark (DEM)") || iUnitName=="DEM" || iUnitName=="DM") {
+                } else if (iUnitName==i18nc("Noun, a currency", "Deutsche Mark (DEM)") || iUnitName=="DEM" || iUnitName=="DM") {
                         //Deutch mark
-                        name=i18n("Deutsche mark (DEM)");
+                        name=i18nc("Noun, a currency", "Deutsche mark (DEM)");
                         symbol="DM";
-                        country=i18n("Germany");
+                        country=i18nc("Noun, a country", "Germany");
                         date=QDate(1948,1,1);
                         value=1.0/1.955083;
-                        type=(seco.isEmpty() || seco==symbol  ? SKGUnitObject::SECONDARY : SKGUnitObject::CURRENCY);
+                        type=(seco.Name.isEmpty() || seco.Name==symbol  ? SKGUnitObject::SECONDARY : SKGUnitObject::CURRENCY);
 
                         err=SKGUnitObject::createCurrencyUnit(iDocument, "EUR", parentUnit);
-                } else if (iUnitName==i18n("Espana Peseta (ESP)") || iUnitName=="ESP" || iUnitName=="P") {
+                } else if (iUnitName==i18nc("Noun, a currency", "Espana Peseta (ESP)") || iUnitName=="ESP" || iUnitName=="P") {
                         //Pesetas
-                        name=i18n("Espana Peseta (ESP)");
+                        name=i18nc("Noun, a currency", "Espana Peseta (ESP)");
                         symbol='P';
-                        country=i18n("Spain");
+                        country=i18nc("Noun, a country", "Spain");
                         date=QDate(1868,1,1);
                         value=1.0/166.386;
-                        type=(seco.isEmpty() || seco==symbol  ? SKGUnitObject::SECONDARY : SKGUnitObject::CURRENCY);
+                        type=(seco.Name.isEmpty() || seco.Name==symbol  ? SKGUnitObject::SECONDARY : SKGUnitObject::CURRENCY);
 
                         err=SKGUnitObject::createCurrencyUnit(iDocument, "EUR", parentUnit);
-                } else if (iUnitName==i18n("Italian Lira (ITL)") || iUnitName=="ITL" || iUnitName==QString::fromUtf8("£")) {
+                } else if (iUnitName==i18nc("Noun, a currency", "Italian Lira (ITL)") || iUnitName=="ITL" || iUnitName==QString::fromUtf8("£")) {
                         //Lyre
-                        name=i18n("Italian Lira (ITL)");
+                        name=i18nc("Noun, a currency", "Italian Lira (ITL)");
                         symbol=QString::fromUtf8("£");
-                        country=i18n("Italy");
+                        country=i18nc("Noun, a country", "Italy");
                         date=QDate(1970,1,1);
                         value=1.0/1936.27;
-                        type=(seco.isEmpty() || seco==symbol  ? SKGUnitObject::SECONDARY : SKGUnitObject::CURRENCY);
+                        type=(seco.Name.isEmpty() || seco.Name==symbol  ? SKGUnitObject::SECONDARY : SKGUnitObject::CURRENCY);
 
                         err=SKGUnitObject::createCurrencyUnit(iDocument, "EUR", parentUnit);
-                } else if (iUnitName==i18n("Belgium Franc (BEF)") || iUnitName=="BEF" || iUnitName=="FB") {
+                } else if (iUnitName==i18nc("Noun, a currency", "Belgium Franc (BEF)") || iUnitName=="BEF" || iUnitName=="FB") {
                         //Lyre
-                        name=i18n("Belgium Franc (BEF)");
+                        name=i18nc("Noun, a currency", "Belgium Franc (BEF)");
                         symbol="FB";
-                        country=i18n("Belgium");
+                        country=i18nc("Noun, a country", "Belgium");
                         date=QDate(1970,1,1);
                         value=1.0/40.3399;
-                        type=(seco.isEmpty() || seco==symbol  ? SKGUnitObject::SECONDARY : SKGUnitObject::CURRENCY);
+                        type=(seco.Name.isEmpty() || seco.Name==symbol  ? SKGUnitObject::SECONDARY : SKGUnitObject::CURRENCY);
+
+                        err=SKGUnitObject::createCurrencyUnit(iDocument, "EUR", parentUnit);
+                } else if (iUnitName==i18nc("Noun, a currency", "Swedish krona (SEK)") || iUnitName=="SEK" || iUnitName=="KR") {
+                        //Swedish krona
+                        name=i18nc("Noun, a currency", "Swedish krona (SEK)");
+                        symbol="KR";
+                        country=i18nc("Noun, a country", "Sweden");
+                        date=QDate(1970,1,1);
+                        value=-1;
+                        Internet="EURSEK=X";
+                        type=(seco.Name.isEmpty() || seco.Name==symbol  ? SKGUnitObject::SECONDARY : SKGUnitObject::CURRENCY);
 
                         err=SKGUnitObject::createCurrencyUnit(iDocument, "EUR", parentUnit);
                 }
+
                 //Indexes
-                else if (iUnitName==i18n("CAC 40")) {
+                else if (iUnitName==i18nc("Noun, a currency", "CAC 40")) {
                         //US Dollar
                         name=iUnitName;
                         symbol=iUnitName;
-                        country=i18n("France");
+                        country=i18nc("Noun, a country", "France");
                         date=QDate(1987,1,1);
                         value=-1;
-                        internet="^FCHI";
+                        Internet="^FCHI";
                         type=SKGUnitObject::INDEX;
-                } else if (iUnitName==i18n("NASDAQ")) {
+                } else if (iUnitName==i18nc("Noun, a currency", "NASDAQ")) {
                         //NASDAQ
                         name=iUnitName;
                         symbol=iUnitName;
-                        country=i18n("United States");
+                        country=i18nc("Noun, a country", "United States");
                         date=QDate(1971,2,5);
                         value=-1;
-                        internet="^IXIC";
+                        Internet="^IXIC";
                         type=SKGUnitObject::INDEX;
-                } else if (iUnitName==i18n("Dow Jones (DJIA)") || iUnitName=="DJIA") {
+                } else if (iUnitName==i18nc("Noun, a currency", "Dow Jones (DJIA)") || iUnitName=="DJIA") {
                         //Dow Jones
                         name=iUnitName;
                         symbol="DJIA";
-                        country=i18n("United States");
+                        country=i18nc("Noun, a country", "United States");
                         date=QDate(1884,1,1);
                         value=-1;
-                        internet="^DJI";
+                        Internet="^DJI";
                         type=SKGUnitObject::INDEX;
-                } else if (iUnitName==i18n("SBF 120")) {
+                } else if (iUnitName==i18nc("Noun, a currency", "SBF 120")) {
                         //SBF 120
                         name=iUnitName;
                         symbol=iUnitName;
-                        country=i18n("France");
+                        country=i18nc("Noun, a country", "France");
                         date=QDate(1990,12,31);
                         value=-1;
-                        internet="^SBF120";
+                        Internet="^SBF120";
                         type=SKGUnitObject::INDEX;
-                } else err=SKGError(ERR_INVALIDARG, i18n("Unknown unit [%1]",iUnitName));
+                } else err=SKGError(ERR_INVALIDARG, i18nc("Error message", "Unknown unit [%1]",iUnitName));
 
                 //Point on primary unit
                 if (value==1 && err.isSucceeded() && (type==SKGUnitObject::CURRENCY || type==SKGUnitObject::SECONDARY)) {
                         SKGUnitObject primunit(iDocument);
-                        err=primunit.setSymbol(prim);
+                        err=primunit.setSymbol(prim.Name);
                         if (err.isSucceeded()) err=primunit.load();
                         if (err.isSucceeded()) {
                                 QString codeprimunit=getInternationalCode(primunit.getName());
                                 QString codeunit=getInternationalCode(name);
                                 if (!codeprimunit.isEmpty()) {
-                                        internet=codeunit+codeprimunit+"=X";
+                                        Internet=codeunit+codeprimunit+"=X";
                                         value=-1;
 
                                         parentUnit=SKGUnitObject(iDocument);
-                                        err=parentUnit.setSymbol(prim);
+                                        err=parentUnit.setSymbol(prim.Name);
                                         if (err.isSucceeded()) err=parentUnit.load();
                                 }
                         }
@@ -283,8 +297,9 @@ SKGError SKGUnitObject::createCurrencyUnit(const SKGDocumentBank* iDocument, con
                 if (err.isSucceeded() && oUnit.exist()) err=oUnit.load();
                 if (err.isSucceeded()) err = oUnit.setType(type);
                 if (err.isSucceeded()) err = oUnit.setSymbol(symbol);
-                if (err.isSucceeded()) err = oUnit.setInternetCode(internet);
+                if (err.isSucceeded()) err = oUnit.setInternetCode(Internet);
                 if (err.isSucceeded()) err = oUnit.setCountry(country);
+                if (err.isSucceeded()) err = oUnit.setNumberDecimal(decimal);
                 if (err.isSucceeded() && parentUnit.exist()) err = oUnit.setUnit(parentUnit);
                 if (err.isSucceeded()) err = oUnit.save();
 
@@ -321,6 +336,16 @@ QString SKGUnitObject::getSymbol() const
         return getAttribute("t_symbol");
 }
 
+SKGError SKGUnitObject::setNumberDecimal(int iNb)
+{
+        return setAttribute("i_nbdecimal", SKGServices::intToString(iNb));
+}
+
+int SKGUnitObject::getNumberDecimal() const
+{
+        return SKGServices::stringToInt(getAttribute("i_nbdecimal"));
+}
+
 SKGError SKGUnitObject::setCountry(const QString& iCountry)
 {
         return setAttribute("t_country", iCountry);
@@ -372,7 +397,12 @@ SKGError SKGUnitObject::getUnit(SKGUnitObject& oUnit) const
 
 SKGError SKGUnitObject::setUnit(const SKGUnitObject& iUnit)
 {
-        return setAttribute("rd_unit_id", SKGServices::intToString(iUnit.getID()));
+        SKGError err;
+        if (*this==iUnit) err=SKGError(ERR_INVALIDARG, i18nc("Error message", "Reference unit of a unit cannot be itself."));
+        else {
+                err=setAttribute("rd_unit_id", SKGServices::intToString(iUnit.getID()));
+        }
+        return err;
 }
 
 SKGError SKGUnitObject::removeUnit()
@@ -383,7 +413,7 @@ SKGError SKGUnitObject::removeUnit()
 SKGError SKGUnitObject::addUnitValue(SKGUnitValueObject& oUnitValue)
 {
         SKGError err;
-        if (getID() == 0) err=SKGError(ERR_FAIL, i18n("%1 failed because linked object is not yet saved in the database.",QString("SKGUnitObject::addUnitValue")));
+        if (getID() == 0) err=SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.",QString("SKGUnitObject::addUnitValue")));
         else {
                 oUnitValue = SKGUnitValueObject((SKGDocumentBank*) getDocument());
                 err = oUnitValue.setAttribute("rd_unit_id", SKGServices::intToString(getID()));
@@ -482,7 +512,7 @@ SKGError SKGUnitObject::split(double iRatio) const
                                                     " WHERE rd_unit_id="+SKGServices::intToString(getID()));
                 if (err.isSucceeded()) err=SKGServices::executeSqliteOrder(getDocument(), "UPDATE suboperation SET f_value=f_value*"+SKGServices::doubleToString(iRatio)+
                                                    " WHERE rd_operation_id IN (SELECT id FROM operation WHERE rc_unit_id="+SKGServices::intToString(getID())+')');
-        } else err=SKGError(ERR_INVALIDARG, i18n("Invalid ratio. Ratio must be greater than 0."));
+        } else err=SKGError(ERR_INVALIDARG, i18nc("Error message", "Invalid ratio. Ratio must be greater than 0."));
         return err;
 }
 
