@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -81,6 +81,18 @@ int main(int argc, char** argv)
                 SKGTEST("PROP:oResult.size", oResult.size(), 1);
         }
 
+
+	{
+	        SKGDocumentBank document1;
+                SKGTESTERROR("DOC:initialize", document1.initialize(), true);
+		QStringList listTables;
+		SKGTESTERROR("SKGServices::getTablesList", SKGServices::getTablesList(&document1, listTables), true);
+		foreach(const QString& table, listTables)
+		{
+		  document1.getDisplaySchemas(table);
+		}
+	}
+
         //End test
         SKGENDTEST();
 }
