@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -154,6 +154,10 @@ int main(int argc, char** argv)
                                         SKGOperationObject opget;
                                         SKGTESTERROR("SUBOPE:getParentOperation", subop_1.getParentOperation(opget), true);
                                         SKGTEST("OPE:comparison", (opget==op_1), true);
+
+					SKGSubOperationObject subop_12=subop_1;
+					SKGSubOperationObject subop_13=SKGObjectBase(subop_1);
+					SKGSubOperationObject subop_14=SKGSubOperationObject(subop_1);
                                 }
 
                                 //Checks
@@ -180,6 +184,9 @@ int main(int argc, char** argv)
                         SKGOperationObject mainOpe;
                         SKGTESTERROR("OPE:getGroupedOperations", mainOperation.getGroupOperation(mainOpe), true);
                         SKGTEST("OPE:isImported", mainOperation.isImported(), false);
+                        SKGTEST("OPE:isTransfer",mainOperation.isTransfer(mainOpe), false);
+
+			SKGTEST("OPE:getAmount", mainOpe.getAmount(QDate::currentDate()), 135);
 
                         SKGAccountObject acc;
                         SKGTESTERROR("OPE:getParentAccount", mainOperation.getParentAccount(acc), true);
