@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -90,13 +90,19 @@ int main(int argc, char** argv)
 
                         SKGTrackerObject tracker(&document1);
                         SKGTrackerObject trackerCopy(tracker);
+                        SKGTrackerObject trackerCopy2((SKGObjectBase) tracker);
                         SKGTESTERROR("REF:setName",tracker.setName("tracker"), true);
                         SKGTESTERROR("REF:setComment",tracker.setComment("comment"), true);
                         SKGTESTERROR("REF:save", tracker.save(), true);
                         SKGTEST("REF:getName", tracker.getName(), "tracker");
                         SKGTEST("REF:getComment", tracker.getComment(), "comment");
 
-                        SKGTESTERROR("OPE:removeTracker",subop1.removeTracker(), true);
+                        SKGTEST("REF:isClosed", tracker.isClosed(), false);
+                        SKGTESTERROR("OPE:setClosed",tracker.setClosed(true), true);
+                        SKGTEST("REF:isClosed", tracker.isClosed(), true);
+                        SKGTESTERROR("OPE:setClosed",tracker.setClosed(false), true);
+                        SKGTEST("REF:isClosed", tracker.isClosed(), false);
+
                         SKGTESTERROR("OPE:setTracker",subop1.setTracker(tracker), true);
                         SKGTESTERROR("OPE:save", subop1.save(), true);
                         SKGTrackerObject tracker2;
@@ -108,6 +114,9 @@ int main(int argc, char** argv)
                         SKGObjectBase::SKGListSKGObjectBase oSubOperations;
                         SKGTESTERROR("REF:getSubOperations",tracker.getSubOperations(oSubOperations), true);
                         SKGTEST("REF:compare", oSubOperations.count(), 1);
+
+			SKGTrackerObject track;
+                        SKGTESTERROR("REF:createTracker",SKGTrackerObject::createTracker ( &document1, "track", track, true ), true);
                 }
         }
 
