@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -51,10 +51,12 @@ int main(int argc, char** argv)
                 SKGTEST("UNIT:getSymbol", unit1.getSymbol(),"F");
                 SKGTESTERROR("UNIT:setCountry", unit1.setCountry("France"), true);
                 SKGTEST("UNIT:getSymbol", unit1.getCountry(),"France");
-                SKGTESTERROR("UNIT:setInternetCode", unit1.setInternetCode("code internet"), true);
-                SKGTEST("UNIT:getInternetCode", unit1.getInternetCode(),"code internet");
+                SKGTESTERROR("UNIT:setInternetCode", unit1.setInternetCode("code Internet"), true);
+                SKGTEST("UNIT:getInternetCode", unit1.getInternetCode(),"code Internet");
                 SKGTESTERROR("UNIT:setType", unit1.setType(SKGUnitObject::OBJECT), true);
                 SKGTEST("UNIT:getType", unit1.getType(),SKGUnitObject::OBJECT);
+                SKGTESTERROR("UNIT:setNumberDecimal", unit1.setNumberDecimal(4), true);
+                SKGTEST("UNIT:getNumberDecimal", unit1.getNumberDecimal(),4);
                 SKGTESTERROR("UNIT:save", unit1.save(), true);
 
                 //Create unit value
@@ -128,8 +130,8 @@ int main(int argc, char** argv)
                 SKGDocumentBank document1;
                 SKGTESTERROR("document1.initialize()", document1.initialize(), true);
                 SKGError err;
-                SKGTEST("DOC:getPrimaryUnit", document1.getPrimaryUnit(), "");
-                SKGTEST("DOC:getSecondaryUnit", document1.getSecondaryUnit(), "");
+                SKGTEST("DOC:getPrimaryUnit", document1.getPrimaryUnit().Name, "");
+                SKGTEST("DOC:getSecondaryUnit", document1.getSecondaryUnit().Name, "");
                 SKGUnitObject franc(&document1);
                 {
                         SKGBEGINTRANSACTION(document1, "UNIT_1", err);
@@ -141,12 +143,12 @@ int main(int argc, char** argv)
                         SKGTEST("FRANC:getType", franc.getType(),SKGUnitObject::PRIMARY);
                         SKGTESTERROR("FRANC:save", franc.save(), true);
 
-                        SKGTEST("DOC:getPrimaryUnit", document1.getPrimaryUnit(), "F");
+                        SKGTEST("DOC:getPrimaryUnit", document1.getPrimaryUnit().Name, "F");
                 }
 
-                SKGTEST("DOC:getPrimaryUnit", document1.getPrimaryUnit(), "F");
-                SKGTEST("DOC:getSecondaryUnit", document1.getSecondaryUnit(), "");
-                SKGTEST("DOC:getSecondaryUnitValue", document1.getSecondaryUnitValue(), 1);
+                SKGTEST("DOC:getPrimaryUnit", document1.getPrimaryUnit().Name, "F");
+                SKGTEST("DOC:getSecondaryUnit", document1.getSecondaryUnit().Name, "");
+                SKGTEST("DOC:getSecondaryUnit", document1.getSecondaryUnit().Value, 1);
 
                 {
                         SKGBEGINTRANSACTION(document1, "UNIT_2", err);
@@ -165,8 +167,8 @@ int main(int argc, char** argv)
                         SKGTESTERROR("EURO:save", euro.save(), true);
                 }
 
-                SKGTEST("DOC:getPrimaryUnit", document1.getPrimaryUnit(), "E");
-                SKGTEST("DOC:getSecondaryUnit", document1.getSecondaryUnit(), "F");
+                SKGTEST("DOC:getPrimaryUnit", document1.getPrimaryUnit().Name, "E");
+                SKGTEST("DOC:getSecondaryUnit", document1.getSecondaryUnit().Name, "F");
 
         }
 
@@ -186,8 +188,8 @@ int main(int argc, char** argv)
                         SKGUnitObject unitObj;
                         SKGTESTERROR("UNIT:createCurrencyUnit", SKGUnitObject::createCurrencyUnit(&document1, "ZZZZZZZ", unitObj), false);
                 }
-                SKGTEST("DOC:getPrimaryUnit", document1.getPrimaryUnit(), QString::fromUtf8("€"));
-                SKGTEST("DOC:getSecondaryUnit", document1.getSecondaryUnit(), "F");
+                SKGTEST("DOC:getPrimaryUnit", document1.getPrimaryUnit().Name, QString::fromUtf8("€"));
+                SKGTEST("DOC:getSecondaryUnit", document1.getSecondaryUnit().Name, "F");
 
                 document1.dump(DUMPUNIT);
         }
@@ -212,6 +214,7 @@ int main(int argc, char** argv)
                         SKGTESTERROR("UNIT:setName", unit2.setName("U2"), true);
                         SKGTESTERROR("UNIT:setSymbol", unit2.setSymbol("U2"), true);
                         SKGTESTERROR("UNIT:removeUnit", unit2.removeUnit(), true);
+                        SKGTESTERROR("UNIT:setUnit", unit2.setUnit(unit2), false);
                         SKGTESTERROR("UNIT:setUnit", unit2.setUnit(unit1), true);
                         SKGTESTERROR("UNIT:save", unit2.save(), true);
                         SKGTESTERROR("UNIT:addOrModifyUnitValue", document1.addOrModifyUnitValue("U2", SKGServices::stringToTime("2001-02-01").date(), 10), true);
