@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,7 +15,7 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
- * A KLineEdit with calculator included for skrooge.
+ * A KLineEdit with calculator included.
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -72,6 +72,18 @@ void SKGCalculatorEdit::setValue (double iValue)
         setText(SKGServices::doubleToString(iValue));
 }
 
+void SKGCalculatorEdit::setText (const QString& iText)
+{
+        //Set default color
+        QPalette field_palette = palette();
+        field_palette.setColor(QPalette::Text,font_color);
+        setPalette(field_palette);
+
+        //Set text
+        KLineEdit::setText(iText);
+}
+
+
 void SKGCalculatorEdit::keyPressEvent( QKeyEvent * event )
 {
         if (event) {
@@ -79,11 +91,16 @@ void SKGCalculatorEdit::keyPressEvent( QKeyEvent * event )
                 if (mode()==CALCULATOR) {
                         bool hasText=!text().isEmpty() && selectedText()!=text();
 
-                        if (event->count()==1 && ((key==Qt::Key_Plus && hasText) || (key==Qt::Key_Minus && hasText) || key==Qt::Key_Asterisk || key==Qt::Key_Slash || key==Qt::Key_Return)) {
+                        if (event->count()==1 && ((key==Qt::Key_Plus && hasText) || (key==Qt::Key_Minus && hasText) || key==Qt::Key_Asterisk || key==Qt::Key_Slash || key==Qt::Key_Return || key == Qt::Key_Enter)) {
                                 keyPressEvent(key);
                                 event->accept();
                         } else KLineEdit::keyPressEvent(event);
                 } else {
+                        //Set default color
+                        QPalette field_palette = palette();
+                        field_palette.setColor(QPalette::Text,font_color);
+                        setPalette(field_palette);
+
                         keyPressEvent(key);
                         KLineEdit::keyPressEvent(event);
                 }
@@ -118,7 +135,7 @@ void SKGCalculatorEdit::keyPressEvent(int key)
                         lastValue=value();
                 }
 
-                if (key==Qt::Key_Return) {
+                if (key==Qt::Key_Return || key == Qt::Key_Enter) {
                         lastOperator=0;
                         lastValue=0;
                 } else {
@@ -126,31 +143,30 @@ void SKGCalculatorEdit::keyPressEvent(int key)
                         setText("");
                 }
         } else {
-                if (key==Qt::Key_Return) {
-                        QPalette field_palette = palette();
-
+                if (key==Qt::Key_Return || key == Qt::Key_Enter) {
                         QString t=text();
-                        t.replace(',','.'); // Replace comma by a point in case of typo
-                        QScriptEngine myEngine;
-                        QScriptValue result = myEngine.evaluate(t);
-                        if (result.isNumber()) {
-                                QString res;
-                                if (t.length()>0 && t[0]=='+' && result.toNumber()>0) res='+';
-                                res+=result.toString();
-                                setText(res);
-                                field_palette.setColor(QPalette::Text,font_color);
-                        }
-                        // The result is not a number,
-                        // * display the original string so thatso that user can correct it.
-                        // * set the widget's base color to red for better visualization
-                        else {
-                                setText(t);
-                                field_palette.setColor(QPalette::Text,Qt::red);
+                        if (!t.isEmpty()) {
+                                t.replace(',','.'); // Replace comma by a point in case of typo
+                                QScriptEngine myEngine;
+                                QScriptValue result = myEngine.evaluate(t);
+                                if (result.isNumber()) {
+                                        QString res;
+                                        if (t.length()>0 && t[0]=='+' && result.toNumber()>0) res='+';
+                                        res+=result.toString();
+                                        setText(res);
+                                }
+                                // The result is not a number,
+                                // * display the original string so thatso that user can correct it.
+                                // * set the widget's base color to red for better visualization
+                                else {
+                                        setText(t);
 
+                                        QPalette field_palette = palette();
+                                        field_palette.setColor(QPalette::Text,Qt::red);
+                                        setPalette(field_palette);
+                                }
                         }
-                        setPalette(field_palette);
                 }
-
         }
 }
 
