@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -17,7 +17,7 @@
 #ifndef SKGCALCULATOREDIT_H
 #define SKGCALCULATOREDIT_H
 /** @file
- * A KLineEdit with calculator included for skrooge.
+ * A KLineEdit with calculator included.
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -26,19 +26,31 @@
 #include <QtDesigner/QDesignerExportWidget>
 #include "skgbasegui_export.h"
 /**
- * This file is Skrooge a KLineEdit with calculator included
+ * This file is a KLineEdit with calculator included
  */
 class SKGBASEGUI_EXPORT SKGCalculatorEdit : public KLineEdit
 {
         Q_OBJECT
+        /**
+         * Value of the calculator editor
+         */
         Q_PROPERTY( double value READ value WRITE setValue USER true)
+        /**
+         * Mode of the calculator editor
+         */
         Q_PROPERTY( SKGCalculatorEdit::Mode mode READ mode WRITE setMode)
+        /**
+         * Sign of the calculator editor
+         */
         Q_PROPERTY( double sign READ sign )
+        /**
+         * Mode of the calculator editor
+         */
         Q_ENUMS(Mode);
 public:
 
         /**
-         * This structure defines type of calculator
+         * This enumerate defines type of calculator
          */
         enum Mode {CALCULATOR, /**< simple calculator */
                    EXPRESSION /**< expression is evaluated */
@@ -81,6 +93,12 @@ public:
          */
         virtual void setValue (double iValue);
 
+        /**
+         * Set the text
+         * @param iText the text
+         */
+        virtual void setText (const QString& iText);
+
         /**
          * Get the sign of the value.
          * 1 if the value is write like "+5"
