@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,21 +15,21 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
-* This file is Skrooge plugin interface default implementation.
+* This file is a plugin interface default implementation.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skginterfaceplugin.h"
 
-SKGInterfacePlugin::SKGInterfacePlugin(QObject * parent)
-                :KParts::Plugin(parent)
+SKGInterfacePlugin::SKGInterfacePlugin ( QObject * parent )
+        :KParts::Plugin ( parent )
 {}
 SKGInterfacePlugin::~SKGInterfacePlugin()
 {}
 
-void SKGInterfacePlugin::processArguments(const QStringList& iArgument)
+void SKGInterfacePlugin::processArguments ( const QStringList& iArgument )
 {
-        Q_UNUSED(iArgument);
+    Q_UNUSED ( iArgument );
 }
 
 void SKGInterfacePlugin::close() {}
@@ -38,69 +38,79 @@ void SKGInterfacePlugin::refresh() {}
 
 QDockWidget* SKGInterfacePlugin::getDockWidget()
 {
-        return NULL;
+    return NULL;
 }
 
-SKGTabWidget* SKGInterfacePlugin::getWidget()
+SKGTabPage* SKGInterfacePlugin::getWidget()
 {
-        return NULL;
+    return NULL;
 }
 
 int SKGInterfacePlugin::getNbDashboardWidgets()
 {
-        return 0;
+    return 0;
 }
 
-QString SKGInterfacePlugin::getDashboardWidgetTitle(int iIndex)
+QString SKGInterfacePlugin::getDashboardWidgetTitle ( int iIndex )
 {
-        Q_UNUSED(iIndex);
-        return "";
+    Q_UNUSED ( iIndex );
+    return "";
 }
 
-SKGWidget* SKGInterfacePlugin::getDashboardWidget(int iIndex)
+SKGWidget* SKGInterfacePlugin::getDashboardWidget ( int iIndex )
 {
-        Q_UNUSED(iIndex);
-        return NULL;
+    Q_UNUSED ( iIndex );
+    return NULL;
 }
 
 QWidget* SKGInterfacePlugin::getPreferenceWidget()
 {
-        return NULL;
+    return NULL;
 }
 
 KConfigSkeleton* SKGInterfacePlugin::getPreferenceSkeleton()
 {
-        return NULL;
+    return NULL;
 }
 
 SKGError SKGInterfacePlugin::savePreferences() const
 {
-        return SKGError();
+    return SKGError();
 }
 
 int SKGInterfacePlugin::getOrder() const
 {
-        return 999;
+    return 999;
+}
+
+QString SKGInterfacePlugin::statusTip () const
+{
+    return toolTip();
+}
+
+QString SKGInterfacePlugin::toolTip () const
+{
+    return "";
 }
 
 QStringList SKGInterfacePlugin::tips() const
 {
-        return QStringList();
+    return QStringList();
 }
 
 bool SKGInterfacePlugin::isInContext() const
 {
-        return false;
+    return false;
 }
 
 bool SKGInterfacePlugin::isTabClosable() const
 {
-        return false;
+    return false;
 }
 
 bool SKGInterfacePlugin::isEnabled() const
 {
-        return true;
+    return true;
 }
 
 #include "skginterfaceplugin.moc"
