@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -17,23 +17,27 @@
 #ifndef SKGMAINPANEL_H
 #define SKGMAINPANEL_H
 /** @file
-* This file is part of Skrooge and defines classes skrooge.
+* This file defines a main panel.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgobjectbase.h"
+#include "skgtabwidget.h"
 #include "skgbasegui_export.h"
+#include "skgtabpage.h"
+#include "skgbasegui_settings.h"
+
 #include <kparts/mainwindow.h>
 #include <ktabwidget.h>
 #include <kurl.h>
 #include <ksystemtrayicon.h>
+#include <ktemporaryfile.h>
 
 #include "ui_skgmainpanel_base.h"
 #include "ui_skgmainpanel_pref.h"
 
 class SKGInterfacePlugin;
 class SKGDocument;
-class SKGTabWidget;
 
 class QPrinter;
 class QListWidgetItem;
@@ -43,11 +47,12 @@ class KUrl;
 class KAction;
 class KSplashScreen;
 class KListWidget;
-class KTipDatabase;
 class KComboBox;
+class KToolBarPopupAction;
+class KMenu;
 
 /**
- * This class serves as the main window for skrooge.  It handles the
+ * This class serves as the main window.  It handles the
  * menus, toolbars, and status bars.
  */
 class SKGBASEGUI_EXPORT SKGMainPanel : public KParts::MainWindow
@@ -121,7 +126,13 @@ public:
          * Get the current tab
          * @return the current tab
          */
-        virtual SKGTabWidget* currentTab() const;
+        virtual SKGTabPage* currentTab() const;
+
+        /**
+         * Get the history item of the current tab
+         * @return the history item
+         */
+        virtual SKGTabPage::SKGPageHistoryItem currentTabHistoryItem() const;
 
         /**
          * Get the label for normal message in status bar
@@ -153,9 +164,10 @@ public:
          * @param index index of the tab to replace or -1 to add a new one
          * @param parameters parameters of the plugin
          * @param title title of the page
+         * @param iID id of the new page
          * @return the opened tab
          */
-        virtual SKGTabWidget* setNewTabContent ( SKGInterfacePlugin* plugin, int index=-1, const QString& parameters="", const QString& title="" );
+        virtual SKGTabPage* setNewTabContent ( SKGInterfacePlugin* plugin, int index=-1, const QString& parameters="", const QString& title="", const QString& iID="" );
 
         /**
          * Register a global action
@@ -171,6 +183,12 @@ public:
          */
         virtual KAction* getGlobalAction ( const QString& iIdentifier );
 
+        /**
+         * Define if the document must be saved when closed
+         * @param iSaveOnClose the save on close mode
+         */
+	virtual void setSaveOnClose(bool iSaveOnClose);
+
         /**
          * Creates a modal file dialog and returns the selected filename or an empty string if none was chosen.
          * A confirmation message is displayed if needed
@@ -241,12 +259,31 @@ public slots:
          */
         virtual void closeAllTabs();
 
+        /**
+         * Get main config groupe
+         * @return main config groupe
+         */
+        static KConfigGroup getMainConfigGroup();
+
+signals:
+        /**
+         * This signal is sent when the current page change.
+         */
+	void currentPageChanged();
+
 protected:
         /**
          * event
          * @param e event
          */
         virtual void changeEvent ( QEvent * e );
+        /**
+         * Event filtering
+         * @param object object
+         * @param event event
+         * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
+         */
+        virtual bool eventFilter ( QObject *object, QEvent *event );
 
 private slots:
         void optionsPreferences();
@@ -259,16 +296,20 @@ private slots:
         void onOpenContext();
         void onTipOfDay();
         void onTrayActivated ( QSystemTrayIcon::ActivationReason reason );
-        void onChangeStyleSheet ( const QString& iNewStryle );
         void saveDefaultState();
         void resetDefaultState();
         void overwriteBookmarkState();
+
+        void actionPrevious();
+        void actionNext();
+
+        void onShowPreviousMenu();
+        void onShowNextMenu();
 private:
         Q_DISABLE_COPY ( SKGMainPanel );
         void setupActions();
         bool iconInSystemtray();
         void refreshTabPosition();
-        bool eventFilter ( QObject *object, QEvent *event );
 
         static int progressBarCallBack ( int iPos, void* iProgressBar );
         static bool naturalLessThan(const QString &s1, const QString &s2);
@@ -276,7 +317,7 @@ private:
         Ui::skgmainpanel_base ui;
         Ui::skgmainpanel_pref uipref;
 
-        KTabWidget *tabView;
+        SKGTabWidget *tabWidget;
         KSplashScreen* spScreen;
 
         SKGDocument* currentBankDocument;
@@ -292,12 +333,19 @@ private:
         KAction *saveDefaultStateAction;
         KAction *resetDefaultStateAction;
         KAction *overwriteBookmarkStateAction;
-        KTipDatabase* tipDatabase;
+	KAction *configureAction;
+        KTemporaryFile tipsFile;
         static bool currentActionCanceled;
         KPushButton *kCancelButton;
         KSystemTrayIcon* kSystemTrayIcon;
         QLabel* kNormalMessage;
 
+        KToolBarPopupAction *previousAction;
+        KToolBarPopupAction *nextAction;
+
+        KMenu *previousMenu;
+        KMenu *nextMenu;
+
         struct doublePointer {
                 void* p1;
                 void* p2;
@@ -306,6 +354,7 @@ private:
         doublePointer progressObjects;
         QString defaultStyle;
         bool middleClick;
+	bool saveOnClose;
 
         static SKGMainPanel* mainPanel;
 };
