@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,7 +15,7 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
-* This file is part of Skrooge and defines classes SKGObjectModelBase.
+* This file defines classes SKGObjectModelBase.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -50,36 +50,7 @@ SKGObjectModelBase::SKGObjectModelBase(SKGDocument* iDocument,
 
         setTable(iTable);
 
-        //Build schemas
-        if (getRealTable()=="doctransaction") {
-                SKGModelTemplate def;
-                def.id="default";
-                def.name=i18nc("Noun, the default value of an item","Default");
-                def.icon="edit-undo";
-                def.schema="t_name;t_value;d_lastmodifdate;t_savestep";
-                listSchema.push_back(def);
-
-                SKGModelTemplate minimum;
-                minimum.id="minimum";
-                minimum.name=i18nc("Noun, the minimum value of an item","Minimum");
-                minimum.icon="";
-                minimum.schema="t_name;t_value;d_lastmodifdate|N;t_savestep|N";
-                listSchema.push_back(minimum);
-        } else if (getRealTable()=="parameters") {
-                SKGModelTemplate def;
-                def.id="default";
-                def.name=i18nc("Noun, the default value of an item","Default");
-                def.icon="edit-undo";
-                def.schema="t_name;t_value";
-                listSchema.push_back(def);
-        } else if (getRealTable()=="node") {
-                SKGModelTemplate def;
-                def.id="default";
-                def.name=i18nc("Noun, the default value of an item","Default");
-                def.icon="edit-undo";
-                def.schema="t_name";
-                listSchema.push_back(def);
-        }
+        if (document) listSchema=document->getDisplaySchemas(getRealTable());
 
         connect((const QObject*) document, SIGNAL(tableModified(QString, int)), this, SLOT(dataModified(QString, int)));
         refresh();
@@ -118,7 +89,7 @@ int SKGObjectModelBase::getID(const SKGObjectBase* obj, int row) const
         return (obj ? 100*(obj->getID())+row : 0);
 }
 
-QList<SKGObjectModelBase::SKGModelTemplate> SKGObjectModelBase::getSchemas() const
+QList<SKGDocument::SKGModelTemplate> SKGObjectModelBase::getSchemas() const
 {
         return listSchema;
 }
@@ -197,16 +168,23 @@ bool SKGObjectModelBase::blockRefresh(bool iBlocked)
         return previous;
 }
 
+bool SKGObjectModelBase::isRefreshBlocked()
+{
+        return refreshBlocked;
+}
+
 void SKGObjectModelBase::refresh()
 {
-        if (!isResetRealyNeeded || refreshBlocked) return;
+        if (!isResetRealyNeeded || isRefreshBlocked()) return;
         SKGTRACEIN(1, "SKGObjectModelBase::refresh");
+	SKGTRACEL(1) << "Table:" << getTable() << endl;
+        QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
         emit beforeReset();
         {
                 _SKGTRACEIN(10, "QAbstractItemModel::refresh-remove");
                 clear();
                 listAttibutes.clear();
-                listAttibuteTypes.clear();
+                listAttributeTypes.clear();
                 /*beginRemoveRows(QModelIndex(), 0, rowCount(QModelIndex())-1);
                 endRemoveRows();*/
         }
@@ -227,11 +205,11 @@ void SKGObjectModelBase::refresh()
                                         QString att=listSupported[i];
                                         if (listAttibutesTmp.contains(att)) {
                                                 listAttibutes.push_back(att);
-                                                if (att.startsWith(QLatin1String("t_"))) listAttibuteTypes.push_back(SKGObjectModelBase::STRING);
-                                                else if (att.startsWith(QLatin1String("f_"))) listAttibuteTypes.push_back(SKGObjectModelBase::DOUBLE);
-                                                else if (att.startsWith(QLatin1String("i_"))) listAttibuteTypes.push_back(SKGObjectModelBase::INTEGER);
-                                                else if (att.startsWith(QLatin1String("d_"))) listAttibuteTypes.push_back(SKGObjectModelBase::DATE);
-                                                else listAttibuteTypes.push_back(SKGObjectModelBase::OTHER);
+                                                if (att.startsWith(QLatin1String("t_"))) listAttributeTypes.push_back(SKGServices::TEXT);
+                                                else if (att.startsWith(QLatin1String("f_"))) listAttributeTypes.push_back(SKGServices::FLOAT);
+                                                else if (att.startsWith(QLatin1String("i_"))) listAttributeTypes.push_back(SKGServices::INTEGER);
+                                                else if (att.startsWith(QLatin1String("d_"))) listAttributeTypes.push_back(SKGServices::DATE);
+                                                else listAttributeTypes.push_back(SKGServices::OTHER);
                                         }
                                 }
 
@@ -249,7 +227,7 @@ void SKGObjectModelBase::refresh()
                                                 if (p!=-1) {
                                                         ;
                                                         listAttibutes.removeAt(p);
-                                                        listAttibuteTypes.removeAt(p);
+                                                        listAttributeTypes.removeAt(p);
                                                         if (p<i) --i;
                                                 }
                                         }
@@ -298,6 +276,7 @@ void SKGObjectModelBase::refresh()
                 }
         }
         emit afterReset();
+        QApplication::restoreOverrideCursor();
 }
 
 int SKGObjectModelBase::rowCount(const QModelIndex &parent ) const
@@ -362,9 +341,9 @@ QString SKGObjectModelBase::getAttribute (int iIndex ) const
         return listAttibutes.value(iIndex);
 }
 
-SKGObjectModelBase::AttributeType SKGObjectModelBase::getAttributeType (int iIndex ) const
+SKGServices::AttributeType SKGObjectModelBase::getAttributeType (int iIndex ) const
 {
-        return listAttibuteTypes.value(iIndex);
+        return listAttributeTypes.value(iIndex);
 }
 
 QVariant SKGObjectModelBase::headerData ( int section, Qt::Orientation orientation, int role ) const
@@ -434,14 +413,14 @@ QVariant SKGObjectModelBase::data(const QModelIndex &index, int role) const
                 QString val=obj->getAttribute(att);
 
                 switch ( getAttributeType(index.column()) ) {
-                case SKGObjectModelBase::DOUBLE: {
+                case SKGServices::FLOAT: {
                         double dval=SKGServices::stringToDouble(val);
                         return dval;
                 }
-                case SKGObjectModelBase::INTEGER: {
+                case SKGServices::INTEGER: {
                         return SKGServices::stringToInt(val);
                 }
-                case SKGObjectModelBase::DATE: {
+                case SKGServices::DATE: {
                         QDate dval=SKGServices::stringToTime(val).date();
                         if (role == Qt::DisplayRole) {
                                 return KGlobal::locale()->formatDate (dval, KLocale::FancyShortDate);
@@ -460,7 +439,7 @@ QVariant SKGObjectModelBase::data(const QModelIndex &index, int role) const
 
         case Qt::TextColorRole: {
                 //Text color
-                if (getAttributeType(index.column())==SKGObjectModelBase::DOUBLE) {
+                if (getAttributeType(index.column())==SKGServices::FLOAT) {
                         QVariant value_displayed = SKGObjectModelBase::data(index, Qt::UserRole);
                         bool ok=false;
                         double value_double=value_displayed.toDouble(&ok);
@@ -470,8 +449,8 @@ QVariant SKGObjectModelBase::data(const QModelIndex &index, int role) const
         }
         case Qt::TextAlignmentRole: {
                 //Text alignment
-                SKGObjectModelBase::AttributeType attType=getAttributeType(index.column());
-                return (int)(Qt::AlignVCenter|(attType==SKGObjectModelBase::DOUBLE || attType==SKGObjectModelBase::INTEGER ? Qt::AlignRight : Qt::AlignLeft));
+                SKGServices::AttributeType attType=getAttributeType(index.column());
+                return (int)(Qt::AlignVCenter|(attType==SKGServices::FLOAT || attType==SKGServices::INTEGER ? Qt::AlignRight : Qt::AlignLeft));
         }
         case Qt::DecorationRole: {
                 //Decoration
@@ -515,7 +494,7 @@ QVariant SKGObjectModelBase::data(const QModelIndex &index, int role) const
                                         return message;
                                 }
                         }
-                } else if (getAttributeType(index.column())==SKGObjectModelBase::DATE) {
+                } else if (getAttributeType(index.column())==SKGServices::DATE) {
                         SKGObjectBase* obj = getObjectPointer(index);
                         if (obj) {
                                 QString att=listAttibutes[index.column()];
@@ -574,7 +553,7 @@ bool SKGObjectModelBase::setData ( const QModelIndex & index, const QVariant& va
                 if ( nodeTable ) {
                         SKGNodeObject obj=getObject ( index );
                         QString name=value.toString();
-                        SKGBEGINTRANSACTION(*getDocument(), i18n("Bookmark update [%1]", name), err);
+                        SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Bookmark update [%1]", name), err);
                         err=obj.setName(name);
                         if (err.isSucceeded()) err=obj.save();
                 }
@@ -598,7 +577,7 @@ Qt::DropActions SKGObjectModelBase::supportedDropActions() const
 QStringList SKGObjectModelBase::mimeTypes() const
 {
         QStringList types;
-        types << "application/skrooge."+getRealTable()+".ids";
+        types << "application/skg."+getRealTable()+".ids";
         return types;
 }
 
@@ -619,7 +598,7 @@ QMimeData* SKGObjectModelBase::mimeData(const QModelIndexList &indexes) const
                 }
         }
 
-        mimeData->setData("application/skrooge."+t+".ids", encodedData);
+        mimeData->setData("application/skg."+t+".ids", encodedData);
         return mimeData;
 }
 
@@ -630,10 +609,10 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData *data,
 {
         Q_UNUSED(row);
         if (action == Qt::IgnoreAction) return true;
-        if (!data || !data->hasFormat("application/skrooge.node.ids")) return false;
+        if (!data || !data->hasFormat("application/skg.node.ids")) return false;
         if (column > 0) return false;
 
-        QByteArray encodedData = data->data("application/skrooge.node.ids");
+        QByteArray encodedData = data->data("application/skg.node.ids");
         QDataStream stream(&encodedData, QIODevice::ReadOnly);
         QStringList newItems;
 
@@ -641,7 +620,7 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData *data,
         SKGNodeObject parentNode;
         if (parent.isValid()) parentNode=getObject(parent);
         {
-                SKGBEGINTRANSACTION(*getDocument(), i18n("Move bookmark"), err);
+                SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Move bookmark"), err);
 
                 double min=0;
                 double max=0;
