@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,18 +15,21 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
- * A collection of widgets for skrooge (qt designer plugin).
+ * A collection of widgets (qt designer plugin).
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgwidgetcollectiondesignerplugin.h"
 #include "skgcomboboxdesignerplugin.h"
+#include "skglineeditdesignerplugin.h"
 #include "skgtableviewdesignerplugin.h"
 #include "skgtreeviewdesignerplugin.h"
 #include "skgdateeditdesignerplugin.h"
 #include "skgcalculatoreditdesignerplugin.h"
 #include "skggraphicsviewdesignerplugin.h"
 #include "skgtablewithgraphdesignerplugin.h"
+#include "skgtabwidgetdesignerplugin.h"
+#include "skgtablewidgetdesignerplugin.h"
 
 #include <QtPlugin>
 
@@ -35,11 +38,14 @@ SKGWidgetCollectionDesignerPlugin::SKGWidgetCollectionDesignerPlugin(QObject *pa
 {
         widgets.append(new SKGCalculatorEditDesignerPlugin(this));
         widgets.append(new SKGComboBoxDesignerPlugin(this));
+	widgets.append(new SKGLineEditDesignerPlugin(this));
         widgets.append(new SKGDateEditDesignerPlugin(this));
         widgets.append(new SKGGraphicsViewDesignerPlugin(this));
         widgets.append(new SKGTableViewDesignerPlugin(this));
         widgets.append(new SKGTreeViewDesignerPlugin(this));
         widgets.append(new SKGTableWithGraphDesignerPlugin(this));
+        widgets.append(new SKGTabWidgetDesignerPlugin(this));
+        widgets.append(new SKGTableWidgetDesignerPlugin(this));
 }
 
 QList<QDesignerCustomWidgetInterface*> SKGWidgetCollectionDesignerPlugin::customWidgets() const
@@ -47,5 +53,5 @@ QList<QDesignerCustomWidgetInterface*> SKGWidgetCollectionDesignerPlugin::custom
         return widgets;
 }
 
-Q_EXPORT_PLUGIN2(skroogeui, SKGWidgetCollectionDesignerPlugin)
+Q_EXPORT_PLUGIN2(skgbaseui, SKGWidgetCollectionDesignerPlugin)
 
