@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -152,14 +152,14 @@
         "CREATE TRIGGER fki_"+TABLECHILD+"_"+TABLEPARENT+"_"+ATTCHILD+"_"+ATTPARENT+" "\
         "BEFORE INSERT ON "+TABLECHILD+" "\
         "FOR EACH ROW BEGIN "\
-        "  SELECT RAISE(ABORT, '"+SKGServices::stringToSqlString(i18n("Impossible to insert object (Constraint name: %1)","fki_"+TABLECHILD+"_"+TABLEPARENT+"_"+ATTCHILD+"_"+ATTPARENT))+"') "\
+        "  SELECT RAISE(ABORT, '"+SKGServices::stringToSqlString(i18nc("Error message", "Impossible to insert object (Constraint name: %1)","fki_"+TABLECHILD+"_"+TABLEPARENT+"_"+ATTCHILD+"_"+ATTPARENT))+"') "\
         "  WHERE NEW."+ATTCHILD+"!=0 AND (SELECT "+ATTPARENT+" FROM "+TABLEPARENT+" WHERE "+ATTPARENT+" = NEW."+ATTCHILD+") IS NULL; "\
         "END;; "\
 	"DROP TRIGGER IF EXISTS fku_"+TABLECHILD+"_"+TABLEPARENT+"_"+ATTCHILD+"_"+ATTPARENT+";;" \
         "CREATE TRIGGER fku_"+TABLECHILD+"_"+TABLEPARENT+"_"+ATTCHILD+"_"+ATTPARENT+" "\
         "BEFORE UPDATE ON "+TABLECHILD+" "\
         "FOR EACH ROW BEGIN "\
-        "    SELECT RAISE(ABORT, '"+SKGServices::stringToSqlString(i18n("Impossible to update object (Constraint name: %1)","fku_"+TABLECHILD+"_"+TABLEPARENT+"_"+ATTCHILD+"_"+ATTPARENT))+"') "\
+        "    SELECT RAISE(ABORT, '"+SKGServices::stringToSqlString(i18nc("Error message", "Impossible to update object (Constraint name: %1)","fku_"+TABLECHILD+"_"+TABLEPARENT+"_"+ATTCHILD+"_"+ATTPARENT))+"') "\
         "      WHERE NEW."+ATTCHILD+"!=0 AND (SELECT "+ATTPARENT+" FROM "+TABLEPARENT+" WHERE "+ATTPARENT+" = NEW."+ATTCHILD+") IS NULL; "\
         "END;; "
 
@@ -173,7 +173,7 @@
         "CREATE TRIGGER fkd_"+TABLECHILD+"_"+TABLEPARENT+"_"+ATTCHILD+"_"+ATTPARENT+" "\
 	"BEFORE DELETE ON "+TABLEPARENT+" "\
 	"FOR EACH ROW BEGIN "\
-  	"    SELECT RAISE(ABORT, '"+SKGServices::stringToSqlString(i18n("Impossible to delete used object (Constraint name: %1)","fkd_"+TABLECHILD+"_"+TABLEPARENT+"_"+ATTCHILD+"_"+ATTPARENT))+"') "\
+  	"    SELECT RAISE(ABORT, '"+SKGServices::stringToSqlString(i18nc("Error message", "Impossible to delete used object (Constraint name: %1)","fkd_"+TABLECHILD+"_"+TABLEPARENT+"_"+ATTCHILD+"_"+ATTPARENT))+"') "\
   	"    WHERE (SELECT "+ATTCHILD+" FROM "+TABLECHILD+" WHERE "+ATTCHILD+" = OLD."+ATTPARENT+") IS NOT NULL; "\
 	"END;; "
 
