@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,7 +15,7 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
- * This file is part of Skrooge and implements classes SKGDocument.
+ * This file implements classes SKGDocument.
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -134,7 +134,7 @@ SKGError SKGDocument::stepForward(int iPosition)
                         inProgress=true;
                         if ((*(int (*)(int, void*)) progressFunction)(posPourcent, progressData)!=0) {
                                 err.setReturnCode(ERR_ABORT);
-                                err.setMessage(i18n("The current operation has been interrupted"));
+                                err.setMessage(i18nc("A message", "The current operation has been interrupted"));
 
                                 //Remove all untransactionnal message
                                 unTransactionnalMessages.clear();
@@ -167,7 +167,7 @@ SKGError SKGDocument::beginTransaction(const QString & iName, int iNbStep, const
                 //Check if the child transaction is a opened in the progress callback
                 if (inProgress) {
                         err.setReturnCode(ERR_FAIL);
-                        err.setMessage(i18n("A transaction can not be started during execution of an other one"));
+                        err.setMessage(i18nc("A message", "A transaction can not be started during execution of an other one"));
                 }
         }
         if (err.isSucceeded()) {
@@ -185,7 +185,7 @@ SKGError SKGDocument::checkExistingTransaction() const
         SKGTRACEINRC(10, "SKGDocument::checkExistingTransaction", err);
         if (getDepthTransaction() <= 0) {
                 err.setReturnCode(ERR_ABORT);
-                err.setMessage(i18n("A transaction must be opened to do this action"));
+                err.setMessage(i18nc("A message", "A transaction must be opened to do this action"));
         }
         return err;
 }
@@ -197,11 +197,14 @@ SKGError SKGDocument::endTransaction(bool succeedded)
         if (nbStepForTransaction.size()==0) {
                 //Set error message
                 err.setReturnCode(ERR_ABORT);
-                err.setMessage(i18n("Closing transaction failed because too many transactions ended"));
+                err.setMessage(i18nc("A message", "Closing transaction failed because too many transactions ended"));
         } else {
-                stepForward(100);
-                nbStepForTransaction.pop_back();
-                posStepForTransaction.pop_back();
+                stepForward(nbStepForTransaction.at(nbStepForTransaction.count()-1)); //=100%
+                QStringList listModifiedTables;
+		if (nbStepForTransaction.size()) { //This test is needed. It's a security in some cases.
+		  nbStepForTransaction.pop_back();
+		  posStepForTransaction.pop_back();
+		}
                 QString currentTransactionString=SKGServices::intToString(getCurrentTransaction());
 
                 if (nbStepForTransaction.size()==0) {
@@ -244,6 +247,15 @@ SKGError SKGDocument::endTransaction(bool succeedded)
                                                                               "AND a.t_object_table=b.t_object_table AND "
                                                                               "b.t_action=a.t_action AND b.t_sqlorder=a.t_sqlorder AND a.id>b.id );");
                                 }
+
+                                //Get current transaction information to be able to emit envent in case of SKG_UNDO_MAX_DEPTH=0
+                                if (err.isSucceeded()) {
+                                        err=SKGServices::getDistinctValues(this, "doctransactionitem",
+                                                                           "t_object_table",
+                                                                           "rd_doctransaction_id="+currentTransactionString,
+                                                                           listModifiedTables);
+                                }
+
                                 //Remove oldest transaction
                                 if (err.isSucceeded()) {
                                         QString maxdepthstring = getParameter("SKG_UNDO_MAX_DEPTH");
@@ -282,41 +294,34 @@ SKGError SKGDocument::endTransaction(bool succeedded)
                                 //For better performance, events are submitted only for the first recursive undo
                                 if (inundoRedoTransaction<=1) {
                                         //Emit modification events
-                                        QStringList listModifiedTables;
-                                        err=SKGServices::getDistinctValues(this, "doctransactionitem",
-                                                                           "t_object_table",
-                                                                           "rd_doctransaction_id="+currentTransactionString,
-                                                                           listModifiedTables);
-                                        if (err.isSucceeded()) {
-                                                QStringList tablesRefreshed;
-                                                foreach (const QString& table, listModifiedTables) {
-                                                        emit tableModified(table, getCurrentTransaction());
+                                        QStringList tablesRefreshed;
+                                        foreach (const QString& table, listModifiedTables) {
+                                                emit tableModified(table, getCurrentTransaction());
+                                                tablesRefreshed.push_back(table);
+                                        }
+                                        emit tableModified("doctransaction", getCurrentTransaction());
+                                        emit tableModified("doctransactionitem", getCurrentTransaction());
+
+                                        //WARNING: list is modified during treatement
+                                        for (int i=0; i<listModifiedTables.count(); ++i) {
+                                                QString table=listModifiedTables[i];
+                                                if (!tablesRefreshed.contains(table)) {
+                                                        emit tableModified(table, 0);
                                                         tablesRefreshed.push_back(table);
                                                 }
-                                                emit tableModified("doctransaction", getCurrentTransaction());
-                                                emit tableModified("doctransactionitem", getCurrentTransaction());
 
-                                                //WARNING: list is modified during treatement
-                                                for (int i=0; i<listModifiedTables.count(); ++i) {
-                                                        QString table=listModifiedTables[i];
-                                                        if (!tablesRefreshed.contains(table)) {
-                                                                emit tableModified(table, 0);
-                                                                tablesRefreshed.push_back(table);
-                                                        }
-
-                                                        QStringList toAdd=getImpactedTable(table);
-                                                        int nbToAdd=toAdd.count();
-                                                        for (int j=0; j<nbToAdd; ++j) {
-                                                                if (!listModifiedTables.contains(toAdd.at(j)))
-                                                                        listModifiedTables.push_back(toAdd.at(j));
-                                                        }
+                                                QStringList toAdd=getImpactedTable(table);
+                                                int nbToAdd=toAdd.count();
+                                                for (int j=0; j<nbToAdd; ++j) {
+                                                        if (!listModifiedTables.contains(toAdd.at(j)))
+                                                                listModifiedTables.push_back(toAdd.at(j));
                                                 }
-
-                                                emit transactionSuccessfullyEnded(getCurrentTransaction());
-
-                                                //Remove temporary transaction if needed
-                                                err = SKGServices::executeSqliteOrder(this, "delete from doctransaction where id="+currentTransactionString+" and t_name='#INTERNAL#';");
                                         }
+
+                                        emit transactionSuccessfullyEnded(getCurrentTransaction());
+
+                                        //Remove temporary transaction if needed
+                                        err = SKGServices::executeSqliteOrder(this, "delete from doctransaction where id="+currentTransactionString+" and t_name='#INTERNAL#';");
                                 }
                         }
 
@@ -415,7 +420,7 @@ SKGError SKGDocument::groupTransactions(int iFrom, int iTo)
         if (err.isSucceeded()) {
                 //A transaction is still opened
                 err.setReturnCode(ERR_ABORT);
-                err.setMessage(i18n("Creation of a group of transactions is forbidden inside a transaction"));
+                err.setMessage(i18nc("A message", "Creation of a group of transactions is forbidden inside a transaction"));
 
         } else {
                 int iidMaster=qMax(iFrom, iTo);
@@ -489,7 +494,7 @@ SKGError SKGDocument::undoRedoTransaction(const UndoRedoMode& iMode)
         if (err.isSucceeded()) {
                 //A transaction is still opened
                 err.setReturnCode(ERR_ABORT);
-                err.setMessage(i18n("Undo / Redo is forbidden inside a transaction"));
+                err.setMessage(i18nc("A message", "Undo / Redo is forbidden inside a transaction"));
 
         } else {
                 if (iMode==SKGDocument::UNDOLASTSAVE) {
@@ -585,7 +590,7 @@ SKGError SKGDocument::undoRedoTransaction(const UndoRedoMode& iMode)
                                                                                  SKGServices::intToString(getCurrentTransaction()),
                                                                                  listSqlOrder);
                                                                  if (err.isSucceeded() && SKGServices::stringToInt(listSqlOrder.at(1).at(0))!=nb-1) {
-                                                                         err=SKGError(ERR_ABORT, i18n("Invalid number of item after undo/redo. Expected (%1) != Result (%2)",nb-1,listSqlOrder.at(1).at(0)));
+                                                                         err=SKGError(ERR_ABORT, i18nc("Error message", "Invalid number of item after undo/redo. Expected (%1) != Result (%2)",nb-1,listSqlOrder.at(1).at(0)));
                                                                  }
                                                          }*/
 
@@ -661,9 +666,9 @@ SKGError SKGDocument::changePassword(const QString & newPassword)
         err = setParameter("SKG_PASSWORD", newPassword);
         if (err.isSucceeded()) {
                 if (newPassword.isEmpty()) {
-                        err=sendMessage(i18n("The document password has been removed."));
+                        err=sendMessage(i18nc("An information message", "The document password has been removed."));
                 } else {
-                        err=sendMessage(i18n("The document password has been modified."));
+                        err=sendMessage(i18nc("An information message", "The document password has been modified."));
                 }
         }
         return err;
@@ -713,7 +718,7 @@ SKGError SKGDocument::load(const QString & name, const QString & password, bool
                 if (name.length() && !inputFile.exists()) {
                         //Set error message
                         err.setReturnCode(ERR_INVALIDARG);
-                        err.setMessage(i18n("File [%1] not found",name));
+                        err.setMessage(i18nc("A message", "File [%1] not found",name));
                 } else {
                         // open your memory database
                         if (dbMode==CopiedInMemory) {
@@ -784,7 +789,7 @@ SKGError SKGDocument::load(const QString & name, const QString & password, bool
                                 } else {
                                         if (dbMode==DirectAccess || dbMode==CopiedInFile) {
                                                 //Copy in temporary file
-                                                temporaryFile=QDir::tempPath()+"/skrooge_"+QUuid::createUuid ().toString()+".skg";
+                                                temporaryFile=QDir::tempPath()+"/skg_"+QUuid::createUuid ().toString()+".skg";
                                                 currentDatabase=new QSqlDatabase(QSqlDatabase::addDatabase("QSQLITE", databaseIdentifier));
                                                 currentDatabase->setDatabaseName(temporaryFile);
                                                 if (!currentDatabase->open()) {
@@ -865,7 +870,7 @@ SKGError SKGDocument::load(const QString & name, const QString & password, bool
         if (err.isSucceeded()) {
                 bool mig=false;
                 err = migrate(mig);
-                if (err.isSucceeded() && mig && !name.isEmpty()) err=sendMessage(i18n("The document has been migrated"));
+                if (err.isSucceeded() && mig && !name.isEmpty()) err=sendMessage(i18nc("An information message", "The document has been migrated"));
         }
 
         //Optimization
@@ -914,7 +919,7 @@ SKGError SKGDocument::save()
         SKGError err;
         SKGTRACEINRC(5, "SKGDocument::save", err);
         if (currentFileName.length() == 0) {
-                err = SKGError(ERR_INVALIDARG, i18n("Save not authorized because the file name is not yet defined"));
+                err = SKGError(ERR_INVALIDARG, i18nc("Error message", "Save not authorized because the file name is not yet defined"));
         } else {
                 //save
                 err = saveAs(currentFileName, true);
@@ -933,7 +938,7 @@ SKGError SKGDocument::saveAs(const QString & name, bool overwrite)
         if (err.isSucceeded()) {
                 //A transaction is still opened
                 err.setReturnCode(ERR_ABORT);
-                err.setMessage(i18n("Save is forbidden if a transaction is still opened"));
+                err.setMessage(i18nc("A message", "Save is forbidden if a transaction is still opened"));
 
         } else {
                 err=SKGError();
@@ -961,7 +966,7 @@ SKGError SKGDocument::saveAs(const QString & name, bool overwrite)
                                 if (!overwrite && QFile(name).exists()) {
                                         //Set error message
                                         err.setReturnCode(ERR_INVALIDARG);
-                                        err.setMessage(i18n("File [%1] already exist",name));
+                                        err.setMessage(i18nc("A message", "File [%1] already exist",name));
                                 } else {
                                         //Get backup file name
                                         bool backupFileMustBeRemoved=false;
@@ -974,7 +979,7 @@ SKGError SKGDocument::saveAs(const QString & name, bool overwrite)
                                         //Create backup file
                                         QFile::remove(backupFileName);
                                         if (QFile(name).exists() && !QFile(name).copy(backupFileName)) {
-                                                err = SKGError(ERR_FAIL, i18n("Creation of backup file %1 failed",backupFileName));
+                                                err = SKGError(ERR_FAIL, i18nc("Error message", "Creation of backup file %1 failed",backupFileName));
                                         }
 
                                         //Open database
@@ -986,7 +991,7 @@ SKGError SKGDocument::saveAs(const QString & name, bool overwrite)
                                                                 if (QFile(name).exists()) {
                                                                         //Set error message
                                                                         err.setReturnCode(ERR_FAIL);
-                                                                        err.setMessage(i18n("Impossible to remove [%1]",name));
+                                                                        err.setMessage(i18nc("A message", "Impossible to remove [%1]",name));
                                                                 } else {
                                                                         //Copy memory in file
                                                                         QSqlDatabase dbfile = QSqlDatabase::addDatabase("QSQLITE", "TEMPORARY_SAVE");
@@ -1029,7 +1034,7 @@ SKGError SKGDocument::saveAs(const QString & name, bool overwrite)
 
                                                         //Copy file to file
                                                         if (!QFile::copy(temporaryFile, name)) {
-                                                                err = SKGError(ERR_FAIL, i18n("copy of %1 to %2 failed",temporaryFile,name));
+                                                                err = SKGError(ERR_FAIL, i18nc("Error message", "copy of %1 to %2 failed",temporaryFile,name));
                                                         } else {
                                                                 err=close();
                                                                 if (err.isSucceeded()) err=load(name);
@@ -1126,7 +1131,7 @@ SKGError SKGDocument::refreshViewsIndexesAndTriggers() const
                 "WHERE id=new.id;"
                 "END;;"
 
-                //-- Foreign Key Preventing insert + Skrooge modification
+                //-- Foreign Key Preventing insert
                 /*   "
                 CREATE TRIGGER fki_node_parent_id_node_id "
                 "BEFORE INSERT ON [node] "
@@ -1136,7 +1141,7 @@ SKGError SKGDocument::refreshViewsIndexesAndTriggers() const
                 "
                 END;; "
 
-                //-- Foreign key preventing update + Skrooge modification
+                //-- Foreign key preventing update
                 "
                 CREATE TRIGGER fku_node_parent_id_node_id "
                 "BEFORE UPDATE ON [node] "
@@ -1148,7 +1153,7 @@ SKGError SKGDocument::refreshViewsIndexesAndTriggers() const
                 */ //TODO
 
 
-                //-- Cascading delete - WARNING rewriten for skrooge to support recursive mode
+                //-- Cascading delete - WARNING rewriten to support recursive mode
                 "DROP TRIGGER IF EXISTS fkdc_node_parent_id_node_id;;"
                 "CREATE TRIGGER fkdc_node_parent_id_node_id "
                 "BEFORE DELETE ON node "
@@ -1324,7 +1329,7 @@ SKGError SKGDocument::migrate(bool& oMigrationDone)
                 SKGTRACEL(10) << "Migration from 0.3 to 0.4" <<endl;
 
                 err = SKGServices::executeSqliteOrder(this, "ALTER TABLE node ADD COLUMN t_autostart VARCHAR(1) DEFAULT 'N' CHECK (t_autostart IN ('Y', 'N'))");
-                if (err.isSucceeded()) err=SKGServices::executeSqliteOrder (this, "UPDATE node set t_autostart='Y' where t_name='"+i18nc("Verb, automatically load when skrooge is started","autostart")+'\'');
+                if (err.isSucceeded()) err=SKGServices::executeSqliteOrder (this, "UPDATE node set t_autostart='Y' where t_name='"+i18nc("Verb, automatically load when the application is started","autostart")+'\'');
 
                 //Set new version
                 version="0.4";
@@ -1384,7 +1389,7 @@ SKGError SKGDocument::migrate(bool& oMigrationDone)
         if (err.isSucceeded() && listTmp.count()==2) err = setParameter("SKG_SQLITE_LAST_VERSION", listTmp.at(1).at(0));
 
 
-        if (err.isFailed()) err.addError(ERR_FAIL, i18n("Database migration from version %1 to version %2 failed",initialversion,version));
+        if (err.isFailed()) err.addError(ERR_FAIL, i18nc("Error message", "Database migration from version %1 to version %2 failed",initialversion,version));
 
         //close temporary transaction
         if (err.isSucceeded()) err=endTransaction(true);
@@ -1609,7 +1614,8 @@ SKGError SKGDocument::getConsolidatedView(const QString& iTable,
                 const QString& iAttribute,
                 const QString& iOpAtt,
                 const QString& iWhereClause,
-                SKGStringListList& oTable) const
+                SKGStringListList& oTable,
+		const QString& iMissingValue) const
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGDocument::getConsolidatedView", err);
@@ -1619,6 +1625,7 @@ SKGError SKGDocument::getConsolidatedView(const QString& iTable,
         SKGTRACEL(10) << "Input parameter [iAttribute]=[" << iAttribute << ']' << endl;
         SKGTRACEL(10) << "Input parameter [iOpAtt]=[" << iOpAtt << ']' << endl;
         SKGTRACEL(10) << "Input parameter [iWhereClause]=[" << iWhereClause << ']' << endl;
+        SKGTRACEL(10) << "Input parameter [iMissingValue]=[" << iMissingValue << ']' << endl;
 
         //Mode
         int mode=0;
@@ -1681,7 +1688,7 @@ SKGError SKGDocument::getConsolidatedView(const QString& iTable,
                                         r.push_back(rowname);
                                         int nbx=oTable[0].count();
                                         for (int j=1; j<nbx; ++j)
-                                                r.push_back("0");
+                                                r.push_back(iMissingValue);
 
                                         oTable.push_back(r);
 
@@ -1709,7 +1716,7 @@ SKGError SKGDocument::getConsolidatedView(const QString& iTable,
                                         int nbx=oTable.count();
                                         for (int j=0; j<nbx; ++j) {
                                                 if (j==0) oTable[j].insert(colindex,colname);
-                                                else oTable[j].insert(colindex, "0");
+                                                else oTable[j].insert(colindex, iMissingValue);
                                         }
 
                                         {
@@ -1732,37 +1739,78 @@ SKGError SKGDocument::getConsolidatedView(const QString& iTable,
                         oTable[rowindex][colindex]=sum;
                 }
 
-
-
                 //Correction bug 205466 vvv
                 //If some months or years are missing, we must add them.
-                if (iAsColumn=="d_DATEMONTH" || iAsColumn=="d_DATEYEAR") {
+                if (iAsColumn.startsWith(QLatin1String("d_"))) {
+		        SKGTRACEINRC(10, "SKGDocument::getConsolidatedView-date treatement", err);
                         for (int c=1; c<oTable[0].count()-1; ++c) { //Dynamic size
-                                QString dateFormat=(iAsColumn=="d_DATEMONTH" ? "yyyy-MM" : "yyyy");
-                                QDate nextExpected=QDate::fromString(oTable.at(0).at(c), dateFormat);
-                                if (iAsColumn=="d_DATEMONTH") nextExpected=nextExpected.addMonths(1);
-                                else nextExpected=nextExpected.addYears(1);
-                                if (oTable.at(0).at(c+1)!=nextExpected.toString (dateFormat)) {
+				bool forecast=false;
+				QString title=oTable.at(0).at(c);
+				if(title.endsWith(QLatin1String("999")))
+				{
+				  title=title.left(title.count()-3);
+				  forecast=true;
+				}
+				QString nextTitle=oTable.at(0).at(c+1);
+				if(nextTitle.endsWith(QLatin1String("999")))
+				{
+				  nextTitle=nextTitle.left(nextTitle.count()-3);
+				  forecast=true;
+				}
+
+                                QString dateFormat=(iAsColumn=="d_date" ? "yyyy-MM-dd" : (iAsColumn=="d_DATEMONTH" ? "yyyy-MM" : (iAsColumn=="d_DATEQUARTER" ? "yyyy-QM" : (iAsColumn=="d_DATESEMESTER" ? "yyyy-SM" : (iAsColumn=="d_DATEWEEK" ? "yyyy-WM" : "yyyy")))));
+                                QDate nextExpected=QDate::fromString(title, dateFormat);
+				QString nextExpectedString;
+                                if (iAsColumn=="d_DATEWEEK")
+				{
+/* TODO
+				  QStringList items=SKGServices::splitCSVLine(oTable.at(0).at(c),'-');
+				  nextExpected=QDate(SKGServices::stringToInt(items.at(0)), 1, 1);
+				  QString w=items.at(1);
+				  w.remove('W');
+				  nextExpected=nextExpected.addDays(7*SKGServices::stringToInt(w));
+				  QString newW=SKGServices::intToString(nextExpected.weekNumber());
+				  if(newW.count()==1) newW='0'+newW;
+				  */
+				  nextExpectedString=nextTitle;
+				}
+                                else if (iAsColumn=="d_DATEMONTH")
+				{
+				  nextExpected=nextExpected.addMonths(1);
+				  nextExpectedString=nextExpected.toString (dateFormat);
+				}
+				else if (iAsColumn=="d_DATEQUARTER")
+				{
+				  nextExpected=nextExpected.addMonths(nextExpected.month()*3-nextExpected.month()); //convert quater in month
+				  nextExpected=nextExpected.addMonths(3);
+				  nextExpectedString=nextExpected.toString ("yyyy-Q")+(nextExpected.month()<=3 ? '1': (nextExpected.month()<=6 ? '2': (nextExpected.month()<=9 ? '3': '4')));
+				}
+                                else if (iAsColumn=="d_DATESEMESTER")
+				{
+				  nextExpected=nextExpected.addMonths(nextExpected.month()*6-nextExpected.month()); //convert semester in month
+				  nextExpected=nextExpected.addMonths(6);
+				  nextExpectedString=nextExpected.toString ("yyyy-S")+(nextExpected.month()<=6 ? '1' : '2');
+				}
+                                else if (iAsColumn=="d_DATEYEAR")
+				{
+				  nextExpected=nextExpected.addYears(1);
+				  nextExpectedString=nextExpected.toString (dateFormat);
+				}
+				else
+				{
+				  nextExpected=nextExpected.addDays(1);
+				  nextExpectedString=nextExpected.toString (dateFormat);
+				}
+
+                                if (title!="0000" && nextTitle!=nextExpectedString && nextTitle!=title) {
                                         int colindex=c+1;
-                                        QString colname=nextExpected.toString (dateFormat);
+					if(forecast) nextExpectedString+="999";
 
                                         int nbx=oTable.count();
-                                        for (int j=0; j<nbx; ++j) {
-                                                if (j==0) oTable[j].insert(colindex,colname);
-                                                else oTable[j].insert(colindex, "0");
+					oTable[0].insert(colindex, nextExpectedString);
+                                        for (int j=1; j<nbx; ++j) {
+                                                oTable[j].insert(colindex, iMissingValue);
                                         }
-
-                                        {
-                                                QHash<QString, int> tmp;
-                                                QHashIterator<QString, int> cols_i(cols);
-                                                while (cols_i.hasNext()) {
-                                                        cols_i.next();
-                                                        tmp.insert(cols_i.key(), cols_i.value()+(cols_i.value()>=colindex ? 1 : 0));
-                                                }
-
-                                                cols=tmp;
-                                        }
-                                        cols.insert(colname,colindex);
                                 }
                         }
                 }
@@ -1772,6 +1820,44 @@ SKGError SKGDocument::getConsolidatedView(const QString& iTable,
         return err;
 }
 
+QList<SKGDocument::SKGModelTemplate> SKGDocument::getDisplaySchemas(const QString& iRealTable) const
+{
+        QList<SKGDocument::SKGModelTemplate> listSchema;
+
+        //Build schemas
+        if (iRealTable=="doctransaction") {
+                SKGModelTemplate def;
+                def.id="default";
+                def.name=i18nc("Noun, the default value of an item","Default");
+                def.icon="edit-undo";
+                def.schema="t_name;t_value;d_lastmodifdate;t_savestep";
+                listSchema.push_back(def);
+
+                SKGModelTemplate minimum;
+                minimum.id="minimum";
+                minimum.name=i18nc("Noun, the minimum value of an item","Minimum");
+                minimum.icon="";
+                minimum.schema="t_name;t_value;d_lastmodifdate|N;t_savestep|N";
+                listSchema.push_back(minimum);
+        } else if (iRealTable=="parameters") {
+                SKGModelTemplate def;
+                def.id="default";
+                def.name=i18nc("Noun, the default value of an item","Default");
+                def.icon="edit-undo";
+                def.schema="t_name;t_value";
+                listSchema.push_back(def);
+        } else if (iRealTable=="node") {
+                SKGModelTemplate def;
+                def.id="default";
+                def.name=i18nc("Noun, the default value of an item","Default");
+                def.icon="edit-undo";
+                def.schema="t_name";
+                listSchema.push_back(def);
+        }
+
+        return listSchema;
+}
+
 QString SKGDocument::getDisplay(const QString& iString) const
 {
         QString output=iString.toLower();
@@ -1780,7 +1866,7 @@ QString SKGDocument::getDisplay(const QString& iString) const
         else if (output.endsWith(QLatin1String("d_date"))) output=i18nc("Noun, the date of an item","Date");
         else if (output.endsWith(QLatin1String("t_savestep"))) output=i18nc("Verb, save a document","Save");
         else if (output.endsWith(QLatin1String("t_value"))) output=i18nc("Noun, the value of an item","Value");
-        else if (output.endsWith(QLatin1String("d_lastmodifdate"))) output=i18n("Last modification");
+        else if (output.endsWith(QLatin1String("d_lastmodifdate"))) output=i18nc("Noun, date of last modification", "Last modification");
         else output=iString;
         return output;
 }
@@ -1791,9 +1877,9 @@ QIcon SKGDocument::getIcon(const QString& iString) const
         return QIcon();
 }
 
-SKGServices::AttibuteType SKGDocument::getAttibuteType(const QString& iAttributeName) const
+SKGServices::AttributeType SKGDocument::getAttributeType(const QString& iAttributeName) const
 {
-        SKGServices::AttibuteType output=SKGServices::TEXT;
+        SKGServices::AttributeType output=SKGServices::TEXT;
         if (iAttributeName.startsWith(QLatin1String("d_"))) output= SKGServices::DATE;
         else if (iAttributeName.startsWith(QLatin1String("i_"))) output= SKGServices::INTEGER;
         else if (iAttributeName.startsWith(QLatin1String("rd_")) || iAttributeName.startsWith(QLatin1String("rc_")) || iAttributeName.startsWith(QLatin1String("r_"))) output= SKGServices::LINK;
