@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -17,7 +17,7 @@
 #ifndef SKGDOCUMENT_H
 #define SKGDOCUMENT_H
 /** @file
- * This file is part of Skrooge and defines classes SKGDocument.
+ * This file defines classes SKGDocument.
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -40,11 +40,22 @@ class SKGError;
 class SKGBASEMODELER_EXPORT SKGDocument : public QObject
 {
         Q_OBJECT;
+        /**
+         * This enumerate defines a type of modification
+         */
+        Q_ENUMS(ModificationType);
+        /**
+         * This enumerate defines the direction of the UNDO / REDO mechanism
+         */
         Q_ENUMS(UndoRedoMode);
+        /**
+         * This enumerate defines the mode of file
+         */
+        Q_ENUMS(DatabaseMode);
 
 public:
         /**
-         * This structure defines a type of modification
+         * This enumerate defines a type of modification
          */
         enum ModificationType {
                 U, /**< Update */
@@ -62,13 +73,28 @@ public:
                 ModificationType type; 			/**< The type of modification */
         } ;
 
+        /**
+         * This structure represents a template to display data
+         */
+        typedef struct {
+                /** Identifier of the schema */
+                QString id;
+                /** The nls name */
+                QString name;
+                /** The icon */
+                QString icon;
+                /** The schema.
+                * The format of this string is the following one: attribute name[|visibility Y or N[|size]];attribute name[|visibility Y or N[|size]];... */
+                QString schema;
+        } SKGModelTemplate;
+
         /**
          * A list of SKGObjectModification ==> SKGObjectModificationList
          */
         typedef QList<SKGObjectModification> SKGObjectModificationList;
 
         /**
-         * This structure defines the direction of the UNDO / REDO mechanism
+         * This enumerate defines the direction of the UNDO / REDO mechanism
          */
         enum UndoRedoMode {
                 UNDOLASTSAVE, 	/**< To do/get an undo=cancel of the last successfully extecuted transactions until last save */
@@ -77,7 +103,7 @@ public:
         };
 
         /**
-         * This structure defines the direction of the UNDO / REDO mechanism
+         * This enumerate defines the mode of file
          */
         enum DatabaseMode {
                 CopiedInMemory, 	/**< The sqlite database is copied in memory (Very good for select, Not good for load ans Save) */
@@ -379,6 +405,7 @@ public:
          * @param iOpAtt Operation to apply on @p iAttribute
          * @param iWhereClause Where clause
          * @param oTable the consolidated view
+         * @param iMissingValue value to put if no value found
          * @return an object managing the error.
          *   @see SKGError
          */
@@ -388,7 +415,8 @@ public:
                                              const QString& iAttribute,
                                              const QString& iOpAtt,
                                              const QString& iWhereClause,
-                                             SKGStringListList& oTable) const;
+                                             SKGStringListList& oTable,
+					     const QString& iMissingValue="0") const;
 
         /**
          * Refresh all views and indexes in the database
@@ -404,6 +432,13 @@ public:
          */
         virtual QString getDisplay(const QString& iString) const;
 
+        /**
+         * Get display schemas
+         * @param iRealTable the real table name
+         * @return list of schemas
+         */
+        virtual QList<SKGDocument::SKGModelTemplate> getDisplaySchemas(const QString& iRealTable) const;
+
         /**
          * Get the icon for attribute
          * @param iString the name of the attribute
@@ -416,7 +451,7 @@ public:
          * @param iAttributeName the name of an attribute
          * @return the type
          */
-        virtual SKGServices::AttibuteType getAttibuteType(const QString& iAttributeName) const;
+        virtual SKGServices::AttributeType getAttributeType(const QString& iAttributeName) const;
 
         /**
          * Add a value in the cache. Cache is cleaned after each transaction
