@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,7 +15,7 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
- * This file is part of Skrooge and implements classes SKGNodeObject.
+ * This file implements classes SKGNodeObject.
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -51,7 +51,7 @@ const SKGNodeObject& SKGNodeObject::operator= (const SKGObjectBase& iObject)
 SKGError SKGNodeObject::setName(const QString& iName)
 {
         SKGError err;
-	if (iName.contains(OBJECTSEPARATOR)) err=SKGError(ERR_FAIL, i18n("The name can not contain [%1]",QString(OBJECTSEPARATOR)));
+	if (iName.contains(OBJECTSEPARATOR)) err=SKGError(ERR_FAIL, i18nc("Error message", "The name can not contain [%1]",QString(OBJECTSEPARATOR)));
         else err=SKGNamedObject::setName(iName);
         return err;
 }
@@ -184,7 +184,7 @@ SKGError SKGNodeObject::addNode(SKGNodeObject& oNode)
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGNodeObject::addNode", err);
-        if (getID() == 0) err=SKGError(ERR_FAIL, i18n("%1 failed because linked object is not yet saved in the database.",QString("SKGNodeObject::addNode")));
+        if (getID() == 0) err=SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.",QString("SKGNodeObject::addNode")));
         else {
                 oNode = SKGNodeObject((SKGDocument*) getDocument());
                 err = oNode.setAttribute("r_node_id", SKGServices::intToString(getID()));
@@ -201,13 +201,13 @@ SKGError SKGNodeObject::setParentNode(const SKGNodeObject& iNode)
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGNodeObject::setParentNode", err);
-	if (iNode.getID() == 0) err=SKGError(ERR_FAIL, i18n("%1 failed because linked object is not yet saved in the database.",QString("SKGNodeObject::setParentNode")));
+	if (iNode.getID() == 0) err=SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.",QString("SKGNodeObject::setParentNode")));
         else {
                 //Check if it's a loop
                 SKGNodeObject current=iNode;
                 do {
                         if (current==*this) {
-                                err=SKGError(ERR_FAIL, i18n("You can not create a loop."));
+                                err=SKGError(ERR_FAIL, i18nc("Error message", "You cannot create a loop."));
                         } else {
                                 SKGNodeObject parent;
                                 current.getParentNode(parent);
