@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,7 +15,7 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
- * This file is part of Skrooge and defines classes SKGObjectBase.
+ * This file defines classes SKGObjectBase.
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -92,9 +92,9 @@ SKGError SKGObjectBase::getObject(const SKGDocument* iDocument, const QString& i
         SKGError err = SKGObjectBase::getObjects(iDocument, iTable, iWhereClause, temporaryResult);
         if (err.isSucceeded()) {
                 int size=temporaryResult.size();
-                if (size> 1)  err=SKGError(ERR_INVALIDARG, i18n("More than one object returned in [%1] for [%2]",iTable,iWhereClause));
+                if (size> 1)  err=SKGError(ERR_INVALIDARG, i18nc("Error message", "More than one object returned in [%1] for [%2]",iTable,iWhereClause));
                 else {
-                        if (size==0)  err=SKGError(ERR_INVALIDARG, i18n("No object returned in [%1] for [%2]",iTable,iWhereClause));
+                        if (size==0)  err=SKGError(ERR_INVALIDARG, i18nc("Error message", "No object returned in [%1] for [%2]",iTable,iWhereClause));
                         else  oObject = *(temporaryResult.begin());
                 }
         }
@@ -285,9 +285,11 @@ SKGError SKGObjectBase::load()
         if (err.isSucceeded()) {
                 int size=result.size();
                 if ( size== 1) {
-                        err = SKGError(ERR_INVALIDARG, i18n("Load of [%1] with [%2] failed because it was not found in the database",table,wc));
+                        err = SKGError(ERR_INVALIDARG, i18nc("Error message", "Load of [%1] with [%2] failed because it was not found in the database",table,wc));
                 } else if (size != 2) {
-                        err = SKGError(ERR_INVALIDARG, i18n("Load of [%1] with [%2] failed because of bad size of result (found %3 object(s))",table,wc,size-1));
+                        err = SKGError(ERR_INVALIDARG, i18np("Load of [%2] with [%3] failed because of bad size of result (found one object)",
+                                                             "Load of [%2] with [%3] failed because of bad size of result (found %1 objects)",
+                                                             size-1,table,wc));
                 } else {
                         SKGStringListListIterator itrow = result.begin();
                         QStringList columns = *(itrow);
@@ -312,7 +314,7 @@ SKGError SKGObjectBase::save(bool iInsertOrUpdate, bool iReloadAfterSave)
         SKGError err;
         SKGTRACEINRC(20, "SKGObjectBase::save", err);
 
-        if (!document) err=SKGError(ERR_POINTER, i18n("Operation impossible because the document is missing"));
+        if (!document) err=SKGError(ERR_POINTER, i18nc("Error message", "Operation impossible because the document is missing"));
         else {
                 //Check if we are in a transaction
                 err = document->checkExistingTransaction();
@@ -380,7 +382,7 @@ SKGError SKGObjectBase::remove(bool iSendMessage) const
 {
         SKGError err;
         SKGTRACEINRC(20, "SKGObjectBase::remove", err);
-        if (!document) err=SKGError(ERR_POINTER, i18n("Operation impossible because the document is missing"));
+        if (!document) err=SKGError(ERR_POINTER, i18nc("Error message", "Operation impossible because the document is missing"));
         else {
                 //Check if we are in a transaction
                 err = document->checkExistingTransaction();
@@ -396,14 +398,14 @@ SKGError SKGObjectBase::remove(bool iSendMessage) const
                         int nb=0;
                         SKGObjectBase::getNbObjects(document, viewForDelete,"id="+SKGServices::intToString(id), nb);
                         if (nb!=1) {
-                                err=SKGError(ERR_FAIL, i18n("You are not authorized to delete this object"));
+                                err=SKGError(ERR_FAIL, i18nc("Error message", "You are not authorized to delete this object [%1]", getDisplayName()));
                         }
                 }
 
                 QString displayname=getDisplayName(); //Must be done before the delete order
                 if (err.isSucceeded()) err=SKGServices::executeSqliteOrder(document, "DELETE FROM "+getRealTable()+" WHERE id="+SKGServices::intToString(id));
                 if (iSendMessage && err.isSucceeded() && !displayname.isEmpty())
-                        err=((SKGDocument*) document)->sendMessage(i18n("[%1] has been deleted",displayname), false);
+                        err=((SKGDocument*) document)->sendMessage(i18nc("An information message", "[%1] has been deleted",displayname), false);
         }
 
         return err;
