@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,7 +15,7 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
-* This file is part of Skrooge and implements classes SKGServices.
+* This file implements classes SKGServices.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -24,6 +24,7 @@
 #include "skgdocument.h"
 
 #include <klocale.h>
+#include <kglobal.h>
 
 #include <sys/time.h>
 
@@ -125,19 +126,23 @@ QString SKGServices::stringToCsv(const QString& iNumber)
 double SKGServices::stringToDouble(const QString& iNumber)
 {
         if (iNumber.isEmpty()) return 0;
+	QString number=iNumber;
+	number.remove(' '); //To be able to convert something like "2 150,10"
 
         bool ok;
-        double output=iNumber.toDouble(&ok);
+        double output=number.toDouble(&ok);
         if (!ok) {
-                QString tmp=iNumber;
+                QString tmp=number;
                 tmp.replace(',', '.');
+		if(tmp.count('.')>1) tmp.remove(tmp.indexOf('.'), 1);
                 output=tmp.toDouble(&ok);
                 if (!ok) {
-                        QString tmp=iNumber;
+                        QString tmp=number;
                         tmp.replace('.', ',');
+			if(tmp.count(',')>1) tmp.remove(tmp.indexOf(','), 1);
                         output=tmp.toDouble(&ok);
                         if (!ok) {
-                                QString tmp=iNumber;
+                                QString tmp=number;
                                 tmp.remove(',');
                                 output=tmp.toDouble(&ok);
                         }
@@ -223,6 +228,8 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
         SKGTRACEIN(2, "SKGServices::getDateFormat");
         bool f_YYYY_MM_DD=true;
         bool f_YYYYMMDD=true;
+        bool f_DDMMYYYY=true;
+        bool f_MMDDYYYY=true;
         bool f_MM_DD_YY=true;
         bool f_DD_MM_YY=true;
         bool f_MM_DD_YYYY=true;
@@ -242,15 +249,44 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
                 val=val.replace('\'',"-20");
                 val=val.replace('.','-');
                 if (rx.indexIn(val)==-1) {
-                        f_YYYY_MM_DD=true;
-                        f_MM_DD_YY=true;
-                        f_DD_MM_YY=true;
-                        f_MM_DD_YYYY=true;
-                        f_DD_MM_YYYY=true;
+                        f_YYYY_MM_DD=false;
+                        f_MM_DD_YY=false;
+                        f_DD_MM_YY=false;
+                        f_MM_DD_YYYY=false;
+                        f_DD_MM_YYYY=false;
 
-                        if (f_YYYYMMDD && val.length()!=8) f_YYYYMMDD=false;
+			if(val.length()==8)
+			{
+			  int left2=SKGServices::stringToInt(val.left(2));
+			  if (left2>12) {
+			    f_MMDDYYYY=false;
+			  }
+			  if (left2>31) {
+			    f_DDMMYYYY=false;
+			  }
+
+			  int mid2=SKGServices::stringToInt(val.mid(2, 2));
+			  if (mid2>12) {
+			    f_DDMMYYYY=false;
+			  }
+			  if (mid2>31) {
+			    f_MMDDYYYY=false;
+			  }
+
+			  int mid4=SKGServices::stringToInt(val.mid(4, 2));
+			  if (mid4>12) {
+			    f_YYYYMMDD=false;
+			  }
+
+			  int right2=SKGServices::stringToInt(val.right(2));
+			  if (right2>31) {
+			    f_YYYYMMDD=false;
+			  }
+			}
                 } else {
                         f_YYYYMMDD=false;
+                        f_DDMMYYYY=false;
+                        f_MMDDYYYY=false;
 
                         QString v1=rx.cap(1);
                         QString v2=rx.cap(2);
@@ -298,11 +334,33 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
         }
 
         if (f_YYYYMMDD) return "YYYYMMDD";
-        else if (f_YYYY_MM_DD) return "YYYY-MM-DD";
+        else if (f_DDMMYYYY) return "DDMMYYYY";
+        else if (f_MMDDYYYY) return "MMDDYYYY";
+        else if (f_DD_MM_YY && f_MM_DD_YY)
+	{
+	    KLocale* locale=KGlobal::locale();
+	    if(locale)
+	    {
+	      QString sFormat=locale->dateFormatShort ();
+	      if(sFormat.startsWith(QLatin1String("%m")) || sFormat.startsWith(QLatin1String("%n"))) return "MM-DD-YY";
+	    }
+	    return "DD-MM-YY";
+	}
         else if (f_DD_MM_YY) return "DD-MM-YY";
         else if (f_MM_DD_YY) return "MM-DD-YY";
-        else if (f_MM_DD_YYYY) return "MM-DD-YYYY";
+        else if (f_DD_MM_YYYY && f_MM_DD_YYYY)
+	{
+	    KLocale* locale=KGlobal::locale();
+	    if(locale)
+	    {
+	      QString sFormat=locale->dateFormatShort ();
+	      if(sFormat.startsWith(QLatin1String("%m")) || sFormat.startsWith(QLatin1String("%n"))) return "MM-DD-YYYY";
+	    }
+	    return "DD-MM-YYYY";
+	}
         else if (f_DD_MM_YYYY) return "DD-MM-YYYY";
+        else if (f_MM_DD_YYYY) return "MM-DD-YYYY";
+        else if (f_YYYY_MM_DD) return "YYYY-MM-DD";
 
         return "";
 }
@@ -319,6 +377,16 @@ QString SKGServices::dateToSqlString(const QString& iDate, const QString& iForma
                 MM=input.mid(4,2);
                 DD=input.mid(6,2);
 
+        } if (iFormat=="DDMMYYYY") {
+                YYYY=input.mid(4,4);
+                MM=input.mid(2,2);
+                DD=input.mid(0,2);
+
+        } if (iFormat=="MMDDYYYY") {
+                YYYY=input.mid(4,4);
+                MM=input.mid(0,2);
+                DD=input.mid(2,2);
+
         } else {
                 QString val=iDate;
                 val=val.replace('/','-');
@@ -446,7 +514,7 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
         SKGTRACEL(10) << "Input parameter [iFileTarget]=[" << iFileTarget << ']' << endl;
         if (iPassword.isEmpty()) {
                 if (!QFile::copy(iFileSource, iFileTarget)) {
-                        err = SKGError(ERR_FAIL, i18n("copy of %1 to %2 failed",iFileSource,iFileTarget));
+                        err = SKGError(ERR_FAIL, i18nc("Error message", "copy of %1 to %2 failed",iFileSource,iFileTarget));
                 }
         } else {
                 QCA::Initializer init;
@@ -467,7 +535,7 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
                                    iEncrypt ? QCA::Encode : QCA::Decode,
                                    key, iv);
                 QFile fileInput(iFileSource);
-                if (!fileInput.open(QIODevice::ReadOnly)) err=SKGError(ERR_INVALIDARG, i18n("Open file [%1] failed",iFileSource));
+                if (!fileInput.open(QIODevice::ReadOnly)) err=SKGError(ERR_INVALIDARG, i18nc("Error message", "Open file [%1] failed",iFileSource));
                 else {
                         QByteArray input = fileInput.readAll();
 
@@ -478,12 +546,12 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
                         QCA::SecureArray u = cipher.update(input);
 
                         // We need to check if that update() call worked.
-                        if (!cipher.ok()) err=SKGError(ERR_FAIL, i18n("Encryption failed"));
+                        if (!cipher.ok()) err=SKGError(ERR_FAIL, i18nc("Error message", "Encryption failed"));
 
                         // output the results of that stage
                         if (err.isSucceeded()) {
                                 QFile fileOutput(iFileTarget);
-                                if (!fileOutput.open(QIODevice::WriteOnly)) err=SKGError(ERR_INVALIDARG, i18n("Write file [%1] failed",iFileTarget));
+                                if (!fileOutput.open(QIODevice::WriteOnly)) err=SKGError(ERR_INVALIDARG, i18nc("Error message", "Write file [%1] failed",iFileTarget));
                                 else {
                                         fileOutput.write(u.toByteArray());
 
@@ -492,7 +560,7 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
                                         QCA::SecureArray f = cipher.final();
 
                                         // Check if the final() call worked
-                                        if (!cipher.ok()) err=SKGError(ERR_FAIL, i18n("Encryption failed"));
+                                        if (!cipher.ok()) err=SKGError(ERR_FAIL, i18nc("Error message", "Encryption failed"));
 
                                         // and output the resulting block. The ciphertext is the results of update()
                                         // and the result of final()
@@ -563,11 +631,11 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
                                 if (err.isSucceeded() && !iFromFileToMemory && !QFile(dbFileName).exists()) {
                                         //Set error message
                                         err.setReturnCode(ERR_FAIL);
-                                        err.setMessage(i18n("Creation file [%1] failed",dbFileName));
+                                        err.setMessage(i18nc("An error message", "Creation file [%1] failed",dbFileName));
                                 }
                         }
                 }
-                if (err.isFailed()) err.addError(SQLLITEERROR + ERR_FAIL, i18n("%1 failed", QString("copySqliteDatabase::copySqliteDatabase()")));
+                if (err.isFailed()) err.addError(SQLLITEERROR + ERR_FAIL, i18nc("Error message", "%1 failed", QString("copySqliteDatabase::copySqliteDatabase()")));
         }
         return err;
 }
@@ -577,7 +645,7 @@ SKGError SKGServices::executeSqliteOrder(const SKGDocument* iDocument, const QSt
         SKGError err;
         _SKGTRACEINRC(10, "SKGServices::ExecuteSqlOrder(SKGDocument)", err);
         if (iDocument == NULL) {
-                err = SKGError(ERR_POINTER, i18n("No database defined"));
+                err = SKGError(ERR_POINTER, i18nc("Error message", "No database defined"));
         } else {
                 err = SKGServices::executeSqliteOrder(iDocument->getDatabase(), iSqlOrder, iLastId);
         }
@@ -591,7 +659,7 @@ SKGError SKGServices::executeSqliteOrder(QSqlDatabase* iDb, const QString& iSqlO
         SKGTRACEL(20) << "Input parameter [iSqlOrder]=[" << iSqlOrder << ']' << endl;
 
         if (iDb == NULL) {
-                err = SKGError(ERR_POINTER, i18n("No database defined"));
+                err = SKGError(ERR_POINTER, i18nc("Error message", "No database defined"));
         } else {
                 QStringList listSqlOrder=iSqlOrder.split(";;", QString::SkipEmptyParts);
                 int nb=listSqlOrder.size();
@@ -665,7 +733,7 @@ SKGError SKGServices::dumpSelectSqliteOrder(const SKGDocument* iDocument, const
         SKGError err;
         _SKGTRACEINRC(10, "SKGServices::dumpSelectSqliteOrder(SKGDocument)", err);
 
-        if (iDocument == NULL) err = SKGError(ERR_POINTER, i18n("No database defined"));
+        if (iDocument == NULL) err = SKGError(ERR_POINTER, i18nc("Error message", "No database defined"));
         else  err = SKGServices::dumpSelectSqliteOrder(iDocument->getDatabase(), iSqlOrder, oStream, iMode);
         return err;
 }
@@ -693,7 +761,7 @@ SKGError SKGServices::dumpSelectSqliteOrder(const SKGDocument* iDocument, const
 {
         SKGError err;
         _SKGTRACEINRC(10, "SKGServices::dumpSelectSqliteOrder(SKGDocument)", err);
-        if (iDocument == NULL) err = SKGError(ERR_POINTER, i18n("No database defined"));
+        if (iDocument == NULL) err = SKGError(ERR_POINTER, i18nc("Error message", "No database defined"));
         else  err = SKGServices::dumpSelectSqliteOrder(iDocument->getDatabase(), iSqlOrder, oResult, iMode);
         return err;
 }
@@ -714,7 +782,7 @@ SKGError SKGServices::dumpSelectSqliteOrder(const SKGDocument* iDocument, const
 {
         SKGError err;
         _SKGTRACEINRC(10, "SKGServices::dumpSelectSqliteOrder(SKGDocument)", err);
-        if (iDocument == NULL) err = SKGError(ERR_POINTER, i18n("No database defined"));
+        if (iDocument == NULL) err = SKGError(ERR_POINTER, i18nc("Error message", "No database defined"));
         else err = SKGServices::dumpSelectSqliteOrder(iDocument->getDatabase(), iSqlOrder, oResult, iMode);
         return err;
 }
@@ -726,7 +794,7 @@ SKGError SKGServices::executeSelectSqliteOrder(QSqlDatabase* iDb, const QString&
         //initialisation
         oResult.clear();
 
-        if (iDb == NULL) err = SKGError(ERR_POINTER, i18n("No database defined"));
+        if (iDb == NULL) err = SKGError(ERR_POINTER, i18nc("Error message", "No database defined"));
         else {
                 QSqlQuery query(QString(), *iDb);
                 double elapse=0;
@@ -791,7 +859,7 @@ SKGError SKGServices::executeSelectSqliteOrder(const SKGDocument* iDocument, con
         SKGError err;
         _SKGTRACEINRC(10, "SKGServices::executeSelectSqliteOrder(SKGDocument)", err);
         oResult.clear();
-        if (iDocument == NULL) err = SKGError(ERR_POINTER, i18n("No database defined"));
+        if (iDocument == NULL) err = SKGError(ERR_POINTER, i18nc("Error message", "No database defined"));
         else  err = SKGServices::executeSelectSqliteOrder(iDocument->getDatabase(), iSqlOrder, oResult);
         return err;
 }
@@ -865,7 +933,7 @@ SKGError SKGServices::getAttributesDescription(const SKGDocument* iDocument, con
                                 attribute.display="";
                         }
                         attribute.icon=iDocument->getIcon(attname);
-                        attribute.type=iDocument->getAttibuteType(attribute.name);
+                        attribute.type=iDocument->getAttributeType(attribute.name);
                         attribute.notnull=(line[3]=="0");
                         attribute.defaultvalue=line[4];
                         oResult.push_back(attribute);
@@ -891,6 +959,9 @@ SKGError SKGServices::getAttributesList(const SKGDocument* iDocument, const QStr
 
 double SKGServices::getMicroTime()
 {
+#ifdef Q_OS_WIN
+        return static_cast<double>(GetTickCount());
+#else
         struct timeval tv;
         struct timezone tz;
 
@@ -899,6 +970,7 @@ double SKGServices::getMicroTime()
 
         //return time
         return (static_cast<double>(1000.0 * tv.tv_sec)) + (static_cast<double>(tv.tv_usec / 1000));
+#endif
 }
 
 #include "skgservices.moc"
