@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -17,7 +17,7 @@
 #ifndef SKGSERVICES_H
 #define SKGSERVICES_H
 /** @file
- * This file is part of Skrooge and defines classes SKGDocument.
+ * This file defines classes SKGDocument.
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -78,20 +78,37 @@ typedef QList<int> SKGIntList;
  */
 typedef QList<int>::Iterator SKGIntListIterator;
 
-
 /**
 * This class containing various static services
 */
 class SKGBASEMODELER_EXPORT SKGServices : public QObject
 {
         Q_OBJECT;
+        /**
+         * This enumerate defines dump modes
+         */
         Q_ENUMS(DumpMode);
-
+        /**
+         * This enumerate defines attributes types
+         */
+        Q_ENUMS(AttributeType);
 public:
+        /**
+         * Unit value
+         */
+        typedef struct {
+                /** The name of the unit */
+                QString Name;
+                /** The amount of the unit */
+                double Value;
+                /** The number of decimal of the unit*/
+                int NbDecimal;
+        } SKGUnitInfo;
+
         /**
          * This structure defines attributes types
          */
-        enum AttibuteType {
+        enum AttributeType {
                 TEXT, 		/**< Text */
                 INTEGER, 	/**< Integer */
                 FLOAT, 		/**< Float */
@@ -100,7 +117,8 @@ public:
                 LINK, 		/**< Link */
                 BLOB, 		/**< Blob */
                 BOOL, 		/**< Boolean (Y, N) */
-                TRISTATE	/**< Tri-state (N, P, C) */
+                TRISTATE,	/**< Tri-state (N, P, C) */
+                OTHER	        /**< Other or undefined */
         };
 
         /**
@@ -110,7 +128,7 @@ public:
                 QString name; 			/**< The internal name of the attribute */
                 QString display; 		/**< The name for display of the attribute */
                 QIcon icon; 		        /**< The icon for display of the attribute */
-                AttibuteType type; 		/**< The type of the attribute */
+                AttributeType type; 		/**< The type of the attribute */
                 bool notnull; 			/**< To know if the attribute can be null or not */
                 QString defaultvalue; 		/**< The default value of the attribute */
         } ;
@@ -126,7 +144,7 @@ public:
         typedef QList<SKGAttributeInfo>::Iterator SKGAttributesListIterator;
 
         /**
-         * This structure defines dump modes
+         * This enumerate defines dump modes
          */
         enum DumpMode {
                 DUMP_CSV, /**< To dump in CSV mode */
@@ -207,7 +225,7 @@ public:
 
         /**
          * Convert a QString to QDateTime.
-         * @param iDateString the time. The format must be "%Y-%m-%d %H-%M-%S or "%Y-%m-%d"
+         * @param iDateString the time. The format must be "%Y-%m-%d %H-%M-%S" or "%Y-%m-%d"
          * @return the converted time_t
          */
         static QDateTime stringToTime(const QString& iDateString);
@@ -225,7 +243,7 @@ public:
          * The output format is "YYYY-MM-DD"
          * @param iDate the QString representing the input date
          * @param iFormat the format of the input date. Must be in the following list:
-         * "YYYYMMDD", "YYYY-MM-DD"
+         * "YYYYMMDD","DDMMYYYY", "MMDDYYYY" "YYYY-MM-DD"
          * "MM/DD/YY", "MM-DD-YY", "DD/MM/YY", "DD-MM-YY"
          * "MM/DD/YYYY", "MM-DD-YYYY", "DD/MM/YYYY", "DD-MM-YYYY"
          * @return the converted QString
@@ -250,7 +268,7 @@ public:
          * Split a csv line
          * @param iString the csv line
          * @param iSeparator the csv separator
-         * @param iCoteDefineBlock to indicate if character " define a block
+         * @param iCoteDefineBlock to indicate if the character double cote define a block
          * @param oRealSeparator the real csv separator. If the csv string is strictly all enclosed then oRealSeparator will contain the real separator
          * @return the list of all values in this csv line
          */
