@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -38,6 +38,8 @@ void fileTest(SKGDocument::DatabaseMode iMode, int& nberror, int& nbcheck, bool
                 SKGDocument document1(iMode);
                 QFile(filename1).remove();
                 SKGTESTERROR("DOC:initialize", document1.initialize(), true);
+                SKGTESTERROR("DOC:setLanguage", document1.setLanguage("en"), true);
+                SKGTESTERROR("DOC:setLanguage", document1.setLanguage("fr"), true);
                 SKGTEST("DOC:isFileModified", document1.isFileModified(), false);
 
                 SKGTESTERROR("DOC:beginTransaction", document1.beginTransaction("tt"), true);
