@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,7 +15,7 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
-* This file is part of Skrooge and defines the main of skrooge.
+* This file defines the main of skrooge.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -38,8 +38,17 @@
  */
 static const char description[] = I18N_NOOP("Personal finance management tool for KDE4, with the aim of being highly intuitive, while providing powerful functions such as reporting (including graphics), persistent Undo/Redo, encryption, and much more...");
 
+/**
+ * To compute the version
+ */
 #define VER1_(x) #x
+/**
+ * To compute the version
+ */
 #define VER_(x) VER1_(x)
+/**
+ * To compute the version
+ */
 #define VER VER_(SKGVERSION)
 
 /**
@@ -83,9 +92,7 @@ public:
                 //Build widget
                 if (!widget) {
                         //Creation splash screen
-                        KSharedConfigPtr config=KSharedConfig::openConfig ( "skroogerc" );
-                        KConfigGroup pref=config->group ( "skrooge" );
-
+                        KConfigGroup pref=SKGMainPanel::getMainConfigGroup();
                         if (pref.readEntry ( "show_splash_screen",true )) {
                                 //KSplashScreen splash(QPixmap ( KStandardDirs::locate("data", QString::fromLatin1("skrooge/images/splash.png"))),Qt::WindowStaysOnTopHint);
                                 QPixmap pix( KStandardDirs::locate("data", QString::fromLatin1("skrooge/images/splash.png")));
@@ -94,7 +101,7 @@ public:
                                 if (splash) {
                                         splash->setMask(pix.createHeuristicMask());
                                         splash->show();
-                                        splash->showMessage(i18n("Loading skrooge ..."), Qt::AlignLeft, QColor(221, 130, 8)); // krazy:exclude=qmethods
+                                        splash->showMessage(i18nc("Splash screen message", "Loading skrooge ..."), Qt::AlignLeft, QColor(221, 130, 8)); // krazy:exclude=qmethods
                                 }
                         }
 
@@ -116,8 +123,17 @@ public:
         }
 
 public:
+        /**
+        * Splash screen
+        */
         KSplashScreen* splash;
+        /**
+         * Main document
+         */
         SKGDocumentBank* doc;
+        /**
+         * Main widget
+         */
         SKGMainPanel *widget;
 };
 
@@ -132,23 +148,23 @@ int main(int argc, char **argv)
 {
         KAboutData about("skrooge",
                          0,
-                         ki18n("Skrooge"),
+                         ki18nc("The name of the application", "Skrooge"),
                          VER,
-                         ki18n(description),
+                         ki18nc("The description of the application", description),
                          KAboutData::License_GPL_V3,
-                         ki18n("(c) 2007-2009 Stephane MANKOWSKI & Guillaume DE BURE"),
+                         ki18nc("Fullname", "(c) 2007-2009 Stephane MANKOWSKI & Guillaume DE BURE"),
                          KLocalizedString(),
-                         "http://extragear.kde.org/apps/skrooge");
+                         "http://skrooge.org");
 
-        about.addAuthor( ki18n("Stephane MANKOWSKI"), ki18n("Architect & Developer"), "stephane@mankowski.fr" );
-        about.addAuthor( ki18n("Guillaume DE BURE"), ki18n("Developer"), "guillaume.debure@gmail.com" );
-        about.addCredit( ki18n("Thierry DAUCOURT"), ki18n("Graphist & Tester"), "thdox@users.sourceforge.net" );
-        about.setOtherText( ki18n("The application name is inspired by Charles Dicken's tale <i>A Christmas Carol</i>, where the main character, Ebenezer Scrooge, a grumpy old narrow man, gets visited by three ghosts who change the way he sees the world, in a good way."));
+        about.addAuthor( ki18nc("Fullname", "Stephane MANKOWSKI"), ki18nc("A job description", "Architect & Developer"), "stephane@mankowski.fr" );
+        about.addAuthor( ki18nc("Fullname", "Guillaume DE BURE"), ki18nc("A job description", "Developer"), "guillaume.debure@gmail.com" );
+        about.addCredit( ki18nc("Fullname", "Thierry DAUCOURT"), ki18nc("A job description", "Graphist & Tester"), "thdox@users.sourceforge.net" );
+        about.setOtherText( ki18nc("The description of the application", "The application name is inspired by Charles Dicken's tale <i>A Christmas Carol</i>, where the main character, Ebenezer Scrooge, a grumpy old narrow man, gets visited by three ghosts who change the way he sees the world, in a good way."));
 
         KCmdLineArgs::init(argc, argv, &about);
 
         KCmdLineOptions options;
-        options.add("+[URL]", ki18n( "Document to open" ));
+        options.add("+[URL]", ki18nc("Application argument", "Document to open" ));
         KCmdLineArgs::addCmdLineOptions(options);
 
         int rc=0;
