@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -59,13 +59,6 @@ public:
          */
         virtual void setState(const QString& iState);
 
-        /**
-         * Get attribute name to save the default state
-         * MUST BE OVERWRITTEN
-         * @return attribute name to save the default state.
-         */
-        virtual QString getDefaultStateAttribute();
-
 private slots:
         void dataModified(const QString& iTableName="", int iIdTransaction=0);
         void onOpen(const QString& iLink);
@@ -80,6 +73,7 @@ private:
         KAction* menuCreditCard;
         KAction* menuInvestment;
         KAction* menuOther;
+        KAction* menuFavorite;
 };
 
 #endif // SKGDEBUGPLUGIN_H
