@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -34,8 +34,10 @@
 #include <QHeaderView>
 #include <QResizeEvent>
 
+bool SKGBookmarkPluginDockWidget::middleClick=false;
+
 SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(SKGDocument* iDocument)
-                : SKGTabWidget(iDocument)
+                : SKGTabPage(iDocument)
 {
         SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget");
 
@@ -56,16 +58,16 @@ SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(SKGDocument* iDocument)
 
         mainMenu->addSeparator();
 
-        actAddBookmarkGroup = mainMenu->addAction(KIcon("folder-new"), i18n("Add bookmark group"));
+        actAddBookmarkGroup = mainMenu->addAction(KIcon("folder-new"), i18nc("Verb","Add bookmark group"));
         connect(actAddBookmarkGroup, SIGNAL(triggered(bool)), this, SLOT(onAddBookmarkGroup()));
 
-        actAddBookmark = mainMenu->addAction(KIcon("list-add"), i18n("Bookmark current page"));
+        actAddBookmark = mainMenu->addAction(KIcon("list-add"), i18nc("Verb","Bookmark current page"));
         connect(actAddBookmark, SIGNAL(triggered(bool)), this, SLOT(onAddBookmark()));
 
         actSetAutostart = mainMenu->addAction(KIcon("user-online"), i18nc("Verb, automatically load when skrooge is started","Autostart"));
         connect(actSetAutostart, SIGNAL(triggered(bool)), this, SLOT(onSetAutostart()));
 
-        actUnsetAutostart = mainMenu->addAction(KIcon("user-offline"), i18n("Remove Autostart"));
+        actUnsetAutostart = mainMenu->addAction(KIcon("user-offline"), i18nc("Verb","Remove Autostart"));
         connect(actUnsetAutostart, SIGNAL(triggered(bool)), this, SLOT(onUnsetAutostart()));
 
         connect(ui.kBookmarksList, SIGNAL(customContextMenuRequested(const QPoint & ) ),this,SLOT(showMenu( const QPoint& )));
@@ -138,7 +140,7 @@ void SKGBookmarkPluginDockWidget::setAutostart(const QString& value)
         //foreach selected bookmark, set the t_autostart attribute to 'y' or 'n'
         {
                 int nb=selectedBookmarks.count();
-                SKGBEGINPROGRESSTRANSACTION(*getDocument(), value == "Y" ? i18n("Autostart bookmarks") : i18n("Do not Autostart bookmarks"), err, nb);
+                SKGBEGINPROGRESSTRANSACTION(*getDocument(), value == "Y" ? i18nc("Noun, name of the user action", "Autostart bookmarks") : i18nc("Noun, name of the user action", "Do not Autostart bookmarks"), err, nb);
                 for (int i = 0 ; err.isSucceeded() && i<nb  ; ++i) {
                         SKGNodeObject bookmark = selectedBookmarks.at(i);
                         err = bookmark.setAttribute("t_autostart",value);
@@ -149,7 +151,7 @@ void SKGBookmarkPluginDockWidget::setAutostart(const QString& value)
         QApplication::restoreOverrideCursor();
 
         //status bar
-        if (err.isSucceeded()) err=SKGError(0, value == "Y" ? i18n("Autostart bookmarks") : i18n("Do not Autostart bookmarks"));
+        if (err.isSucceeded()) err=SKGError(0, value == "Y" ? i18nc("Successful message after an user action", "Autostart bookmarks") : i18nc("Successful message after an user action", "Do not Autostart bookmarks"));
         SKGMainPanel::getMainPanel()->displayErrorMessage(err);
 
 }
@@ -180,14 +182,9 @@ void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool
                 QStringList data=SKGServices::splitCSVLine(selectedNode.getData());
                 if (data.count()>3) {
                         //This bookmark has information ==> we open it
-                        SKGTabWidget* w=SKGMainPanel::getMainPanel()->setNewTabContent(SKGMainPanel::getMainPanel()->getPluginByName(data[0]),tabNumberForNextOpen, data[3], selectedNode.getName());
+                        SKGMainPanel::getMainPanel()->setNewTabContent(SKGMainPanel::getMainPanel()->getPluginByName(data[0]),tabNumberForNextOpen, data[3], selectedNode.getName(), SKGServices::intToString(selectedNode.getID()));
                         selectedNode.opened = true;
                         tabNumberForNextOpen=-1;
-                        if (w) {
-                                w->setBookmarkID(SKGServices::intToString(selectedNode.getID()));
-
-                                SKGMainPanel::getMainPanel()->refresh();
-                        }
                 } else {
                         //This bookmark is a folder ==> we open children by recursion
                         SKGObjectBase::SKGListSKGObjectBase children;
@@ -242,6 +239,7 @@ void SKGBookmarkPluginDockWidget::onAddBookmarkGroup()
         SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::onAddBookmarkGroup");
         SKGError err;
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+	SKGNodeObject node;
         {
                 //Get current selection name
                 QString name;
@@ -252,21 +250,21 @@ void SKGBookmarkPluginDockWidget::onAddBookmarkGroup()
                 }
 
                 //Add current name
-                QString namef=i18n("New bookmark");
-                if (namef.isEmpty()) namef=i18n("new bookmark folder");
-
                 if (!name.isEmpty()) name+=OBJECTSEPARATOR;
-                name+=namef;
+                name+=i18nc("Default name for bookmark", "New bookmark");
 
                 //Create bookmark folder
-                SKGBEGINTRANSACTION(*getDocument(), i18n("Bookmark folder creation [%1]", name), err);
-                SKGNodeObject node;
+                SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Bookmark folder creation [%1]", name), err);
                 err=SKGNodeObject::createPathNode(getDocument(), name, node, true);
         }
         QApplication::restoreOverrideCursor();
 
         //status bar
-        if (err.isSucceeded()) err=SKGError(0, i18n("Bookmark group created"));
+        if (err.isSucceeded())
+	{
+	  ui.kBookmarksList->selectObject(node.getUniqueID());
+	  err=SKGError(0, i18nc("Successful message after an user action", "Bookmark group created"));
+	}
         SKGMainPanel::getMainPanel()->displayErrorMessage(err);
 }
 
@@ -277,7 +275,8 @@ void SKGBookmarkPluginDockWidget::onAddBookmark()
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
         //Get current page
-        SKGTabWidget* currentPage=SKGMainPanel::getMainPanel()->currentTab();
+        SKGNodeObject node;
+        SKGTabPage* currentPage=SKGMainPanel::getMainPanel()->currentTab();
         if (currentPage) {
                 //Get current selection name
                 QString name;
@@ -300,8 +299,7 @@ void SKGBookmarkPluginDockWidget::onAddBookmark()
                 name+=defaultName;
 
                 //Create bookmark
-                SKGBEGINTRANSACTION(*getDocument(), i18n("Bookmark creation [%1]", name), err);
-                SKGNodeObject node;
+                SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Bookmark creation [%1]", name), err);
                 err=SKGNodeObject::createPathNode(getDocument(), name, node, true);
                 if (err.isSucceeded()) {
                         QString value=SKGServices::stringToCsv(currentPage->objectName())+';'+
@@ -317,7 +315,11 @@ void SKGBookmarkPluginDockWidget::onAddBookmark()
         QApplication::restoreOverrideCursor();
 
         //status bar
-        if (err.isSucceeded()) err=SKGError(0, i18n("Bookmark created"));
+        if (err.isSucceeded())
+	{
+	  ui.kBookmarksList->selectObject(node.getUniqueID());
+	  err=SKGError(0, i18nc("Successful message after an user action", "Bookmark created"));
+	}
         SKGMainPanel::getMainPanel()->displayErrorMessage(err);
 }
 
@@ -346,7 +348,7 @@ void SKGBookmarkPluginDockWidget::onRemoveBookmark()
 
         SKGError err;
         {
-                SKGBEGINTRANSACTION(*getDocument(), i18n("Bookmark delete"), err);
+                SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Bookmark delete"), err);
                 //Get current selection
                 SKGObjectBase::SKGListSKGObjectBase bookmarks=getSelectedObjects();
                 int nb=bookmarks.count();
@@ -359,7 +361,7 @@ void SKGBookmarkPluginDockWidget::onRemoveBookmark()
         QApplication::restoreOverrideCursor();
 
         //status bar
-        if (err.isSucceeded()) err=SKGError(0, i18n("Bookmark deleted"));
+        if (err.isSucceeded()) err=SKGError(0, i18nc("Successful message after an user action", "Bookmark deleted"));
         SKGMainPanel::getMainPanel()->displayErrorMessage(err);
 }
 
@@ -387,22 +389,6 @@ void SKGBookmarkPluginDockWidget::onBookmarkEditorChanged()
 void SKGBookmarkPluginDockWidget::refresh()
 {
         SKGTRACEIN(10, "SKGBookmarkPluginDockWidget::refresh");
-        //Automatic open of autostart bookmark
-        QString doc_id=getDocument()->getUniqueIdentifier();
-
-        if (docUniqueIdentifier!=doc_id) {
-                docUniqueIdentifier=doc_id;
-                SKGObjectBase::SKGListSKGObjectBase oNodeList;
-                SKGError err = SKGObjectBase::getObjects(getDocument(), "v_node", "t_autostart='Y' ORDER BY f_sortorder, t_name", oNodeList);
-                int nbAutoStartedBookmarks = oNodeList.count();
-                for (int i=0;i<nbAutoStartedBookmarks;i++) {
-                        SKGNodeObject autostarted_bookmark = oNodeList.at(i);
-                        autostarted_bookmark.load();
-                        SKGTRACEIN(10, "autostarting bookmark : "+autostarted_bookmark.getName());
-                        openBookmark(autostarted_bookmark, i>0);
-                }
-        }
-
         //Bookmarks
         SKGObjectBase::SKGListSKGObjectBase bookmarks=getSelectedObjects();
         int nbSelectedObjects=bookmarks.count();
@@ -412,6 +398,21 @@ void SKGBookmarkPluginDockWidget::refresh()
                 if (actUnsetAutostart) actUnsetAutostart->setEnabled(node.getAttribute("t_autostart")=="Y");
         }
 
+	//Set current selection of dock
+	/*SKGTabPage* cPage= SKGMainPanel::getMainPanel()->currentTab();
+	if(cPage)
+	{
+	  //Get uuid of current page
+	  QString id=cPage->getBookmarkID();
+	  if(!id.isEmpty())
+	  {
+	    bool previous=ui.kBookmarksList->blockSignals ( true );
+	    ui.kBookmarksList->clearSelection();
+	    ui.kBookmarksList->selectObject(id+"-node");
+	    ui.kBookmarksList->blockSignals ( previous );
+	  }
+	} */
+
         onBookmarkEditorChanged();
 }
 
