@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,7 +22,7 @@
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
 #include "ui_skgbookmarkplugindockwidget_base.h"
-#include "skgtabwidget.h"
+#include "skgtabpage.h"
 #include "skgnodeobject.h"
 
 class KMenu;
@@ -30,7 +30,7 @@ class KMenu;
 /**
  * This file is Skrooge plugin for undoredo management
  */
-class SKGBookmarkPluginDockWidget : public SKGTabWidget
+class SKGBookmarkPluginDockWidget : public SKGTabPage
 {
         Q_OBJECT
 
@@ -62,7 +62,7 @@ public:
          * @param iNode bookmark object to open
          * @param iFirstInNewPage to open first object in new page
          */
-        virtual void openBookmark(const SKGNodeObject& iNode, bool iFirstInNewPage=false);
+        static void openBookmark(const SKGNodeObject& iNode, bool iFirstInNewPage=false);
 
 protected:
         /**
@@ -97,7 +97,6 @@ private:
         void setAutostart(const QString& value);
 
         Ui::skgbookmarkplugindockwidget_base ui;
-        QString docUniqueIdentifier;
         KMenu* mainMenu;
         QAction* actDelete;
         QAction* actRename;
@@ -105,7 +104,7 @@ private:
         QAction* actAddBookmarkGroup;
         QAction* actSetAutostart;
         QAction* actUnsetAutostart;
-        bool middleClick;
+        static bool middleClick;
 };
 
 #endif // SKGBOOKMARKPLUGINDOCKWIDGET_H
