@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -27,7 +27,13 @@
 #include <kactioncollection.h>
 #include <kstandardaction.h>
 
+/**
+ * This plugin factory.
+ */
 K_PLUGIN_FACTORY(SKGDashboardPluginFactory, registerPlugin<SKGDashboardPlugin>();)
+/**
+ * This plugin export.
+ */
 K_EXPORT_PLUGIN(SKGDashboardPluginFactory("skrooge_dashboard", "skrooge_dashboard"))
 
 SKGDashboardPlugin::SKGDashboardPlugin(QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
@@ -65,7 +71,7 @@ void SKGDashboardPlugin::close()
         SKGTRACEIN(10, "SKGDashboardPlugin::close");
 }
 
-SKGTabWidget* SKGDashboardPlugin::getWidget()
+SKGTabPage* SKGDashboardPlugin::getWidget()
 {
         SKGTRACEIN(10, "SKGDashboardPlugin::getWidget");
         return new SKGDashboardPluginWidget(currentBankDocument);
@@ -95,11 +101,6 @@ QString SKGDashboardPlugin::icon() const
         return "go-home";
 }
 
-QString SKGDashboardPlugin::statusTip () const
-{
-        return i18nc("Noun, a summary of your financial situation","Dashboard");
-}
-
 QString SKGDashboardPlugin::toolTip () const
 {
         return i18nc("Noun, a summary of your financial situation","Dashboard");
@@ -114,7 +115,7 @@ int SKGDashboardPlugin::getOrder() const
 QStringList SKGDashboardPlugin::tips() const
 {
         QStringList output;
-        output.push_back(i18n("<p>... the dashboard is there to give you a summary of your situation.</p>"));
+        output.push_back(i18nc("Description of a tips", "<p>... the dashboard is there to give you a summary of your situation.</p>"));
         return output;
 }
 
