@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,7 +22,7 @@
 * @author Stephane MANKOWSKI
 */
 #include "ui_skgdashboardpluginwidget_base.h"
-#include "skgtabwidget.h"
+#include "skgtabpage.h"
 
 #include <QGridLayout>
 #include <QList>
@@ -35,7 +35,7 @@ class SKGInterfacePlugin;
 /**
  * A dashboard for skrooge
  */
-class SKGDashboardPluginWidget : public SKGTabWidget
+class SKGDashboardPluginWidget : public SKGTabPage
 {
         Q_OBJECT
 
@@ -89,6 +89,8 @@ private slots:
         void onAddWidget();
         void onRemoveWidget();
         void onColumnNbChanged();
+        void onMoveAfterWidget();
+        void onMoveBeforeWidget();
 
 private:
         Q_DISABLE_COPY(SKGDashboardPluginWidget);
@@ -103,7 +105,10 @@ private:
         QStringList items;
         QList<SKGWidget*> itemsPointers;;
         KMenu* menu;
+	QMenu* addMenu;
         QMenu* removeMenu;
+        QMenu* previousMenu;
+        QMenu* nextMenu;
         int col;
         int row;
         int nbMaxCol;
