@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -64,7 +64,7 @@ public:
          * The context widget of the plugin.
          * @return The context widget of the plugin
          */
-        virtual SKGTabWidget* getWidget();
+        virtual SKGTabPage* getWidget();
 
         /**
          * The title of the plugin.
@@ -78,12 +78,6 @@ public:
          */
         virtual QString icon() const;
 
-        /**
-         * The statusTip of the plugin.
-         * @return The toolTip of the plugin
-         */
-        virtual QString statusTip () const;
-
         /**
          * The toolTip of the plugin.
          * @return The toolTip of the plugin
