@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -29,7 +29,7 @@
 #include <QDomDocument>
 
 SKGDebugPluginWidget::SKGDebugPluginWidget(SKGDocument* iDocument)
-                :SKGTabWidget(iDocument)
+                :SKGTabPage(iDocument)
 {
         SKGTRACEIN(10, "SKGDebugPluginWidget::SKGDebugPluginWidget");
         ui.setupUi(this);
@@ -42,7 +42,7 @@ SKGDebugPluginWidget::SKGDebugPluginWidget(SKGDocument* iDocument)
         //Fill combo box
         ui.kExplainCmb->addItem (KIcon("system-run"), i18nc("Verb, execute the SQL query", "Execute"));
         ui.kExplainCmb->addItem (KIcon("help-hint"), i18nc("Verb, explain the query","Explain"));
-        ui.kExplainCmb->addItem (KIcon("games-hint"), i18n("Explain query plan"));
+        ui.kExplainCmb->addItem (KIcon("games-hint"), i18nc("Verb, explain the query plan", "Explain query plan"));
 
         //Set level trace
         ui.kTraceLevel->setValue(SKGTraces::SKGLevelTrace);
@@ -129,14 +129,14 @@ void SKGDebugPluginWidget::onExecuteSqlOrder(bool iInTransaction)
         QString oResult;
         double time=SKGServices::getMicroTime();
         if (iInTransaction) {
-                SKGBEGINTRANSACTION(*getDocument(), i18n("SQL command from debug plugin"), err);
+                SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "SQL command from debug plugin"), err);
                 err=SKGServices::dumpSelectSqliteOrder(getDocument(), text, oResult);
         } else {
                 err=SKGServices::dumpSelectSqliteOrder(getDocument(), text, oResult);
         }
         time=SKGServices::getMicroTime()-time;
 
-        oResult+=i18n("\nExecution time: %1 ms",SKGServices::doubleToString(time));
+        oResult+=i18nc("Execution time", "\nExecution time: %1 ms",SKGServices::doubleToString(time));
 
         if (err.isSucceeded()) {
                 ui.kSQLResult->setPlainText(oResult);
