@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -36,7 +36,13 @@
 #include <QTextCodec>
 #include <QDomDocument>
 
+/**
+ * This plugin factory.
+ */
 K_PLUGIN_FACTORY(SKGImportExportPluginFactory, registerPlugin<SKGImportExportPlugin>();)
+/**
+ * This plugin export.
+ */
 K_EXPORT_PLUGIN(SKGImportExportPluginFactory("skrooge_importexport", "skrooge_importexport"))
 
 SKGImportExportPlugin::SKGImportExportPlugin(QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
@@ -77,21 +83,22 @@ void SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
         actionCollection()->addAction( QLatin1String("import"), imports );
 
         //Import
-        QStringList overlayofx;
-        overlayofx.push_back("skrooge");
+        QStringList overlay;
+        overlay.push_back("skrooge");
 
-        importAction = new KAction(KIcon("document-import", NULL, overlayofx), i18nc("Verb, action to import items from another format","&Import..."), this);
+        importAction = new KAction(KIcon("document-import", NULL, overlay), i18nc("Verb, action to import items from another format","Import..."), this);
         importAction->setShortcut ( Qt::CTRL+Qt::ALT+Qt::Key_I );
         connect(importAction, SIGNAL(triggered(bool)), SLOT(import()));
         actionCollection()->addAction( QLatin1String("import_operation"), importAction );
         imports->addAction(importAction);
+        importAction->setShortcut ( Qt::CTRL+Qt::META+Qt::Key_I );
 
         if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("import_operation", importAction);
 
         //Import CSV Unit
         QStringList overlaycsv;
         overlaycsv.push_back("text-csv");
-        importCsvUnitAction = new KAction(KIcon("document-import", NULL, overlaycsv), i18n("Import CSV &Unit..."), this);
+        importCsvUnitAction = new KAction(KIcon("document-import", NULL, overlaycsv), i18nc("Verb, action to import","Import CSV Unit..."), this);
         connect(importCsvUnitAction, SIGNAL(triggered(bool)), SLOT(import()));
         actionCollection()->addAction( QLatin1String("import_csv_unit"), importCsvUnitAction );
         imports->addAction(importCsvUnitAction);
@@ -103,15 +110,16 @@ void SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
         actionCollection()->addAction( QLatin1String("export"), exports );
 
         //Export QIF
-        exportQifAction = new KAction(KIcon("document-export"), i18n("Export &QIF..."), this);
+        exportQifAction = new KAction(KIcon("document-export"), i18nc("Verb, action to export items to another format","Export QIF..."), this);
         connect(exportQifAction, SIGNAL(triggered(bool)), SLOT(exportQif()));
         actionCollection()->addAction( QLatin1String("export_qif"), exportQifAction );
         exports->addAction(exportQifAction);
+        exportQifAction->setShortcut ( Qt::CTRL+Qt::META+Qt::Key_E );
 
         if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("export_qif", exportQifAction);
 
         //Export CSV
-        exportCsvAction = new KAction(KIcon("document-export", NULL, overlaycsv), i18n("Export &CSV..."), this);
+        exportCsvAction = new KAction(KIcon("document-export", NULL, overlaycsv), i18nc("Verb, action to export items to another format","Export CSV..."), this);
         connect(exportCsvAction, SIGNAL(triggered(bool)), SLOT(exportCsv()));
         actionCollection()->addAction( QLatin1String("export_csv"), exportCsvAction );
         exports->addAction(exportCsvAction);
@@ -126,15 +134,16 @@ void SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
         QStringList overlaytransfers;
         overlaytransfers.push_back("skrooge_transfer");
 
-        processingFoundTransfert = new KAction(KIcon("tools-wizard", NULL, overlaytransfers), i18n("Find and group transfers"), this);
+        processingFoundTransfert = new KAction(KIcon("tools-wizard", NULL, overlaytransfers), i18nc("Verb, action to find and group transfers","Find and group transfers"), this);
         connect(processingFoundTransfert, SIGNAL(triggered(bool)), SLOT(foundTransfer()));
         actionCollection()->addAction( QLatin1String("process_foundtransfer"), processingFoundTransfert );
         processing->addAction(processingFoundTransfert);
+        processingFoundTransfert->setShortcut ( Qt::CTRL+Qt::META+Qt::Key_G );
 
         if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("process_foundtransfer", processingFoundTransfert);
 
         //Processing bankperfect
-        processingBankPerfect = new KAction(KIcon("tools-wizard"), i18n("Clean BankPerfect's imports"), this);
+        processingBankPerfect = new KAction(KIcon("tools-wizard"), i18nc("Verb, action to clean an import","Clean BankPerfect's imports"), this);
         connect(processingBankPerfect, SIGNAL(triggered(bool)), SLOT(cleanBankPerfect()));
         actionCollection()->addAction( QLatin1String("process_bankperfect"), processingBankPerfect );
         processing->addAction(processingBankPerfect);
@@ -142,7 +151,7 @@ void SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
         if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("process_bankperfect", processingBankPerfect);
 
         //Processing banks
-        processingBank = new KAction(KIcon("tools-wizard"), i18n("Clean bank's imports"), this);
+        processingBank = new KAction(KIcon("tools-wizard"), i18nc("Verb, action to clean an import","Clean bank's imports"), this);
         connect(processingBank, SIGNAL(triggered(bool)), SLOT(cleanBanks()));
         actionCollection()->addAction( QLatin1String("process_banks"), processingBank );
         processing->addAction(processingBank);
@@ -152,20 +161,23 @@ void SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
         //Processing banks
         QStringList overlayValidate;
         overlayValidate.push_back("dialog-ok-apply");
-        validateImportedOperationsAction = new KAction(KIcon("document-import", NULL, overlayValidate), i18n("Validate imported operations"), this);
+        validateImportedOperationsAction = new KAction(KIcon("document-import", NULL, overlayValidate), i18nc("Verb, action to validate imported operations","Validate imported operations"), this);
         connect(validateImportedOperationsAction, SIGNAL(triggered(bool)), SLOT(validateImportedOperations()));
         actionCollection()->addAction( QLatin1String("validate_imported_operation"), validateImportedOperationsAction );
+        validateImportedOperationsAction->setShortcut ( Qt::CTRL+Qt::SHIFT+Qt::Key_V );
 
         if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("validate_imported_operation", validateImportedOperationsAction);
 
-        openNotValidatedAction = new KAction ( KIcon("skrooge_open_imported"), i18n ( "Open imported operations not yet validated" ), this);
+        QStringList overlayopen;
+        overlayopen.push_back("skg_open");
+        openNotValidatedAction = new KAction ( KIcon("document-import", NULL, overlayopen), i18nc("Verb, action to open","Open imported operations not yet validated..." ), this);
         connect ( openNotValidatedAction, SIGNAL ( triggered ( bool ) ), this, SLOT ( openNotValidated() ) );
         actionCollection()->addAction ( QLatin1String ( "view_open_not_validated" ), openNotValidatedAction );
-        openNotValidatedAction->setShortcut ( Qt::CTRL+Qt::SHIFT+Qt::Key_V );
+        openNotValidatedAction->setShortcut ( Qt::META+Qt::Key_V );
 
         if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction ( "view_open_not_validated", openNotValidatedAction );
 
-        mergeImportedOperationAction = new KAction(KIcon("skrooge_merge_import"), i18n("Merge imported operations"), this);
+        mergeImportedOperationAction = new KAction(KIcon("skrooge_merge_import"), i18nc("Verb, action to merge","Merge imported operations"), this);
         connect(mergeImportedOperationAction, SIGNAL(triggered(bool)), SLOT(mergeImportedOperation()));
         actionCollection()->addAction( QLatin1String("merge_imported_operation"), mergeImportedOperationAction );
         mergeImportedOperationAction->setShortcut ( Qt::CTRL+Qt::Key_M );
@@ -204,7 +216,7 @@ KConfigSkeleton* SKGImportExportPlugin::getPreferenceSkeleton()
 
 QString SKGImportExportPlugin::title() const
 {
-        return i18n("Import / Export");
+        return i18nc("Noun","Import / Export");
 }
 
 QString SKGImportExportPlugin::icon() const
@@ -212,22 +224,17 @@ QString SKGImportExportPlugin::icon() const
         return "utilities-file-archiver";
 }
 
-QString SKGImportExportPlugin::statusTip () const
-{
-        return i18n("Import / Export management (CSV, QIF ...)");
-}
-
 QString SKGImportExportPlugin::toolTip () const
 {
-        return i18n("Import / Export management");
+        return i18nc("Noun","Import / Export management");
 }
 
 QStringList SKGImportExportPlugin::tips() const
 {
         QStringList output;
-        output.push_back(i18n("<p>... skrooge is able to detect automatically transfers after an import.</p>"));
-        output.push_back(i18n("<p>... you can import many files in one shot.</p>"));
-        output.push_back(i18n("<p>... unit amounts can be imported through a CSV file.</p>"));
+        output.push_back(i18nc("Description of a tips", "<p>... skrooge is able to detect automatically transfers after an import.</p>"));
+        output.push_back(i18nc("Description of a tips", "<p>... you can import many files in one shot.</p>"));
+        output.push_back(i18nc("Description of a tips", "<p>... unit amounts can be imported through a CSV file.</p>"));
         return output;
 }
 
@@ -258,7 +265,7 @@ void SKGImportExportPlugin::refresh()
 
                 SKGObjectBase::SKGListSKGObjectBase selection=SKGMainPanel::getMainPanel()->getSelectedObjects();
                 if ( selection.count() >0 && test) {
-                        bool onOperation= ( selection.at ( 0 ).getRealTable() =="operation" );
+                        bool onOperation= ( selection.at ( 0 ).getRealTable() =="operation" &&  selection.at ( 0 ).getTable()!="v_operation_consolidated");
                         if ( validateImportedOperationsAction ) validateImportedOperationsAction->setEnabled ( onOperation );
                         if ( mergeImportedOperationAction ) mergeImportedOperationAction->setEnabled ( onOperation );
                 } else {
@@ -286,11 +293,11 @@ void SKGImportExportPlugin::import(const QString& iFile)
                 if (iFile.isEmpty()) {
                         //Panel to ask files
                         KEncodingFileDialog::Result result=KEncodingFileDialog::getOpenFileNamesAndEncoding(lastCodecUsed, "kfiledialog:///IMPEXP",
-                                                           sender()==importCsvUnitAction ? "*.csv|"+i18n("CSV Files") :
-                                                           "*.ofx *.qfx *.qif *.csv|"+i18n("All supported formats")+
-                                                           "\n*.ofx *.qfx|"+i18n("OFX Files")+
-                                                           "\n*.qif|"+i18n("QIF Files")+
-                                                           "\n*.csv|"+i18n("CSV Files") ,
+                                                           sender()==importCsvUnitAction ? "*.csv|"+i18nc("A file format", "CSV Files") :
+                                                           QString(SKGImportExportManager::isOFXSupported() ? "*.ofx *.qfx ": "")+"*.qif *.csv|"+i18nc("A file format", "All supported formats")+'\n'+
+                                                           (SKGImportExportManager::isOFXSupported() ? "*.ofx *.qfx|"+i18nc("A file format", "OFX Files")+'\n': "")+
+                                                           "*.qif|"+i18nc("A file format", "QIF Files")+'\n'+
+                                                           "*.csv|"+i18nc("A file format", "CSV Files") ,
                                                            SKGMainPanel::getMainPanel());
                         fileNames=result.fileNames.toSet();
                         codec=result.encoding;
@@ -304,12 +311,11 @@ void SKGImportExportPlugin::import(const QString& iFile)
 
                         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
                         {
-                                SKGBEGINPROGRESSTRANSACTION(*currentBankDocument, i18n("Import with codec %1", codec), err, nbFiles);
+                                SKGBEGINPROGRESSTRANSACTION(*currentBankDocument, i18nc("Noun, name of the user action", "Import with codec %1", codec), err, nbFiles);
 
                                 //Read Setting
-                                KSharedConfigPtr config=KSharedConfig::openConfig("skrooge_importexportrc");
-                                KConfigGroup pref=config->group("skrooge_importexport");
-                                bool automatic_validation = pref.readEntry("automatic_validation",false);
+                                bool automatic_validation = skgimportexport_settings::automatic_validation();
+                                bool automatic_rule = skgimportexport_settings::apply_rules();
 
                                 if (err.isSucceeded()) err=currentBankDocument->setParameter("SKG_LAST_CODEC_USED_FOR_IMPORT", codec);
 
@@ -329,27 +335,28 @@ void SKGImportExportPlugin::import(const QString& iFile)
                                         //Import
                                         SKGImportExportManager imp1((SKGDocumentBank*) currentBankDocument, mode, fileName);
                                         imp1.setAutomaticValidation(automatic_validation);
+					imp1.setAutomaticApplyRules(automatic_rule);
                                         imp1.setCodec(codec);
 
                                         if (mode==SKGImportExportManager::CSV || mode==SKGImportExportManager::CSVUNIT) {
                                                 //Set header line
-                                                bool automatic_search_header = pref.readEntry("automatic_search_header", true);
+                                                bool automatic_search_header = skgimportexport_settings::automatic_search_header();
                                                 if (!automatic_search_header) {
-                                                        int header_position = pref.readEntry("header_position", 1);
+                                                        int header_position = skgimportexport_settings::header_position();
                                                         if (err.isSucceeded()) err=imp1.setCSVHeaderIndex(header_position-1);
 
                                                 }
 
-                                                bool automatic_search_columns = pref.readEntry("automatic_search_columns", true);
+                                                bool automatic_search_columns = skgimportexport_settings::automatic_search_columns();
                                                 if (!automatic_search_columns) {
-                                                        QStringList columns_positions = pref.readEntry("columns_positions", "").split('|');
+                                                        QStringList columns_positions = skgimportexport_settings::columns_positions().split('|');
                                                         if (err.isSucceeded()) err=imp1.setCSVMapping(&columns_positions);
                                                 }
                                         }
 
                                         if (err.isSucceeded()) err=imp1.importFile();
                                         if (err.isFailed()) {
-                                                err.addError(ERR_FAIL, i18n("Import of %1 file named [%2] failed", extension, fileName));
+                                                err.addError(ERR_FAIL, i18nc("Error message", "Import of %1 file named [%2] failed", extension, fileName));
                                         }
 
                                         if (err.isSucceeded()) err=currentBankDocument->stepForward(i);
@@ -366,6 +373,9 @@ void SKGImportExportPlugin::import(const QString& iFile)
 
                 //Display error
                 if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->displayErrorMessage(err);
+
+                //Open last modified operations if setting activated
+                if (err.isSucceeded()) openLastModifiedIfSetting();
         }
 }
 
@@ -373,12 +383,12 @@ void SKGImportExportPlugin::exportCsv()
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGImportExportPlugin::exportCsv",err);
-        QString fileName=SKGMainPanel::getSaveFileName(KUrl("kfiledialog:///IMPEXP"), "*.csv|"+i18n("CSV Files") , SKGMainPanel::getMainPanel());
+        QString fileName=SKGMainPanel::getSaveFileName(KUrl("kfiledialog:///IMPEXP"), "*.csv|"+i18nc("A file format", "CSV Files") , SKGMainPanel::getMainPanel());
         if (fileName.isEmpty() || !currentBankDocument) return;
 
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
         {
-                SKGBEGINTRANSACTION(*currentBankDocument, i18n("Export CSV"), err);
+                SKGBEGINTRANSACTION(*currentBankDocument, i18nc("Noun, name of the user action", "Export CSV"), err);
                 if (err.isSucceeded()) {
                         SKGImportExportManager imp1((SKGDocumentBank*) currentBankDocument, SKGImportExportManager::CSV, fileName);
                         err=imp1.exportFile();
@@ -387,8 +397,8 @@ void SKGImportExportPlugin::exportCsv()
         QApplication::restoreOverrideCursor();
 
         //status bar
-        if (err.isSucceeded()) err=SKGError(0, i18n("File [%1] successfully exported.", fileName));
-        else err.addError(ERR_FAIL, i18n("Export of [%1] failed", fileName));
+        if (err.isSucceeded()) err=SKGError(0, i18nc("Successful message after an user action", "File [%1] successfully exported.", fileName));
+        else err.addError(ERR_FAIL, i18nc("Error message", "Export of [%1] failed", fileName));
 
         //Display error
         if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->displayErrorMessage(err);
@@ -398,12 +408,12 @@ void SKGImportExportPlugin::exportQif()
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGImportExportPlugin::exportQif",err);
-        QString fileName=SKGMainPanel::getSaveFileName(KUrl("kfiledialog:///IMPEXP"), "*.qif|"+i18n("QIF Files") , SKGMainPanel::getMainPanel());
+        QString fileName=SKGMainPanel::getSaveFileName(KUrl("kfiledialog:///IMPEXP"), "*.qif|"+i18nc("A file format", "QIF Files") , SKGMainPanel::getMainPanel());
         if (fileName.isEmpty() || !currentBankDocument) return;
 
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
         {
-                SKGBEGINTRANSACTION(*currentBankDocument, i18n("Export QIF"), err);
+                SKGBEGINTRANSACTION(*currentBankDocument, i18nc("Noun, name of the user action", "Export QIF"), err);
                 if (err.isSucceeded()) {
                         SKGImportExportManager imp1((SKGDocumentBank*) currentBankDocument, SKGImportExportManager::QIF, fileName);
                         err=imp1.exportFile();
@@ -412,8 +422,8 @@ void SKGImportExportPlugin::exportQif()
         QApplication::restoreOverrideCursor();
 
         //status bar
-        if (err.isSucceeded()) err=SKGError(0, i18n("File [%1] successfully exported.", fileName));
-        else err.addError(ERR_FAIL, i18n("Export of [%1] failed", fileName));
+        if (err.isSucceeded()) err=SKGError(0, i18nc("Successful message after an user action", "File [%1] successfully exported.", fileName));
+        else err.addError(ERR_FAIL, i18nc("Error message", "Export of [%1] failed", fileName));
 
         //Display error
         if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->displayErrorMessage(err);
@@ -427,7 +437,7 @@ void SKGImportExportPlugin::foundTransfer()
                 QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
                 int NbOperationsMerged=0;
                 {
-                        SKGBEGINTRANSACTION(*currentBankDocument, i18n("Find and group transfers"), err);
+                        SKGBEGINTRANSACTION(*currentBankDocument, i18nc("Noun, name of the user action", "Find and group transfers"), err);
                         if (err.isSucceeded()) {
                                 SKGImportExportManager imp1((SKGDocumentBank*) currentBankDocument, SKGImportExportManager::QIF, "");
                                 err=imp1.findAndGroupTransfers(NbOperationsMerged);
@@ -438,10 +448,13 @@ void SKGImportExportPlugin::foundTransfer()
                 //status bar
                 if (err.isSucceeded()) err=SKGError(0, i18np("Document successfully processed. %1 operation merged.",
                                                             "Document successfully processed. %1 operations merged.", NbOperationsMerged));
-                else err.addError(ERR_FAIL, i18n("Processing failed."));
+                else err.addError(ERR_FAIL, i18nc("Error message", "Processing failed."));
 
                 //Display error
                 if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->displayErrorMessage(err);
+
+                //Open last modified operations if setting activated
+                if (err.isSucceeded()) openLastModifiedIfSetting();
         }
 }
 
@@ -452,7 +465,7 @@ void SKGImportExportPlugin::cleanBankPerfect()
         if (currentBankDocument) {
                 QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
                 {
-                        SKGBEGINTRANSACTION(*currentBankDocument, i18n("Clean BankPerfect's imports"), err);
+                        SKGBEGINTRANSACTION(*currentBankDocument, i18nc("Noun, name of the user action", "Clean BankPerfect's imports"), err);
                         if (err.isSucceeded()) {
                                 SKGImportExportManager imp1((SKGDocumentBank*) currentBankDocument, SKGImportExportManager::QIF, "");
                                 err=imp1.cleanBankPerfectImport();
@@ -461,11 +474,14 @@ void SKGImportExportPlugin::cleanBankPerfect()
                 QApplication::restoreOverrideCursor();
 
                 //status bar
-                if (err.isSucceeded()) err=SKGError(0, i18n("Document successfully cleaned."));
-                else err.addError(ERR_FAIL, i18n("Clean failed."));
+                if (err.isSucceeded()) err=SKGError(0, i18nc("Successful message after an user action", "Document successfully cleaned."));
+                else err.addError(ERR_FAIL, i18nc("Error message", "Clean failed."));
 
                 //Display error
                 if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->displayErrorMessage(err);
+
+                //Open last modified operations if setting activated
+                if (err.isSucceeded()) openLastModifiedIfSetting();
         }
 }
 
@@ -475,7 +491,7 @@ void SKGImportExportPlugin::cleanBanks()
         SKGTRACEINRC(10, "SKGImportExportPlugin::cleanBanks",err);
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
         {
-                SKGBEGINTRANSACTION(*currentBankDocument, i18n("Clean bank's imports"), err);
+                SKGBEGINTRANSACTION(*currentBankDocument, i18nc("Noun, name of the user action", "Clean bank's imports"), err);
                 if (err.isSucceeded()) {
                         SKGImportExportManager imp1((SKGDocumentBank*) currentBankDocument, SKGImportExportManager::QIF, "");
                         err=imp1.cleanBankImport();
@@ -484,11 +500,14 @@ void SKGImportExportPlugin::cleanBanks()
         QApplication::restoreOverrideCursor();
 
         //status bar
-        if (err.isSucceeded()) err=SKGError(0, i18n("Document successfully cleaned."));
-        else err.addError(ERR_FAIL, i18n("Clean failed."));
+        if (err.isSucceeded()) err=SKGError(0, i18nc("Successful message after an user action", "Document successfully cleaned."));
+        else err.addError(ERR_FAIL, i18nc("Error message", "Clean failed."));
 
         //Display error
         if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->displayErrorMessage(err);
+
+        //Open last modified operations if setting activated
+        if (err.isSucceeded()) openLastModifiedIfSetting();
 }
 
 void SKGImportExportPlugin::validateImportedOperations()
@@ -500,7 +519,7 @@ void SKGImportExportPlugin::validateImportedOperations()
         if (SKGMainPanel::getMainPanel() && currentBankDocument) {
                 SKGObjectBase::SKGListSKGObjectBase selection=SKGMainPanel::getMainPanel()->getSelectedObjects();
                 int nb=selection.count();
-                SKGBEGINPROGRESSTRANSACTION(*currentBankDocument, i18n("Validate imported operations"), err, nb);
+                SKGBEGINPROGRESSTRANSACTION(*currentBankDocument, i18nc("Noun, name of the user action", "Validate imported operations"), err, nb);
                 for (int i=0; err.isSucceeded() && i<nb; ++i) {
                         SKGOperationObject op=selection[i];
                         if (op.getAttribute("t_imported")=="P") {
@@ -511,8 +530,8 @@ void SKGImportExportPlugin::validateImportedOperations()
                 }
 
                 //status bar
-                if (err.isSucceeded()) err=SKGError(0, i18n("Imported operations validated."));
-                else err.addError(ERR_FAIL, i18n("Validation failed"));
+                if (err.isSucceeded()) err=SKGError(0, i18nc("Successful message after an user action", "Imported operations validated."));
+                else err.addError(ERR_FAIL, i18nc("Error message", "Validation failed"));
         }
         QApplication::restoreOverrideCursor();
 
@@ -529,33 +548,20 @@ void SKGImportExportPlugin::mergeImportedOperation()
         if (SKGMainPanel::getMainPanel() && currentBankDocument) {
                 SKGObjectBase::SKGListSKGObjectBase selection=SKGMainPanel::getMainPanel()->getSelectedObjects();
                 int nb=selection.count();
-                err=SKGError(ERR_INVALIDARG, i18n("Invalid selection, you must select one imported operation and one manual operation with same amounts"));
+                err=SKGError(ERR_INVALIDARG, i18nc("Error message", "Invalid selection, you must select one imported operation and one manual operation with same amounts"));
                 if (nb==2) {
                         SKGOperationObject opImported=selection.at(0);
                         SKGOperationObject opManual=selection.at(1);
                         if (opImported.isImported()!=opManual.isImported() && opImported.getCurrentAmount()==opManual.getCurrentAmount()) {
-                                if (!opImported.isImported()) {
-                                        qSwap(opImported, opManual);
-                                }
-
-                                SKGBEGINTRANSACTION(*currentBankDocument, i18n("Merge imported operations"), err);
-                                err=opManual.setDate(opImported.getDate());
-                                if (err.isSucceeded()) err=opManual.setImported(true);
-                                if (err.isSucceeded()) err=opManual.setImportID(opImported.getImportID());
-                                if (err.isSucceeded() && opManual.getComment().isEmpty()) err=opManual.setComment(opImported.getComment());
-                                if (err.isSucceeded() && opManual.getPayee().isEmpty()) err=opManual.setPayee(opImported.getPayee());
-                                if (err.isSucceeded() && opManual.getMode().isEmpty()) err=opManual.setMode(opImported.getMode());
-                                if (err.isSucceeded() && !opManual.isBookmarked()) err=opManual.bookmark(opImported.isBookmarked());
-                                if (err.isSucceeded() && !opManual.getNumber()) err=opManual.setNumber(opImported.getNumber());
-                                if (err.isSucceeded()) err=opManual.save();
-                                if (err.isSucceeded()) err=opImported.remove();
-
-                                if (err.isFailed()) err.addError(ERR_FAIL, i18n("Merge failed"));
+                                SKGBEGINTRANSACTION(*currentBankDocument, i18nc("Noun, name of the user action", "Merge imported operations"), err);
+                                if (!opImported.isImported())  qSwap(opImported, opManual);
+                                err=opManual.merge(opImported);
+                                if (err.isFailed()) err.addError(ERR_FAIL, i18nc("Error message", "Merge failed"));
                         }
                 }
 
                 //status bar
-                if (err.isSucceeded()) err=SKGError(0, i18n("Imported operations merged."));
+                if (err.isSucceeded()) err=SKGError(0, i18nc("Successful message after an user action", "Imported operations merged."));
         }
         QApplication::restoreOverrideCursor();
 
@@ -563,21 +569,35 @@ void SKGImportExportPlugin::mergeImportedOperation()
         if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->displayErrorMessage(err);
 }
 
+void SKGImportExportPlugin::openLastModifiedIfSetting()
+{
+        //Read Setting
+        bool open_after_import_or_processing = skgimportexport_settings::open_after_import_or_processing();
+        if (open_after_import_or_processing) {
+                //Open last operations
+                KAction* action=SKGMainPanel::getMainPanel()->getGlobalAction ("view_open_last_modified");
+                if (action) {
+                        action->trigger();
+                }
+        }
+}
+
 void SKGImportExportPlugin::openNotValidated()
 {
         SKGTRACEIN ( 10, "SKGImportExportPlugin::openNotValidated");
         QString wc="t_imported='P'";
-        QString title=i18n ( "Operations imported and not yet validated" );
+        QString title=i18nc("Noun, a list of items", "Operations imported and not yet validated" );
 
         //Call operation plugin
         QDomDocument doc("SKGML");
-        doc.setContent ( currentBankDocument->getParameter("SKGOPERATION_DEFAULT_PARAMETERS") );
+        if(currentBankDocument) doc.setContent ( currentBankDocument->getParameter("SKGOPERATION_DEFAULT_PARAMETERS") );
         QDomElement root = doc.documentElement();
         if (root.isNull()) {
                 root=doc.createElement("parameters");
                 doc.appendChild(root);
         }
 
+        root.setAttribute ( "account", i18nc("For all accounts", "All") );
         root.setAttribute ( "operationTable", "v_operation_display" );
         root.setAttribute ( "operationWhereClause", wc );
         root.setAttribute ( "title", title );
