@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -27,7 +27,13 @@
 #include <kactioncollection.h>
 #include <kstandardaction.h>
 
+/**
+ * This plugin factory.
+ */
 K_PLUGIN_FACTORY(SKGMonthlyPluginFactory, registerPlugin<SKGMonthlyPlugin>();)
+/**
+ * This plugin export.
+ */
 K_EXPORT_PLUGIN(SKGMonthlyPluginFactory("skrooge_monthly", "skrooge_monthly"))
 
 SKGMonthlyPlugin::SKGMonthlyPlugin(QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
@@ -65,7 +71,7 @@ void SKGMonthlyPlugin::close()
         SKGTRACEIN(10, "SKGMonthlyPlugin::close");
 }
 
-SKGTabWidget* SKGMonthlyPlugin::getWidget()
+SKGTabPage* SKGMonthlyPlugin::getWidget()
 {
         SKGTRACEIN(10, "SKGMonthlyPlugin::getWidget");
         return new SKGMonthlyPluginWidget(currentBankDocument);
@@ -87,7 +93,7 @@ KConfigSkeleton* SKGMonthlyPlugin::getPreferenceSkeleton()
 
 QString SKGMonthlyPlugin::title() const
 {
-        return i18n("Monthly report");
+        return toolTip();
 }
 
 QString SKGMonthlyPlugin::icon() const
@@ -95,14 +101,9 @@ QString SKGMonthlyPlugin::icon() const
         return "skrooge_monthly_report";
 }
 
-QString SKGMonthlyPlugin::statusTip () const
-{
-        return i18n("Monthly report");
-}
-
 QString SKGMonthlyPlugin::toolTip () const
 {
-        return i18n("Monthly report");
+        return i18nc("A tool tip", "Monthly report");
 }
 
 int SKGMonthlyPlugin::getOrder() const
@@ -113,7 +114,7 @@ int SKGMonthlyPlugin::getOrder() const
 QStringList SKGMonthlyPlugin::tips() const
 {
         QStringList output;
-        output.push_back(i18n("<p>... you can generate a monthly report.</p>"));
+        output.push_back(i18nc("Description of a tips", "<p>... you can generate a monthly report.</p>"));
         return output;
 }
 
