@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,12 +22,15 @@
 #include "skgoperationplugin.h"
 #include "skgoperationpluginwidget.h"
 #include "skgoperationboardwidget.h"
+#include "skgbookmarkboardwidget.h"
 #include "skgtraces.h"
 #include "skgoperationobject.h"
+#include "skgaccountobject.h"
 #include "skgsuboperationobject.h"
 #include "skgtransactionmng.h"
 #include "skgmainpanel.h"
 #include "skgtableview.h"
+#include "skgruleobject.h"
 #include "skgoperation_settings.h"
 
 #include <kactioncollection.h>
@@ -35,7 +38,13 @@
 
 #include <QDomDocument>
 
+/**
+ * This plugin factory.
+ */
 K_PLUGIN_FACTORY ( SKGOperationPluginFactory, registerPlugin<SKGOperationPlugin>(); )
+/**
+ * This plugin export.
+ */
 K_EXPORT_PLUGIN ( SKGOperationPluginFactory ( "skrooge_operation", "skrooge_operation" ) )
 
 SKGOperationPlugin::SKGOperationPlugin ( QObject* iParent, const QVariantList& /*iArg*/ ) : SKGInterfacePlugin ( iParent )
@@ -47,11 +56,15 @@ SKGOperationPlugin::~SKGOperationPlugin()
 {
         SKGTRACEIN ( 10, "SKGOperationPlugin::~SKGOperationPlugin" );
         currentBankDocument=NULL;
-
         duplicateAction=NULL;
         switchToPointedAction=NULL;
         switchHighLight=NULL;
         openHighLights=NULL;
+        openLastModified=NULL;
+        groupOperation=NULL;
+        ungroupOperation=NULL;
+	createTemplateAction=NULL;
+	openSuboperations=NULL;
 }
 
 void SKGOperationPlugin::setupActions ( SKGDocument* iDocument, const QStringList& iArgument )
@@ -66,54 +79,79 @@ void SKGOperationPlugin::setupActions ( SKGDocument* iDocument, const QStringLis
         setXMLFile ( "skrooge_operation.rc" );
 
         //Menu
-        duplicateAction = new KAction ( KIcon ( "skrooge_duplicate" ), i18n ( "&Duplicate" ), this );
+        duplicateAction = new KAction ( KIcon ( "skrooge_duplicate" ), i18nc ("Verb, duplicate an object",  "Duplicate" ), this );
         connect ( duplicateAction, SIGNAL ( triggered ( bool ) ), this, SLOT ( actionDuplicate() ) );
         actionCollection()->addAction ( QLatin1String ( "edit_duplicate_operation" ), duplicateAction );
         duplicateAction->setShortcut ( Qt::CTRL+Qt::Key_D );
 
         if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction ( "edit_duplicate_operation", duplicateAction );
 
-        createTemplateAction = new KAction ( KIcon ( "skrooge_template" ), i18n ( "&Create template" ), this );
+        createTemplateAction = new KAction ( KIcon ( "skrooge_template" ), i18nc ("Verb", "Create template" ), this );
         connect ( createTemplateAction, SIGNAL ( triggered ( bool ) ), this, SLOT ( actionCreateTemplate() ) );
         actionCollection()->addAction ( QLatin1String ( "edit_template_operation" ), createTemplateAction );
         createTemplateAction->setShortcut ( Qt::CTRL+Qt::SHIFT+Qt::Key_T );
 
         if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction ( "edit_template_operation", createTemplateAction );
 
-        switchToPointedAction = new KAction ( KIcon ( "dialog-ok" ), i18n ( "&Point" ), this );
+        switchToPointedAction = new KAction ( KIcon ( "dialog-ok" ), i18nc ("Verb, mark an object", "Point" ), this );
         connect ( switchToPointedAction, SIGNAL ( triggered ( bool ) ), this, SLOT ( actionSwitchToPointed() ) );
         actionCollection()->addAction ( QLatin1String ( "edit_point_selected_operation" ), switchToPointedAction );
         switchToPointedAction->setShortcut ( Qt::CTRL+Qt::Key_R );
 
         if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction ( "edit_point_selected_operation", switchToPointedAction );
 
-        KAction* fastEditionAction = new KAction ( KIcon ( "games-solve" ), i18n ( "&Fast edit" ), this );
+        KAction* fastEditionAction = new KAction ( KIcon ( "games-solve" ), i18nc ("Verb", "Fast edit" ), this );
         actionCollection()->addAction ( QLatin1String ( "fast_edition" ), fastEditionAction );
         fastEditionAction->setEnabled ( false );
         fastEditionAction->setShortcut ( Qt::Key_F10 );
 
         if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction ( "fast_edition", fastEditionAction );
 
-        KAction* fastEditionWithoutAmountAction = new KAction ( KIcon ( "games-solve" ), i18n ( "&Fast edit without amount" ), this );
-        actionCollection()->addAction ( QLatin1String ( "fast_edition_without_amount" ), fastEditionWithoutAmountAction );
-        fastEditionWithoutAmountAction->setEnabled ( false );
-        fastEditionWithoutAmountAction->setShortcut ( Qt::CTRL+Qt::Key_F10 );
-
-        if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction ( "fast_edition_without_amount", fastEditionWithoutAmountAction );
-
-        switchHighLight = new KAction ( KIcon ( "rating" ), i18n ( "Switch &highlight" ), this );
+        switchHighLight = new KAction ( KIcon ( "rating" ), i18nc ("Verb", "Switch highlight" ), this );
         connect ( switchHighLight, SIGNAL ( triggered ( bool ) ), this, SLOT ( actionSwitchHighLight() ) );
         actionCollection()->addAction ( QLatin1String ( "edit_switch_highlight" ), switchHighLight );
         switchHighLight->setShortcut ( Qt::CTRL+Qt::Key_H );
 
         if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction ( "edit_switch_highlight", switchHighLight );
 
-        openHighLights = new KAction ( KIcon ( "skrooge_open_highlight" ), i18n ( "&Open highlights" ), this );
+        QStringList overlayopen;
+        overlayopen.push_back("skg_open");
+        openHighLights = new KAction(KIcon( "rating", NULL, overlayopen), i18nc ("Verb", "Open highlights..." ), this );
         connect ( openHighLights, SIGNAL ( triggered ( bool ) ), this, SLOT ( actionOpenHighLights() ) );
         actionCollection()->addAction ( QLatin1String ( "view_open_highlight" ), openHighLights );
-        openHighLights->setShortcut ( Qt::CTRL+Qt::SHIFT+Qt::Key_H );
+        openHighLights->setShortcut ( Qt::META+Qt::Key_H );
 
         if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction ( "view_open_highlight", openHighLights );
+
+        openLastModified = new KAction ( KIcon("view-refresh", NULL, overlayopen), i18nc ("Verb", "Open last modified..." ), this);
+        connect ( openLastModified, SIGNAL ( triggered ( bool ) ), this, SLOT ( actionOpenLastModified() ) );
+        actionCollection()->addAction ( QLatin1String ( "view_open_last_modified" ), openLastModified );
+        openLastModified->setShortcut ( Qt::META+Qt::Key_L );
+
+        if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction ( "view_open_last_modified", openLastModified );
+
+        openSuboperations = new KAction ( KIcon("skrooge_split", NULL, overlayopen), i18nc ("Verb", "Open sub operations..." ), this);
+        connect ( openSuboperations, SIGNAL ( triggered ( bool ) ), this, SLOT ( actionOpenSubOperations() ) );
+        actionCollection()->addAction ( QLatin1String ( "view_open_suboperations" ), openSuboperations );
+        openSuboperations->setShortcut ( Qt::META+Qt::Key_S );
+
+        if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction ( "view_open_suboperations", openSuboperations );
+
+        groupOperation = new KAction ( KIcon ( "skrooge_transfer" ), i18nc ("Verb", "Group operations" ), this );
+        connect ( groupOperation, SIGNAL ( triggered ( bool ) ), this, SLOT ( actionGroupOperation() ) );
+        actionCollection()->addAction ( QLatin1String ( "edit_group_operation" ), groupOperation );
+        groupOperation->setShortcut ( Qt::CTRL+Qt::Key_G );
+
+        if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction ( "edit_group_operation", groupOperation );
+
+        QStringList overlay;
+        overlay.push_back("edit-delete");
+        ungroupOperation = new KAction ( KIcon ( "skrooge_transfer", NULL, overlay ), i18nc ("Verb", "Ungroup operations" ), this );
+        connect ( ungroupOperation, SIGNAL ( triggered ( bool ) ), this, SLOT ( actionUngroupOperation() ) );
+        actionCollection()->addAction ( QLatin1String ( "edit_ungroup_operation" ), ungroupOperation );
+        ungroupOperation->setShortcut ( Qt::CTRL+Qt::SHIFT+Qt::Key_G );
+
+        if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction ( "edit_ungroup_operation", ungroupOperation );
 }
 
 void SKGOperationPlugin::refresh()
@@ -122,19 +160,26 @@ void SKGOperationPlugin::refresh()
         if ( currentBankDocument && SKGMainPanel::getMainPanel() ) {
                 bool test=(currentBankDocument->getDatabase()!=NULL);
                 if ( openHighLights ) openHighLights->setEnabled ( test );
+                if ( openLastModified ) openLastModified->setEnabled ( test && currentBankDocument->getNbTransaction()>0 );
 
                 SKGObjectBase::SKGListSKGObjectBase selection=SKGMainPanel::getMainPanel()->getSelectedObjects();
                 if ( selection.count() >0 ) {
-                        bool onOperation= ( selection.at ( 0 ).getRealTable() =="operation" );
+                        bool onOperation= ( selection.at ( 0 ).getRealTable() =="operation" &&  selection.at ( 0 ).getTable()!="v_operation_consolidated");
+                        bool onAccount= ( selection.at ( 0 ).getRealTable() =="account");
+                        bool onRule= ( selection.at ( 0 ).getRealTable() =="rule");
                         if ( duplicateAction ) duplicateAction->setEnabled ( onOperation );
                         if ( createTemplateAction ) createTemplateAction->setEnabled ( onOperation );
-                        if ( switchHighLight ) switchHighLight->setEnabled ( onOperation );
+                        if ( switchHighLight ) switchHighLight->setEnabled ( onOperation || onAccount || onRule);
                         if ( switchToPointedAction ) switchToPointedAction->setEnabled ( onOperation );
+                        if ( groupOperation ) groupOperation->setEnabled ( onOperation && selection.count()>=2);
+                        if ( ungroupOperation ) ungroupOperation->setEnabled ( onOperation );
                 } else {
                         if ( duplicateAction ) duplicateAction->setEnabled ( false );
                         if ( createTemplateAction ) createTemplateAction->setEnabled ( false );
                         if ( switchHighLight ) switchHighLight->setEnabled ( false );
                         if ( switchToPointedAction ) switchToPointedAction->setEnabled ( false );
+                        if ( groupOperation ) groupOperation->setEnabled ( false );
+                        if ( ungroupOperation ) ungroupOperation->setEnabled ( false );
                 }
         }
 }
@@ -146,22 +191,24 @@ void SKGOperationPlugin::close()
 
 int SKGOperationPlugin::getNbDashboardWidgets()
 {
-        return 1;
+        return 2;
 }
 
 QString SKGOperationPlugin::getDashboardWidgetTitle(int iIndex)
 {
-        if (iIndex==0) return i18n("Income && Expenditure");
+        if (iIndex==0) return i18nc("Noun, the title of a section", "Income && Expenditure");
+        else if (iIndex==1) return i18nc("Noun, the title of a section", "Highlighted operations");
         return "";
 }
 
 SKGWidget* SKGOperationPlugin::getDashboardWidget(int iIndex)
 {
         if (iIndex==0) return new SKGOperationBoardWidget(currentBankDocument);
+        else if (iIndex==1) return new SKGBookmarkBoardWidget(currentBankDocument);
         return NULL;
 }
 
-SKGTabWidget* SKGOperationPlugin::getWidget()
+SKGTabPage* SKGOperationPlugin::getWidget()
 {
         SKGTRACEIN ( 10, "SKGOperationPlugin::getWidget" );
         return new SKGOperationPluginWidget(( SKGDocumentBank* ) currentBankDocument);
@@ -182,7 +229,7 @@ KConfigSkeleton* SKGOperationPlugin::getPreferenceSkeleton()
 
 QString SKGOperationPlugin::title() const
 {
-        return i18n ( "Operations" );
+        return i18nc("Noun", "Operations" );
 }
 
 QString SKGOperationPlugin::icon() const
@@ -190,14 +237,9 @@ QString SKGOperationPlugin::icon() const
         return "view-pim-tasks";
 }
 
-QString SKGOperationPlugin::statusTip () const
-{
-        return i18n ( "Operation management (creation, update, ...)" );
-}
-
 QString SKGOperationPlugin::toolTip () const
 {
-        return i18n ( "Operation management" );
+        return i18nc("Noun", "Operation management" );
 }
 
 
@@ -209,11 +251,12 @@ int SKGOperationPlugin::getOrder() const
 QStringList SKGOperationPlugin::tips() const
 {
         QStringList output;
-        output.push_back ( i18n ( "<p>... you can press <strong>+</strong>, <strong>-</strong>, <strong>CTRL +</strong> or <strong>CTRL -</strong> to quickly change dates.</p>" ) );
-        output.push_back ( i18n ( "<p>... you can update many operations in one shot.</p>" ) );
-        output.push_back ( i18n ( "<p>... you can double click on an operation to show or edit sub operations.</p>" ) );
-        output.push_back ( i18n ( "<p>... you can duplicate an operation including complex operations (split, grouped, ...).</p>" ) );
-        output.push_back ( i18n ( "<p>... you can create template of operations.</p>" ) );
+        output.push_back(i18nc("Description of a tips", "<p>... you can press <strong>+</strong>, <strong>-</strong>, <strong>CTRL +</strong> or <strong>CTRL -</strong> to quickly change dates.</p>" ) );
+        output.push_back(i18nc("Description of a tips", "<p>... you can update many operations in one shot.</p>" ) );
+        output.push_back(i18nc("Description of a tips", "<p>... you can double click on an operation to show or edit sub operations.</p>" ) );
+        output.push_back(i18nc("Description of a tips", "<p>... you can duplicate an operation including complex operations (split, grouped, ...).</p>" ) );
+        output.push_back(i18nc("Description of a tips", "<p>... you can create template of operations.</p>" ) );
+        output.push_back(i18nc("Description of a tips", "<p>... you can group and ungroup operations.</p>" ) );
         return output;
 }
 
@@ -222,6 +265,69 @@ bool SKGOperationPlugin::isInContext() const
         return true;
 }
 
+void SKGOperationPlugin::actionGroupOperation()
+{
+        SKGError err;
+        SKGTRACEINRC ( 10, "SKGOperationPlugin::actionGroupOperation",err );
+        //Get Selection
+        if ( SKGMainPanel::getMainPanel() && currentBankDocument ) {
+                SKGObjectBase::SKGListSKGObjectBase selection=SKGMainPanel::getMainPanel()->getSelectedObjects();
+                int nb=selection.count();
+                if (nb>=2) {
+                        SKGBEGINPROGRESSTRANSACTION(*currentBankDocument, i18nc("Noun, name of the user action","Group operations" ), err, nb );
+                        QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
+                        SKGOperationObject main=selection.at(0);
+                        if ( err.isSucceeded() ) err=currentBankDocument->stepForward(1);
+                        for ( int i=1; err.isSucceeded() && i<nb; ++i ) {
+                                SKGOperationObject operationObj=selection.at(i);
+                                if ( err.isSucceeded() ) err=operationObj.setGroupOperation(main);
+                                if ( err.isSucceeded() ) err=operationObj.save();
+
+                                if ( err.isSucceeded() ) err=currentBankDocument->stepForward ( i+1 );
+                        }
+                        QApplication::restoreOverrideCursor();
+                }
+
+                //status bar
+                if ( err.isSucceeded() ) err=SKGError(0, i18nc("Successful message after an user action", "Operations grouped." ) );
+                else err.addError ( ERR_FAIL, i18nc("Error message",  "Group creation failed" ) );
+
+                //Display error
+                SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
+        }
+}
+
+void SKGOperationPlugin::actionUngroupOperation()
+{
+        SKGError err;
+        SKGTRACEINRC ( 10, "SKGOperationPlugin::actionUngroupOperation",err );
+        //Get Selection
+        if ( SKGMainPanel::getMainPanel() && currentBankDocument ) {
+                SKGObjectBase::SKGListSKGObjectBase selection=SKGMainPanel::getMainPanel()->getSelectedObjects();
+                int nb=selection.count();
+                {
+                        SKGBEGINPROGRESSTRANSACTION(*currentBankDocument, i18nc("Noun, name of the user action","Ungroup operation" ), err, nb );
+
+                        QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
+                        for ( int i=0; err.isSucceeded() && i<nb; ++i ) {
+                                SKGOperationObject operationObj=selection.at ( i );
+                                if ( err.isSucceeded() ) err=operationObj.setGroupOperation(operationObj);
+                                if ( err.isSucceeded() ) err=operationObj.save();
+
+                                if ( err.isSucceeded() ) err=currentBankDocument->stepForward ( i+1 );
+                        }
+                        QApplication::restoreOverrideCursor();
+                }
+
+                //status bar
+                if ( err.isSucceeded() ) err=SKGError(0, i18nc("Successful message after an user action", "Operation ungrouped." ) );
+                else err.addError ( ERR_FAIL, i18nc("Error message",  "Group deletion failed" ) );
+
+                //Display error
+                SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
+        }
+}
+
 void SKGOperationPlugin::actionSwitchToPointed()
 {
         SKGError err;
@@ -231,7 +337,7 @@ void SKGOperationPlugin::actionSwitchToPointed()
                 SKGObjectBase::SKGListSKGObjectBase selection=SKGMainPanel::getMainPanel()->getSelectedObjects();
                 int nb=selection.count();
                 {
-                        SKGBEGINPROGRESSTRANSACTION ( *currentBankDocument, i18n ( "Switch to pointed" ), err, nb );
+                        SKGBEGINPROGRESSTRANSACTION(*currentBankDocument, i18nc("Noun, name of the user action","Switch to pointed" ), err, nb );
 
                         QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
                         for ( int i=0; err.isSucceeded() && i<nb; ++i ) {
@@ -245,8 +351,8 @@ void SKGOperationPlugin::actionSwitchToPointed()
                 }
 
                 //status bar
-                if ( err.isSucceeded() ) err=SKGError ( 0, i18n ( "Operation pointed." ) );
-                else err.addError ( ERR_FAIL, i18n ( "Switch failed" ) );
+                if ( err.isSucceeded() ) err=SKGError(0, i18nc("Successful message after an user action", "Operation pointed." ) );
+                else err.addError ( ERR_FAIL, i18nc("Error message",  "Switch failed" ) );
 
                 //Display error
                 SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
@@ -262,22 +368,36 @@ void SKGOperationPlugin::actionSwitchHighLight()
                 SKGObjectBase::SKGListSKGObjectBase selection=SKGMainPanel::getMainPanel()->getSelectedObjects();
                 int nb=selection.count();
                 {
-                        SKGBEGINPROGRESSTRANSACTION ( *currentBankDocument, i18n ( "Operation highlight" ), err, nb );
+                        SKGBEGINPROGRESSTRANSACTION(*currentBankDocument, i18nc("Noun, name of the user action","Highlight" ), err, nb );
 
                         QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
                         for ( int i=0; err.isSucceeded() && i<nb; ++i ) {
-                                SKGOperationObject operationObj=selection.at ( i );
-                                if ( err.isSucceeded() ) err=operationObj.bookmark ( !operationObj.isBookmarked() );
-                                if ( err.isSucceeded() ) err=operationObj.save();
-
+			        if( selection.at ( i ).getRealTable() =="account")
+				{
+				  SKGAccountObject obj=selection.at ( i );
+				  if ( err.isSucceeded() ) err=obj.bookmark ( !obj.isBookmarked() );
+				  if ( err.isSucceeded() ) err=obj.save();
+				}
+				else if( selection.at ( i ).getRealTable() =="operation")
+				{
+				  SKGOperationObject obj=selection.at ( i );
+				  if ( err.isSucceeded() ) err=obj.bookmark ( !obj.isBookmarked() );
+				  if ( err.isSucceeded() ) err=obj.save();
+				}
+				else if( selection.at ( i ).getRealTable() =="rule")
+				{
+				  SKGRuleObject obj=selection.at ( i );
+				  if ( err.isSucceeded() ) err=obj.bookmark ( !obj.isBookmarked() );
+				  if ( err.isSucceeded() ) err=obj.save();
+				}
                                 if ( err.isSucceeded() ) err=currentBankDocument->stepForward ( i+1 );
                         }
                         QApplication::restoreOverrideCursor();
                 }
 
                 //status bar
-                if ( err.isSucceeded() )  err=SKGError ( 0, i18n ( "Operation highlighted." ) );
-                else err.addError ( ERR_FAIL, i18n ( "Operation highlight failed" ) );
+                if ( err.isSucceeded() )  err=SKGError(0, i18nc("Successful message after an user action", "Highlighted." ) );
+                else err.addError ( ERR_FAIL, i18nc("Error message",  "Highlight failed" ) );
 
                 //Display error
                 SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
@@ -294,7 +414,7 @@ void SKGOperationPlugin::actionDuplicate()
                 SKGObjectBase::SKGListSKGObjectBase selection=SKGMainPanel::getMainPanel()->getSelectedObjects();
                 int nb=selection.count();
                 {
-                        SKGBEGINPROGRESSTRANSACTION ( *currentBankDocument, i18n ( "Duplicate operation" ), err, nb );
+                        SKGBEGINPROGRESSTRANSACTION(*currentBankDocument, i18nc("Noun, name of the user action","Duplicate operation" ), err, nb );
 
                         QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
                         for ( int i=0; err.isSucceeded() && i<nb; ++i ) {
@@ -310,10 +430,10 @@ void SKGOperationPlugin::actionDuplicate()
 
                 //status bar
                 if ( err.isSucceeded() ) {
-                        err=SKGError ( 0, i18n ( "Operation duplicated." ) );
+                        err=SKGError(0, i18nc("Successful message after an user action", "Operation duplicated." ) );
                         SKGOperationPluginWidget* w=dynamic_cast<SKGOperationPluginWidget*>(SKGMainPanel::getMainPanel()->currentTab());
                         if (w) w->getTableView()->selectObjects(listUUID, true);
-                } else err.addError ( ERR_FAIL, i18n ( "Duplicate operation failed" ) );
+                } else err.addError ( ERR_FAIL, i18nc("Error message",  "Duplicate operation failed" ) );
 
                 //Display error
                 SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
@@ -330,7 +450,7 @@ void SKGOperationPlugin::actionCreateTemplate()
                 SKGObjectBase::SKGListSKGObjectBase selection=SKGMainPanel::getMainPanel()->getSelectedObjects();
                 int nb=selection.count();
                 {
-                        SKGBEGINPROGRESSTRANSACTION ( *currentBankDocument, i18n ( "Create template" ), err, nb );
+                        SKGBEGINPROGRESSTRANSACTION(*currentBankDocument, i18nc("Noun, name of the user action","Create template" ), err, nb );
 
                         QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
                         for ( int i=0; err.isSucceeded() && i<nb; ++i ) {
@@ -346,13 +466,13 @@ void SKGOperationPlugin::actionCreateTemplate()
 
                 //status bar
                 if ( err.isSucceeded() ) {
-                        err=SKGError ( 0, i18n ( "Template created." ) );
+                        err=SKGError(0, i18nc("Successful message after an user action", "Template created." ) );
                         SKGOperationPluginWidget* w=dynamic_cast<SKGOperationPluginWidget*>(SKGMainPanel::getMainPanel()->currentTab());
                         if (w) {
                                 w->setTemplateMode(true);
                                 w->getTableView()->selectObjects(listUUID, true);
                         }
-                } else err.addError ( ERR_FAIL, i18n ( "Creation template failed" ) );
+                } else err.addError ( ERR_FAIL, i18nc("Error message",  "Creation template failed" ) );
 
                 //Display error
                 SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
@@ -363,17 +483,18 @@ void SKGOperationPlugin::actionOpenHighLights()
 {
         SKGTRACEIN ( 10, "SKGOperationPlugin::actionOpenHighLights");
         QString wc="t_bookmarked='Y'";
-        QString title=i18n ( "Highlighted operations" );
+        QString title=i18nc("Noun, a list of items", "Highlighted operations" );
 
         //Call operation plugin
         QDomDocument doc("SKGML");
-        doc.setContent ( currentBankDocument->getParameter("SKGOPERATION_DEFAULT_PARAMETERS") );
+        if(currentBankDocument) doc.setContent ( currentBankDocument->getParameter("SKGOPERATION_DEFAULT_PARAMETERS") );
         QDomElement root = doc.documentElement();
         if (root.isNull()) {
                 root=doc.createElement("parameters");
                 doc.appendChild(root);
         }
 
+        root.setAttribute ( "account", i18nc("For all accounts", "All") );
         root.setAttribute ( "operationTable", "v_operation_display" );
         root.setAttribute ( "operationWhereClause", wc );
         root.setAttribute ( "title", title );
@@ -382,4 +503,48 @@ void SKGOperationPlugin::actionOpenHighLights()
         if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->setNewTabContent ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge operation plugin" ), -1, doc.toString() );
 }
 
+void SKGOperationPlugin::actionOpenLastModified()
+{
+        SKGTRACEIN ( 10, "SKGOperationPlugin::actionOpenLastModified");
+        QString wc="id in (SELECT i_object_id FROM doctransactionitem di, doctransaction dt WHERE dt.t_mode='U' AND dt.id=di.rd_doctransaction_id AND di.t_object_table='operation'AND (select count(1) from doctransaction B where B.i_parent=dt.id)=0)";
+        QString title=i18nc("Noun, a list of items", "Operations modified or created during last action" );
+
+        //Call operation plugin
+        QDomDocument doc("SKGML");
+        if(currentBankDocument) doc.setContent ( currentBankDocument->getParameter("SKGOPERATION_DEFAULT_PARAMETERS") );
+        QDomElement root = doc.documentElement();
+        if (root.isNull()) {
+                root=doc.createElement("parameters");
+                doc.appendChild(root);
+        }
+
+        root.setAttribute ( "account", i18nc("For all accounts", "All") );
+	root.setAttribute ( "operationTable", "v_operation_display" );
+        root.setAttribute ( "operationWhereClause", wc );
+        root.setAttribute ( "title", title );
+        root.setAttribute ( "title_icon", "rating" );
+
+        if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->setNewTabContent ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge operation plugin" ), -1, doc.toString() );
+}
+
+void SKGOperationPlugin::actionOpenSubOperations()
+{
+        SKGTRACEIN ( 10, "SKGOperationPlugin::actionOpenLastModified");
+        //Call operation plugin
+        QDomDocument doc("SKGML");
+        if(currentBankDocument) doc.setContent ( currentBankDocument->getParameter("SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS") );
+        QDomElement root = doc.documentElement();
+        if (root.isNull()) {
+                root=doc.createElement("parameters");
+                doc.appendChild(root);
+        }
+
+        root.setAttribute ( "account", i18nc("For all accounts", "All") );
+	root.setAttribute ( "operationTable", "v_operation_consolidated" );
+        root.setAttribute ( "operationWhereClause", "" );
+        root.setAttribute ( "title", i18nc("Noun, a list of items", "Sub operations") );
+        root.setAttribute ( "title_icon", icon() );
+
+        if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->setNewTabContent ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge operation plugin" ), -1, doc.toString() );
+}
 #include "skgoperationplugin.moc"
