@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,7 +22,7 @@
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
 #include "ui_skgoperationpluginwidget_base.h"
-#include "skgtabwidget.h"
+#include "skgtabpage.h"
 #include "skgoperationobject.h"
 #include "skgsuboperationobject.h"
 
@@ -35,10 +35,11 @@ class KAction;
 /**
  * This file is Skrooge plugin for operation management
  */
-class SKGOperationPluginWidget : public SKGTabWidget
+class SKGOperationPluginWidget : public SKGTabPage
 {
         Q_OBJECT
 
+
 public:
         /**
          * Default Constructor
@@ -108,13 +109,17 @@ public:
          */
         static void openOperation(const SKGOperationObject& iOperation);
 
-public slots:
+protected:
         /**
-        * Refresh the content.
+         * Event filtering
+         * @param object object
+         * @param event event
+         * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
          */
-        virtual void refresh();
+        virtual bool eventFilter ( QObject *object, QEvent *event );
 
 private slots:
+        void dataModified(const QString& iTableName, int iIdTransaction);
         void onOperationCreatorModified();
         void onAddOperationClicked();
         void onUpdateOperationClicked();
@@ -126,7 +131,7 @@ private slots:
         void onDoubleClick();
         void onQuantityChanged();
         void onSubopCellChanged ( int row,int column );
-        void onRemoveSubOperation();
+        void onRemoveSubOperation(int iRow=-1);
         void onRefreshInformationZone();
         void onRotateAccountTools();
         void onValidatePointedOperations();
@@ -139,12 +144,15 @@ private:
 
         SKGError getSelectedOperation ( SKGOperationObject& operation );
 
+        bool isWidgetEditionEnabled(QWidget* iWidget);
+        void setWidgetEditionEnabled(QWidget* iWidget, bool iEnabled);
+        void setAllWidgetsEnabled();
 
         bool isTemplateMode();
         int getCurrentMode();
         void setCurrentMode(int iMode);
         void displaySubOperations();
-        void displaySubOperations ( const SKGOperationObject& iOperation );
+        void displaySubOperations ( const SKGOperationObject& iOperation , bool iKeepId=true);
         double getRemainingQuantity();
         void addSubOperationLine ( int row, const QString& category, const QString& tracker, const QString& comment, double quantity, int id=0 );
         SKGError updateSelection ( const SKGObjectBase::SKGListSKGObjectBase& iSelection, bool forceCreation=false);
@@ -154,10 +162,10 @@ private:
         Ui::skgoperationplugin_base ui;
         SKGObjectModel* objectModel;
         QString operationWhereClause;
+	QString previousValue;
         QDomDocument lastState;
 
         KAction* fastEditionAction;
-        KAction* fastEditionWthoutAmountAction;
 
         QString lastFastEditionWhereClause;
         int lastFastEditionOperationFound;
@@ -167,6 +175,8 @@ private:
         int modeInfoZone;
         int mode;
         bool modeTemplate;
+	QKeySequence deleteShortcut;
+        QString frozen_logo;
 };
 
 #endif // SKGOPERATIONPLUGINWIDGET_H
