@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -32,7 +32,13 @@
 #include <QPrintPreviewDialog>
 #include <QPainter>
 
+/**
+ * This plugin factory.
+ */
 K_PLUGIN_FACTORY(SKGPrintPluginFactory, registerPlugin<SKGPrintPlugin>();)
+/**
+ * This plugin export.
+ */
 K_EXPORT_PLUGIN(SKGPrintPluginFactory("skrooge_print", "skrooge_print"))
 
 SKGPrintPlugin::SKGPrintPlugin(QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
@@ -83,7 +89,7 @@ void SKGPrintPlugin::close()
         SKGTRACEIN(10, "SKGPrintPlugin::close");
 }
 
-SKGTabWidget* SKGPrintPlugin::getWidget()
+SKGTabPage* SKGPrintPlugin::getWidget()
 {
         SKGTRACEIN(10, "SKGPrintPlugin::getWidget");
         return NULL;
@@ -114,11 +120,6 @@ QString SKGPrintPlugin::icon() const
         return "printer";
 }
 
-QString SKGPrintPlugin::statusTip () const
-{
-        return i18nc("Verb, action to use a printer","print");
-}
-
 QString SKGPrintPlugin::toolTip () const
 {
         return i18nc("Verb, action to use a printer","print");
@@ -132,7 +133,7 @@ int SKGPrintPlugin::getOrder() const
 QStringList SKGPrintPlugin::tips() const
 {
         QStringList output;
-        output.push_back(i18n("<p>... you can print all opened pages.</p>"));
+        output.push_back(i18nc("Description of a tips", "<p>... you can print all opened pages.</p>"));
         return output;
 }
 
@@ -173,12 +174,12 @@ void SKGPrintPlugin::print(QPrinter * iPrinter)
                 SKGError err;
                 QPainter painter;
                 if (!painter.begin(iPrinter)) {
-                        err=SKGError(ERR_FAIL, i18n("Printer initialisation failed"));
+                        err=SKGError(ERR_FAIL, i18nc("Error message", "Printer initialization failed"));
                 } else {
                         KTabWidget* tabs=(KTabWidget*) SKGMainPanel::getMainPanel()->centralWidget();
                         int nbpages=tabs->count();
                         for (int i=0; i<nbpages; ++i) {
-                                SKGTabWidget* page=(SKGTabWidget*) tabs->widget(i);
+                                SKGTabPage* page=(SKGTabPage*) tabs->widget(i);
                                 if (page) {
                                         QWidget* widget=page->getWidgetForPrint();
                                         if (widget) {
@@ -196,7 +197,7 @@ void SKGPrintPlugin::print(QPrinter * iPrinter)
 
                                                 if (i<nbpages-1) {
                                                         if (!iPrinter->newPage()) {
-                                                                err=SKGError(ERR_FAIL, i18n("Creation of new page failed"));
+                                                                err=SKGError(ERR_FAIL, i18nc("Error message", "Creation of new page failed"));
                                                         }
                                                 }
                                         }
@@ -206,8 +207,8 @@ void SKGPrintPlugin::print(QPrinter * iPrinter)
                 }
 
                 //status bar
-                if (err.isSucceeded()) err=SKGError(0, i18n("Print successfully done."));
-                else err.addError(ERR_FAIL, i18n("Print failed"));
+                if (err.isSucceeded()) err=SKGError(0, i18nc("Successful message after an user action", "Print successfully done."));
+                else err.addError(ERR_FAIL, i18nc("Error message", "Print failed"));
 
 
                 //Display error
