@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -29,7 +29,13 @@
 #include <kactioncollection.h>
 #include <kstandardaction.h>
 
+/**
+ * This plugin factory.
+ */
 K_PLUGIN_FACTORY(SKGPropertiesPluginFactory, registerPlugin<SKGPropertiesPlugin>();)
+/**
+ * This plugin export.
+ */
 K_EXPORT_PLUGIN(SKGPropertiesPluginFactory("skrooge_properties", "skrooge_properties"))
 
 SKGPropertiesPlugin::SKGPropertiesPlugin(QObject* iParent, const QVariantList& /*iArg*/) :
@@ -99,14 +105,9 @@ QString SKGPropertiesPlugin::icon() const
         return "dialog-information";
 }
 
-QString SKGPropertiesPlugin::statusTip () const
-{
-        return i18n("Manage properties");
-}
-
 QString SKGPropertiesPlugin::toolTip () const
 {
-        return i18n("Manage properties");
+        return i18nc("A tool tip", "Properties management");
 }
 
 int SKGPropertiesPlugin::getOrder() const
@@ -117,7 +118,7 @@ int SKGPropertiesPlugin::getOrder() const
 QStringList SKGPropertiesPlugin::tips() const
 {
         QStringList output;
-        output.push_back(i18n("<p>... you can manage properties on all objects (operations, accounts, etc.)</p>"));
+        output.push_back(i18nc("Description of a tips", "<p>... you can manage properties on all objects (operations, accounts, etc.)</p>"));
         return output;
 }
 
