@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -34,7 +34,7 @@
 #include <QFile>
 
 SKGPropertiesPluginDockWidget::SKGPropertiesPluginDockWidget(SKGDocument* iDocument)
-                :SKGTabWidget(iDocument)
+                :SKGTabPage(iDocument)
 {
         SKGTRACEIN(1, "SKGPropertiesPluginDockWidget::SKGPropertiesPluginDockWidget");
 
@@ -54,7 +54,6 @@ SKGPropertiesPluginDockWidget::SKGPropertiesPluginDockWidget(SKGDocument* iDocum
 
         ui.kFilterEdit->setProxy(modelproxy);
 
-        ui.kView->setWindowTitle(i18nc("Noun, an item's properties","Properties"));
         ui.kView->setDefaultSaveParameters(getDocument(), "SKG_DEFAULT_PROPERTIES");
 
         connect(ui.kView, SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionChanged()));
@@ -182,11 +181,11 @@ void SKGPropertiesPluginDockWidget::onAddProperty()
                 if (file.exists()) {
                         //Value is a file name ==> blob
                         if (!file.open(QIODevice::ReadOnly)) {
-                                err=SKGError(ERR_INVALIDARG, i18n("Open file [%1] failed", value));
+                                err=SKGError(ERR_INVALIDARG, i18nc("Error message", "Open file [%1] failed", value));
                         } else {
                                 QByteArray blob_bytes=file.readAll();
                                 if (!blob_bytes.count()) {
-                                        err=SKGError(ERR_INVALIDARG, i18n("Open file [%1] failed", value));
+                                        err=SKGError(ERR_INVALIDARG, i18nc("Error message", "Open file [%1] failed", value));
                                 } else {
                                         blob=blob_bytes;
                                         value=QFileInfo(value).fileName();
@@ -201,7 +200,7 @@ void SKGPropertiesPluginDockWidget::onAddProperty()
                 if (err.isSucceeded()) {
                         SKGObjectBase::SKGListSKGObjectBase selection=SKGMainPanel::getMainPanel()->getSelectedObjects();
                         int nb=selection.count();
-                        SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18n("Property creation"), err, nb);
+                        SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Property creation"), err, nb);
                         for (int i=0; err.isSucceeded() && i<nb; ++i) {
                                 SKGObjectBase prop;
                                 err=selection[i].setProperty(name, value, blob, &prop);
@@ -217,7 +216,7 @@ void SKGPropertiesPluginDockWidget::onAddProperty()
 
         //status bar
         if (err.isSucceeded()) {
-                err=SKGError(0, i18n("Property created"));
+                err=SKGError(0, i18nc("Successful message after an user action", "Property created"));
                 ui.kView->selectObjects(listUUID, true);
         }
         SKGMainPanel::getMainPanel()->displayErrorMessage(err);
@@ -243,8 +242,8 @@ void SKGPropertiesPluginDockWidget::onRemoveProperty()
         }
 
         //status bar
-        if (err.isSucceeded()) err=SKGError(0, i18n("Properties deleted."));
-        else err.addError(ERR_FAIL, i18n("Delete failed"));
+        if (err.isSucceeded()) err=SKGError(0, i18nc("Successful message after an user action", "Properties deleted."));
+        else err.addError(ERR_FAIL, i18nc("Error message", "Delete failed"));
         QApplication::restoreOverrideCursor();
 
         //Display error
