@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,12 +22,12 @@
 * @author Stephane MANKOWSKI
 */
 #include "ui_skgpropertiesplugindockwidget_base.h"
-#include "skgtabwidget.h"
+#include "skgtabpage.h"
 
 /**
  * A skrooge plugin to manage properties on objects
  */
-class SKGPropertiesPluginDockWidget : public SKGTabWidget
+class SKGPropertiesPluginDockWidget : public SKGTabPage
 {
         Q_OBJECT
 
