@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -29,13 +29,21 @@
 #include "skgtrackerobject.h"
 #include "skgunitobject.h"
 #include "skgruleobject.h"
+#include "skgnodeobject.h"
+#include "skgreportboardwidget.h"
 
 #include <kaction.h>
 #include <kactioncollection.h>
 
 #include <QDomDocument>
 
+/**
+ * This plugin factory.
+ */
 K_PLUGIN_FACTORY ( SKGReportPluginFactory, registerPlugin<SKGReportPlugin>(); )
+/**
+ * This plugin export.
+ */
 K_EXPORT_PLUGIN ( SKGReportPluginFactory ( "skrooge_report", "skrooge_report" ) )
 
 SKGReportPlugin::SKGReportPlugin ( QObject* iParent, const QVariantList& /*iArg*/ ) : SKGInterfacePlugin ( iParent )
@@ -62,10 +70,12 @@ void SKGReportPlugin::setupActions ( SKGDocument* iDocument, const QStringList&
         setXMLFile ( "skrooge_report.rc" );
 
         //Menu
-        openReportAction = new KAction ( KIcon ( "skrooge_open_report" ), i18n ( "Open &report" ), this );
+        QStringList overlayopen;
+        overlayopen.push_back("skg_open");
+        openReportAction = new KAction ( KIcon ( "view-statistics", NULL, overlayopen), i18nc ("Verb", "Open report..." ), this );
         connect ( openReportAction, SIGNAL ( triggered ( bool ) ), this, SLOT ( actionOpenReport() ) );
         actionCollection()->addAction ( QLatin1String ( "open_report" ), openReportAction );
-        openReportAction->setShortcut ( Qt::CTRL+Qt::Key_G );
+        openReportAction->setShortcut ( Qt::META+Qt::Key_R );
 
         if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction ( "open_report", openReportAction );
 }
@@ -91,7 +101,24 @@ void SKGReportPlugin::close()
         SKGTRACEIN ( 10, "SKGReportPlugin::close" );
 }
 
-SKGTabWidget* SKGReportPlugin::getWidget()
+int SKGReportPlugin::getNbDashboardWidgets()
+{
+        return 1;
+}
+
+QString SKGReportPlugin::getDashboardWidgetTitle(int iIndex)
+{
+	if(iIndex==0) return i18nc("Noun, the title of a section", "Report");
+        return "";
+}
+
+SKGWidget* SKGReportPlugin::getDashboardWidget(int iIndex)
+{
+        if (iIndex==0) return new SKGReportBoardWidget(currentBankDocument);
+        return NULL;
+}
+
+SKGTabPage* SKGReportPlugin::getWidget()
 {
         SKGTRACEIN ( 10, "SKGReportPlugin::getWidget" );
         return new SKGReportPluginWidget ( ( SKGDocumentBank* ) currentBankDocument );
@@ -99,7 +126,7 @@ SKGTabWidget* SKGReportPlugin::getWidget()
 
 QString SKGReportPlugin::title() const
 {
-        return i18n ( "Report" );
+        return i18nc("Noun", "Report" );
 }
 
 QString SKGReportPlugin::icon() const
@@ -107,14 +134,9 @@ QString SKGReportPlugin::icon() const
         return "view-statistics";
 }
 
-QString SKGReportPlugin::statusTip () const
-{
-        return i18n ( "Generate report" );
-}
-
 QString SKGReportPlugin::toolTip () const
 {
-        return i18n ( "Generate report" );
+        return i18nc("Noun", "Generate report" );
 }
 
 int SKGReportPlugin::getOrder() const
@@ -125,9 +147,9 @@ int SKGReportPlugin::getOrder() const
 QStringList SKGReportPlugin::tips() const
 {
         QStringList output;
-        output.push_back ( i18n ( "<p>... you can double click on a value in \"%1\" to show corresponding operations.</p>", title() ) );
-        output.push_back ( i18n ( "<p>... you can open reports for selections made in other pages.</p>" ) );
-        output.push_back ( i18n ( "<p>... you can export reports in many formats.</p>" ) );
+        output.push_back(i18nc("Description of a tips", "<p>... you can double click on a value in \"%1\" to show corresponding operations.</p>", title() ) );
+        output.push_back(i18nc("Description of a tips", "<p>... you can open reports for selections made in other pages.</p>" ) );
+        output.push_back(i18nc("Description of a tips", "<p>... you can export reports in many formats.</p>" ) );
         return output;
 }
 
@@ -150,7 +172,7 @@ void SKGReportPlugin::actionOpenReport()
                         QString table=selection.at ( 0 ).getRealTable();
                         if ( table=="account" ) {
                                 wc="rd_account_id in (";
-                                title=i18n ( "Operations of account " );
+                                title=i18nc("Noun, a list of items", "Operations of account " );
 
                                 for ( int i=0; i<nb; ++i ) {
                                         SKGAccountObject tmp=selection.at ( i );
@@ -164,7 +186,7 @@ void SKGReportPlugin::actionOpenReport()
                                 wc+=')';
                         } else if ( table=="unit" ) {
                                 wc="rc_unit_id in (";
-                                title=i18n ( "Operations with Unit equal to " );
+                                title=i18nc("Noun, a list of items", "Operations with Unit equal to " );
 
                                 for ( int i=0; i<nb; ++i ) {
                                         SKGUnitObject tmp=selection.at ( i );
@@ -179,7 +201,7 @@ void SKGReportPlugin::actionOpenReport()
                         } else if ( table=="category" ) {
                                 wc="t_REALCATEGORY in (";
                                 QString wc2;
-                                title=i18n ( "Operations with Category equal to " );
+                                title=i18nc("Noun, a list of items", "Operations with Category equal to " );
 
                                 for ( int i=0; i<nb; ++i ) {
                                         SKGCategoryObject tmp=selection.at ( i );
@@ -195,7 +217,7 @@ void SKGReportPlugin::actionOpenReport()
                                 wc+=") OR "+wc2;
                         } else if ( table=="refund" ) {
                                 wc="r_refund_id in (";
-                                title=i18n ( "Operations followed by " );
+                                title=i18nc("Noun, a list of items", "Operations followed by " );
 
                                 for ( int i=0; i<nb; ++i ) {
                                         SKGTrackerObject tmp=selection.at ( i );
@@ -209,7 +231,7 @@ void SKGReportPlugin::actionOpenReport()
                                 wc+=')';
                         } else if ( table=="operation" ) {
                                 wc="id in (";
-                                title=i18n ( "Selected operations" );
+                                title=i18nc("Noun, a list of items", "Selected operations" );
 
                                 for ( int i=0; i<nb; ++i ) {
                                         if ( i ) {
@@ -219,7 +241,7 @@ void SKGReportPlugin::actionOpenReport()
                                 }
                                 wc+=')';
                         } else if ( table=="rule" ) {
-                                title=i18n ( "Operations corresponding to rule " );
+                                title=i18nc("Noun, a list of items", "Operations corresponding to rule " );
 
                                 for ( int i=0; i<nb; ++i ) {
                                         SKGRuleObject tmp=selection.at ( i );
