@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -61,6 +61,26 @@ public:
          */
         virtual void close();
 
+        /**
+         * The number of dashboard widgets of the plugin.
+         * @return The number of dashboard widgets of the plugin
+         */
+        virtual int getNbDashboardWidgets();
+
+        /**
+         * Get a dashboard widget title of the plugin.
+         * @param iIndex the index of the widget
+         * @return The title
+         */
+        virtual QString getDashboardWidgetTitle(int iIndex);
+
+        /**
+         * Get a dashboard widget of the plugin.
+         * @param iIndex the index of the widget
+         * @return The dashboard widget of the plugin
+         */
+        virtual SKGWidget* getDashboardWidget(int iIndex);
+
         /**
          * Must be modified to refresh widgets after a modification.
          */
@@ -70,7 +90,7 @@ public:
          * The context widget of the plugin.
          * @return The context widget of the plugin
          */
-        virtual SKGTabWidget* getWidget();
+        virtual SKGTabPage* getWidget();
 
         /**
          * The title of the plugin.
@@ -84,12 +104,6 @@ public:
          */
         virtual QString icon() const;
 
-        /**
-         * The statusTip of the plugin.
-         * @return The toolTip of the plugin
-         */
-        virtual QString statusTip () const;
-
         /**
          * The toolTip of the plugin.
          * @return The toolTip of the plugin
@@ -121,8 +135,6 @@ private:
         Q_DISABLE_COPY(SKGReportPlugin);
 
         KAction *openReportAction;
-
-
         SKGDocument* currentBankDocument;
 };
 
