@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -33,7 +33,13 @@
 #include <kactioncollection.h>
 #include <kstandardaction.h>
 
+/**
+ * This plugin factory.
+ */
 K_PLUGIN_FACTORY ( SKGScheduledPluginFactory, registerPlugin<SKGScheduledPlugin>(); )
+/**
+ * This plugin export.
+ */
 K_EXPORT_PLUGIN ( SKGScheduledPluginFactory ( "skrooge_scheduled", "skrooge_scheduled" ) )
 
 SKGScheduledPlugin::SKGScheduledPlugin ( QObject* iParent, const QVariantList& /*iArg*/ ) : SKGInterfacePlugin ( iParent )
@@ -60,7 +66,7 @@ void SKGScheduledPlugin::setupActions ( SKGDocument* iDocument, const QStringLis
         setXMLFile ( "skrooge_scheduled.rc" );
 
         //Create yours actions here
-        scheduleOperationAction = new KAction ( KIcon ( "skrooge_schedule" ), i18n ( "&Schedule" ), this );
+        scheduleOperationAction = new KAction ( KIcon ( "skrooge_schedule" ), i18nc ("Verb, create a scheduled operation", "Schedule" ), this );
         connect ( scheduleOperationAction, SIGNAL ( triggered ( bool ) ), this, SLOT ( actionScheduleOperation() ) );
         actionCollection()->addAction ( QLatin1String ( "schedule_operation" ), scheduleOperationAction );
         scheduleOperationAction->setShortcut ( Qt::CTRL+Qt::Key_I );
@@ -75,7 +81,7 @@ void SKGScheduledPlugin::refresh()
                 SKGObjectBase::SKGListSKGObjectBase selection=SKGMainPanel::getMainPanel()->getSelectedObjects();
 
                 if ( selection.count() >0 ) {
-                        bool onOperation= ( selection.at ( 0 ).getRealTable() =="operation" );
+                        bool onOperation= ( selection.at ( 0 ).getRealTable() =="operation" &&  selection.at ( 0 ).getTable()!="v_operation_consolidated");
                         if ( scheduleOperationAction ) scheduleOperationAction->setEnabled ( onOperation );
                 } else {
                         if ( scheduleOperationAction ) scheduleOperationAction->setEnabled ( false );
@@ -89,12 +95,10 @@ void SKGScheduledPlugin::refresh()
 
                                 SKGError err;
                                 //Read Setting
-                                KSharedConfigPtr config=KSharedConfig::openConfig ( "skrooge_scheduledrc" );
-                                KConfigGroup pref=config->group ( "skrooge_scheduled" );
-                                bool check_on_open = pref.readEntry ( "check_on_open",true );
+                                bool check_on_open = skgscheduled_settings::check_on_open();
 
                                 if ( check_on_open ) {
-                                        SKGBEGINTRANSACTION ( *currentBankDocument, i18n ( "Insert recurrent operations" ), err );
+                                        SKGBEGINTRANSACTION ( *currentBankDocument, i18nc("Noun, name of the user action", "Insert recurrent operations" ), err );
 
                                         QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
                                         int nbi=0;
@@ -120,7 +124,7 @@ int SKGScheduledPlugin::getNbDashboardWidgets()
 
 QString SKGScheduledPlugin::getDashboardWidgetTitle(int iIndex)
 {
-        if (iIndex==0) return i18n("Scheduled operations");
+        if (iIndex==0) return i18nc("Noun, the title of a section", "Scheduled operations");
         return "";
 }
 
@@ -130,7 +134,7 @@ SKGWidget* SKGScheduledPlugin::getDashboardWidget(int iIndex)
         return NULL;
 }
 
-SKGTabWidget* SKGScheduledPlugin::getWidget()
+SKGTabPage* SKGScheduledPlugin::getWidget()
 {
         SKGTRACEIN ( 10, "SKGScheduledPlugin::getWidget" );
         return new SKGScheduledPluginWidget ( ( SKGDocumentBank* ) currentBankDocument );
@@ -151,7 +155,7 @@ KConfigSkeleton* SKGScheduledPlugin::getPreferenceSkeleton()
 
 QString SKGScheduledPlugin::title() const
 {
-        return i18n ( "Scheduled" );
+        return i18nc("Noun", "Scheduled operations" );
 }
 
 QString SKGScheduledPlugin::icon() const
@@ -159,17 +163,11 @@ QString SKGScheduledPlugin::icon() const
         return "chronometer";
 }
 
-QString SKGScheduledPlugin::statusTip () const
-{
-        return i18n ( "Manage scheduled operations" );
-}
-
 QString SKGScheduledPlugin::toolTip () const
 {
-        return i18n ( "Manage scheduled operations" );//MUST BE CHANGED
+        return i18nc("Noun", "Operations scheduled management" );
 }
 
-
 int SKGScheduledPlugin::getOrder() const
 {
         return 20;
@@ -178,7 +176,7 @@ int SKGScheduledPlugin::getOrder() const
 QStringList SKGScheduledPlugin::tips() const
 {
         QStringList output;
-        output.push_back ( i18n ( "<p>... you can schedule operations or templates.</p>" ) );
+        output.push_back(i18nc("Description of a tips", "<p>... you can schedule operations or templates.</p>" ) );
         return output;
 }
 
@@ -192,6 +190,43 @@ bool SKGScheduledPlugin::isEnabled() const
         return true;
 }
 
+SKGError SKGScheduledPlugin::savePreferences() const
+{
+        SKGError err;
+        if ( currentBankDocument ) {
+                //Read Setting
+                if (skgscheduled_settings::create_template()) {
+                        SKGObjectBase::SKGListSKGObjectBase recurrents;
+                        err=SKGObjectBase::getObjects(currentBankDocument, "v_recurrentoperation", "(select count(1) from operation where operation.id=rd_operation_id and t_template='N')=1", recurrents);
+                        int nb=recurrents.count();
+                        if (nb) {
+                                SKGBEGINPROGRESSTRANSACTION(*currentBankDocument, i18nc("Noun, name of the user action", "Conversion schedule" ), err, nb );
+                                for ( int i=0; err.isSucceeded() && i<nb; ++i ) {
+                                        //Migration of existing schedule in template mode
+                                        SKGRecurrentOperationObject recOp=recurrents.at(i);
+                                        SKGOperationObject operationObj;
+
+                                        if (err.isSucceeded()) recOp.getParentOperation(operationObj);
+
+                                        SKGOperationObject operationObjOrig=operationObj;
+                                        if (err.isSucceeded()) err=operationObjOrig.duplicate(operationObj , operationObjOrig.getDate(), true);
+
+                                        if (err.isSucceeded()) err=recOp.setParentOperation(operationObj);
+                                        if (err.isSucceeded()) err=recOp.save();
+                                        if (err.isSucceeded()) err=recOp.load();
+
+                                        if (err.isSucceeded()) err=operationObjOrig.setAttribute("r_recurrentoperation_id", SKGServices::intToString(recOp.getID()));
+                                        if (err.isSucceeded()) err=operationObjOrig.save();
+
+                                        if (err.isSucceeded()) err=currentBankDocument->stepForward ( i+1 );
+                                }
+                                if (err.isSucceeded()) currentBankDocument->sendMessage(i18nc("An information message",  "All scheduled operations have been converted in template"), true);
+                        }
+                }
+        }
+        return err;
+}
+
 void SKGScheduledPlugin::actionScheduleOperation()
 {
         SKGError err;
@@ -203,36 +238,32 @@ void SKGScheduledPlugin::actionScheduleOperation()
                 int nb=selection.count();
                 QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
                 if ( nb && currentBankDocument ) {
-                        SKGBEGINPROGRESSTRANSACTION ( *currentBankDocument, i18n ( "Operation schedule" ), err, nb );
-
-                        KSharedConfigPtr config=KSharedConfig::openConfig("skrooge_scheduledrc");
-                        KConfigGroup pref=config->group("skrooge_scheduled");
-
+                        SKGBEGINPROGRESSTRANSACTION(*currentBankDocument, i18nc("Noun, name of the user action", "Operation schedule" ), err, nb );
                         for ( int i=0; err.isSucceeded() && i<nb; ++i ) {
                                 SKGOperationObject operationObj=selection.at ( i );
                                 bool isTemplate=operationObj.isTemplate();
 
                                 SKGOperationObject operationObjOrig;
-                                if (!isTemplate && pref.readEntry("create_template",true)) {
+                                if (!isTemplate && skgscheduled_settings::create_template()) {
                                         //The selected operation is not a template and settings is set to create one
                                         operationObjOrig=operationObj;
                                         if (err.isSucceeded()) err=operationObjOrig.duplicate(operationObj , operationObjOrig.getDate(), true);
-                                        if (err.isSucceeded()) currentBankDocument->sendMessage(i18n( "A template has been created"), true);
+                                        if (err.isSucceeded()) currentBankDocument->sendMessage(i18nc("An information message",  "A template has been created"), true);
                                 }
 
                                 SKGRecurrentOperationObject recOp;
                                 err=operationObj.addRecurrentOperation ( recOp );
-                                if (err.isSucceeded()) err=recOp.warnEnabled(pref.readEntry("remind_me",true));
-                                if (err.isSucceeded()) err=recOp.setWarnDays(pref.readEntry("remind_me_days",5));
-                                if (err.isSucceeded()) err=recOp.autoWriteEnabled(pref.readEntry("auto_write",true));
-                                if (err.isSucceeded()) err=recOp.setAutoWriteDays(pref.readEntry("auto_write_days",0));
-                                if (err.isSucceeded()) err=recOp.timeLimit(pref.readEntry("nb_times_val",false));
-                                if (err.isSucceeded()) err=recOp.setTimeLimit(pref.readEntry("nb_times",1));
-                                if (err.isSucceeded()) err=recOp.setPeriodIncrement(pref.readEntry("once_every",1));
-                                if (err.isSucceeded()) err=recOp.setPeriodUnit((SKGRecurrentOperationObject::PeriodUnit) pref.readEntry("once_every_unit",1));
+                                if (err.isSucceeded()) err=recOp.warnEnabled(skgscheduled_settings::remind_me());
+                                if (err.isSucceeded()) err=recOp.setWarnDays(skgscheduled_settings::remind_me_days());
+                                if (err.isSucceeded()) err=recOp.autoWriteEnabled(skgscheduled_settings::auto_write());
+                                if (err.isSucceeded()) err=recOp.setAutoWriteDays(skgscheduled_settings::auto_write_days());
+                                if (err.isSucceeded()) err=recOp.timeLimit(skgscheduled_settings::nb_times_val());
+                                if (err.isSucceeded()) err=recOp.setTimeLimit(skgscheduled_settings::nb_times());
+                                if (err.isSucceeded()) err=recOp.setPeriodIncrement(skgscheduled_settings::once_every());
+                                if (err.isSucceeded()) err=recOp.setPeriodUnit((SKGRecurrentOperationObject::PeriodUnit) SKGServices::stringToInt(skgscheduled_settings::once_every_unit()));
                                 if ( err.isSucceeded() && !isTemplate ) err=recOp.setDate(recOp.getNextDate());
                                 if (err.isSucceeded()) err=recOp.save();
-                                if (!isTemplate && pref.readEntry("create_template",true)) {
+                                if (!isTemplate && skgscheduled_settings::create_template()) {
                                         if (err.isSucceeded()) err=recOp.load();
                                         if (err.isSucceeded()) err=operationObjOrig.setAttribute("r_recurrentoperation_id", SKGServices::intToString(recOp.getID()));
                                         if (err.isSucceeded()) err=operationObjOrig.save();
@@ -243,8 +274,8 @@ void SKGScheduledPlugin::actionScheduleOperation()
                 QApplication::restoreOverrideCursor();
 
                 //status bar
-                if (err.isSucceeded())  err=SKGError ( 0, i18n ( "Operation scheduled." ) );
-                else err.addError ( ERR_FAIL, i18n ( "Operation schedule failed" ) );
+                if (err.isSucceeded())  err=SKGError(0, i18nc("Successful message after an user action", "Operation scheduled." ) );
+                else err.addError ( ERR_FAIL, i18nc("Error message",  "Operation schedule failed" ) );
 
                 //Display error
                 SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
