@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -33,7 +33,13 @@
 #include <kstandardaction.h>
 #include <ktoolbarpopupaction.h>
 
+/**
+ * This plugin factory.
+ */
 K_PLUGIN_FACTORY ( SKGUndoRedoPluginFactory, registerPlugin<SKGUndoRedoPlugin>(); )
+/**
+ * This plugin export.
+ */
 K_EXPORT_PLUGIN ( SKGUndoRedoPluginFactory ( "skrooge_undoredo", "skrooge_undoredo" ) )
 
 SKGUndoRedoPlugin::SKGUndoRedoPlugin ( QObject* iParent, const QVariantList& /*iArg*/ ) : SKGInterfacePlugin ( iParent ), dockWidget ( NULL )
@@ -71,13 +77,13 @@ void SKGUndoRedoPlugin::setupActions ( SKGDocument* iDocument, const QStringList
         dockWidget->setWidget ( new SKGUndoRedoPluginDockWidget ( currentBankDocument ) );
 
         //Menu
-        undoSaveAction = new KAction ( KIcon ( "document-revert" ), i18n ( "Undo &document" ), this );
+        undoSaveAction = new KAction ( KIcon ( "document-revert" ), i18nc ( "Verb, action to cancel previous action", "Undo document" ), this );
         connect ( undoSaveAction, SIGNAL ( triggered ( bool ) ), this, SLOT ( actionUndoSave() ) );
         actionCollection()->addAction ( QLatin1String ( "edit_undolastsave" ), undoSaveAction );
         undoSaveAction->setShortcut ( Qt::CTRL+Qt::ALT+Qt::Key_Z );
         if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction ( "edit_undolastsave", undoSaveAction );
 
-        undoAction = new KToolBarPopupAction ( KIcon ( "edit-undo" ), i18n ( "&Undo" ), this );
+        undoAction = new KToolBarPopupAction ( KIcon ( "edit-undo" ), i18nc ( "Verb, action to cancel previous action", "Undo" ), this );
         connect ( undoAction, SIGNAL ( triggered ( bool ) ), this, SLOT ( actionUndo() ) );
         actionCollection()->addAction ( QLatin1String ( "edit_undo" ), undoAction );
         undoAction->setShortcut ( Qt::CTRL+Qt::Key_Z );
@@ -90,7 +96,7 @@ void SKGUndoRedoPlugin::setupActions ( SKGDocument* iDocument, const QStringList
         //undoAction=KStandardAction::undo(this, SLOT(actionUndo()), actionCollection());
         if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction ( "edit-undo", undoAction );
 
-        redoAction = new KToolBarPopupAction ( KIcon ( "edit-redo" ), i18n ( "&Redo" ), this );
+        redoAction = new KToolBarPopupAction ( KIcon ( "edit-redo" ), i18nc ( "Verb, action to redo previous cancelled action", "Redo" ), this );
         connect ( redoAction, SIGNAL ( triggered ( bool ) ), this, SLOT ( actionRedo() ) );
         actionCollection()->addAction ( QLatin1String ( "edit_redo" ), redoAction );
         redoAction->setShortcut ( Qt::CTRL+Qt::SHIFT+Qt::Key_Z );
@@ -121,12 +127,12 @@ void SKGUndoRedoPlugin::refresh()
                 //Refresh undo redo
                 QString name;
                 currentBankDocument->getTransactionToProcess ( SKGDocument::UNDO, &name );
-                QString message = i18n ( "Undo operation [%1].", name );
+                QString message = i18nc ("Verb",  "Undo operation [%1].", name );
                 if ( !name.length() ) message="";
                 if ( undoAction ) undoAction->setStatusTip ( message );
 
                 currentBankDocument->getTransactionToProcess ( SKGDocument::REDO, &name );
-                message = i18n ( "Redo operation [%1].", name );
+                message = i18nc ("Verb",  "Redo operation [%1].", name );
                 if ( !name.length() ) message="";
                 if ( redoAction ) redoAction->setStatusTip ( message );
         }
@@ -160,10 +166,8 @@ SKGError SKGUndoRedoPlugin::savePreferences() const
         SKGError err;
         if ( currentBankDocument ) {
                 //Read Setting
-                KSharedConfigPtr config=KSharedConfig::openConfig ( "skrooge_undoredorc" );
-                KConfigGroup pref=config->group ( "skrooge_undoredo" );
-                QString max = SKGServices::intToString (pref.readEntry ( "maxNumberOfUndo", 50 ));
-                QString clean = (pref.readEntry ( "cleanHistoryOnSave", false ) ? "Y" : "N");
+                QString max = SKGServices::intToString (skgundoredo_settings::maxNumberOfUndo());
+                QString clean = (skgundoredo_settings::cleanHistoryOnSave() ? "Y" : "N");
 
                 //Save setting in document
                 if ( max!=currentBankDocument->getParameter ( "SKG_UNDO_MAX_DEPTH" ) ) err=currentBankDocument->setParameter ( "SKG_UNDO_MAX_DEPTH", max );
@@ -174,7 +178,7 @@ SKGError SKGUndoRedoPlugin::savePreferences() const
 
 QString SKGUndoRedoPlugin::title() const
 {
-        return i18n ( "History" );
+        return i18nc("Noun", "History" );
 }
 
 QString SKGUndoRedoPlugin::icon() const
@@ -182,21 +186,16 @@ QString SKGUndoRedoPlugin::icon() const
         return "edit-undo";
 }
 
-QString SKGUndoRedoPlugin::statusTip () const
-{
-        return i18n ( "History" );
-}
-
 QString SKGUndoRedoPlugin::toolTip () const
 {
-        return i18n ( "History" );
+        return i18nc("Noun", "History" );
 }
 
 QStringList SKGUndoRedoPlugin::tips() const
 {
         QStringList output;
-        output.push_back ( i18n ( "<p>... you can undo and redo your modifications.</p>" ) );
-        output.push_back ( i18n ( "<p>... you can modify the maximum size of the undo/redo stack in the settings.</p>" ) );
+        output.push_back(i18nc("Description of a tips", "<p>... you can undo and redo your modifications.</p>" ) );
+        output.push_back(i18nc("Description of a tips", "<p>... you can modify the maximum size of the undo/redo stack in the settings.</p>" ) );
         return output;
 }
 
@@ -220,8 +219,8 @@ void SKGUndoRedoPlugin::actionUndoSave()
                 QApplication::restoreOverrideCursor();
 
                 //status bar
-                if ( err.isSucceeded() ) err=SKGError ( 0, i18n ( "Undo successfully done." ) );
-                else err.addError ( ERR_FAIL, i18n ( "Undo failed" ) );
+                if ( err.isSucceeded() ) err=SKGError(0, i18nc("Successful message after an user action", "Undo successfully done." ) );
+                else err.addError ( ERR_FAIL, i18nc("Error message",  "Undo failed" ) );
 
                 //Display error
                 SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
@@ -240,8 +239,8 @@ void SKGUndoRedoPlugin::actionUndo()
                 QApplication::restoreOverrideCursor();
 
                 //status bar
-                if ( err.isSucceeded() ) err=SKGError ( 0, i18n ( "Undo successfully done." ) );
-                else err.addError ( ERR_FAIL, i18n ( "Undo failed" ) );
+                if ( err.isSucceeded() ) err=SKGError(0, i18nc("Successful message after an user action", "Undo successfully done." ) );
+                else err.addError ( ERR_FAIL, i18nc("Error message",  "Undo failed" ) );
 
                 //Display error
                 SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
@@ -278,8 +277,8 @@ void SKGUndoRedoPlugin::actionRedo()
                 QApplication::restoreOverrideCursor();
 
                 //status bar
-                if ( err.isSucceeded() ) err=SKGError ( 0, i18n ( "Redo successfully done." ) );
-                else err.addError ( ERR_FAIL, i18n ( "Redo failed" ) );
+                if ( err.isSucceeded() ) err=SKGError(0, i18nc("Successful message after an user action", "Redo successfully done." ) );
+                else err.addError ( ERR_FAIL, i18nc("Error message",  "Redo failed" ) );
 
                 //Display error
                 SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
