@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -29,7 +29,7 @@
 #include <QResizeEvent>
 
 SKGUndoRedoPluginDockWidget::SKGUndoRedoPluginDockWidget(SKGDocument* iDocument)
-                :SKGTabWidget(iDocument)
+                :SKGTabPage(iDocument)
 {
         SKGTRACEIN(1, "SKGUndoRedoPluginDockWidget::SKGUndoRedoPluginDockWidget");
 
@@ -37,13 +37,12 @@ SKGUndoRedoPluginDockWidget::SKGUndoRedoPluginDockWidget(SKGDocument* iDocument)
 
         SKGObjectModelBase* modelview = new SKGObjectModelBase(getDocument(), "doctransaction", "1=1 ORDER BY d_date DESC", this);
         ui.kTransactionList->setModel(modelview);
-        ui.kTransactionList->verticalHeader()->hide();
-        ui.kTransactionList->horizontalHeader()->hide();
-        ui.kTransactionList->horizontalHeader()->setResizeMode(QHeaderView::ResizeToContents);
-        ui.kTransactionList->verticalHeader()->setResizeMode(QHeaderView::ResizeToContents);
+        ui.kTransactionList->header()->hide();
+
+        ui.kTransactionList->setDefaultSaveParameters(getDocument(), "SKG_DEFAULT_UNDOREDO");
 
         connect(ui.kTransactionList, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(onUndoRedo(QModelIndex)));
-
+        connect ( ( const QObject* ) getDocument(), SIGNAL(tableModified(QString, int)), this, SLOT(dataModified(QString, int)), Qt::QueuedConnection );
 }
 
 SKGUndoRedoPluginDockWidget::~SKGUndoRedoPluginDockWidget()
@@ -51,6 +50,14 @@ SKGUndoRedoPluginDockWidget::~SKGUndoRedoPluginDockWidget()
         SKGTRACEIN(1, "SKGUndoRedoPluginDockWidget::~SKGUndoRedoPluginDockWidget");
 }
 
+void SKGUndoRedoPluginDockWidget::dataModified(const QString& iTableName, int iIdTransaction)
+{
+    SKGTRACEIN ( 10, "SKGUndoRedoPluginDockWidget::dataModified" );
+    Q_UNUSED(iIdTransaction);
+    Q_UNUSED(iTableName);
+    ui.kTransactionList->resizeColumnsToContents();
+}
+
 void SKGUndoRedoPluginDockWidget::onUndoRedo(const QModelIndex & index)
 {
         SKGTRACEIN(1, "SKGUndoRedoPluginDockWidget::onUndoRedo");
@@ -73,8 +80,8 @@ void SKGUndoRedoPluginDockWidget::onUndoRedo(const QModelIndex & index)
         QApplication::restoreOverrideCursor();
 
         //status bar
-        if (err.isSucceeded()) err=SKGError(0, mode==SKGDocument::UNDO ? i18n("Undo successfully done.") : i18n("Redo successfully done."));
-        else err.addError(ERR_FAIL, mode==SKGDocument::UNDO ? i18n("Undo failed") : i18n("Redo failed"));
+        if (err.isSucceeded()) err=SKGError(0, mode==SKGDocument::UNDO ? i18nc("Message for successful user action","Undo successfully done.") : i18nc("Message for successful user action", "Redo successfully done."));
+        else err.addError(ERR_FAIL, mode==SKGDocument::UNDO ? i18nc("Error message","Undo failed") : i18nc("Error message","Redo failed"));
 
         //Display error
         SKGMainPanel::getMainPanel()->displayErrorMessage(err);
