@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,12 +22,12 @@
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
 #include "ui_skgundoredoplugindockwidget_base.h"
-#include "skgtabwidget.h"
+#include "skgtabpage.h"
 
 /**
  * This file is Skrooge plugin for undoredo management
  */
-class SKGUndoRedoPluginDockWidget : public SKGTabWidget
+class SKGUndoRedoPluginDockWidget : public SKGTabPage
 {
         Q_OBJECT
 
@@ -51,6 +51,7 @@ protected:
         virtual void resizeEvent(QResizeEvent *event);
 
 private slots:
+        void dataModified(const QString& iTableName, int iIdTransaction);
         void onUndoRedo(const QModelIndex & index);
 
 private:
