@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -31,7 +31,13 @@
 #include <kactioncollection.h>
 #include <kaction.h>
 
+/**
+ * This plugin factory.
+ */
 K_PLUGIN_FACTORY(SKGUnitPluginFactory, registerPlugin<SKGUnitPlugin>();)
+/**
+ * This plugin export.
+ */
 K_EXPORT_PLUGIN(SKGUnitPluginFactory("skrooge_unit", "skrooge_unit"))
 
 SKGUnitPlugin::SKGUnitPlugin(QObject* iParent, const QVariantList& /*iArg*/)
@@ -61,7 +67,7 @@ void SKGUnitPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
         setXMLFile("skrooge_unit.rc");
 
         //Menu
-        splitShareAction = new KAction(KIcon("skrooge_split_stock"), i18n("&Split share..."), this);
+        splitShareAction = new KAction(KIcon("skrooge_split_stock"), i18nc("Verb","Split share..."), this);
         connect(splitShareAction, SIGNAL(triggered(bool)), this, SLOT(actionSplitShare()));
         actionCollection()->addAction( QLatin1String("edit_split_stock"), splitShareAction );
         splitShareAction->setShortcut(Qt::ALT+Qt::Key_Slash);
@@ -81,7 +87,7 @@ int SKGUnitPlugin::getNbDashboardWidgets()
 
 QString SKGUnitPlugin::getDashboardWidgetTitle(int iIndex)
 {
-        if (iIndex==0) return i18n("Shares && Indexes");
+        if (iIndex==0) return i18nc("Noun, the title of a section", "Shares && Indexes");
         return "";
 }
 
@@ -113,10 +119,7 @@ void SKGUnitPlugin::refresh()
                                 docUniqueIdentifier=doc_id;
 
                                 //Read Setting
-                                KSharedConfigPtr config=KSharedConfig::openConfig("skrooge_unitrc");
-                                KConfigGroup pref=config->group("skrooge_unit");
-                                bool download_on_open = pref.readEntry("download_on_open",false);
-                                if (download_on_open) {
+                                if (skgunit_settings::download_on_open()) {
                                         SKGError err;
                                         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
@@ -138,7 +141,7 @@ void SKGUnitPlugin::refresh()
         }
 }
 
-SKGTabWidget* SKGUnitPlugin::getWidget()
+SKGTabPage* SKGUnitPlugin::getWidget()
 {
         SKGTRACEIN(10, "SKGUnitPlugin::getWidget");
         return new SKGUnitPluginWidget((SKGDocumentBank*) currentBankDocument);
@@ -168,22 +171,17 @@ QString SKGUnitPlugin::icon() const
         return "skrooge_unit";
 }
 
-QString SKGUnitPlugin::statusTip () const
-{
-        return i18n("Unit management (creation, update, ...)");
-}
-
 QString SKGUnitPlugin::toolTip () const
 {
-        return i18n("Unit management");
+        return i18nc("A tool tip", "Unit management");
 }
 
 QStringList SKGUnitPlugin::tips() const
 {
         QStringList output;
-        output.push_back(i18n("<p>... you can download units.</p>"));
-        output.push_back(i18n("<p>... units can be downloaded automatically when a document is opened.</p>"));
-        output.push_back(i18n("<p>... you can split a share.</p>"));
+        output.push_back(i18nc("Description of a tips", "<p>... you can download units.</p>"));
+        output.push_back(i18nc("Description of a tips", "<p>... units can be downloaded automatically when a document is opened.</p>"));
+        output.push_back(i18nc("Description of a tips", "<p>... you can split a share.</p>"));
         return output;
 }
 
@@ -208,12 +206,12 @@ void SKGUnitPlugin::actionSplitShare()
                 int nb=selection.count();
                 if (nb==1) {
                         bool ok=false;
-                        double ratio=KInputDialog::getDouble  (i18n("Split share"),
-                                                               i18n("Ratio (2 means 2-for-1, 0.5 means 1-for-2) :"), 2.0,
+                        double ratio=KInputDialog::getDouble  (i18nc("Question", "Split share"),
+                                                               i18nc("Question", "Ratio (2 means 2-for-1, 0.5 means 1-for-2) :"), 2.0,
                                                                0, DBL_MAX, 8, &ok, SKGMainPanel::getMainPanel());
                         if (ok) {
                                 SKGUnitObject unit=selection.at(0);
-                                SKGBEGINTRANSACTION(*currentBankDocument, i18n("Split stock [%1] by [%2]", unit.getName(), ratio), err);
+                                SKGBEGINTRANSACTION(*currentBankDocument, i18nc("Noun, name of the user action", "Split stock [%1] by [%2]", unit.getName(), ratio), err);
                                 QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
                                 err=unit.split(ratio);
                                 QApplication::restoreOverrideCursor();
@@ -221,8 +219,8 @@ void SKGUnitPlugin::actionSplitShare()
                 }
 
                 //status
-                if (err.isSucceeded())  err=SKGError(0, i18n("Stock split."));
-                else err.addError(ERR_FAIL, i18n("Splitting stock failed."));
+                if (err.isSucceeded())  err=SKGError(0, i18nc("Successful message after an user action", "Stock split."));
+                else err.addError(ERR_FAIL, i18nc("Error message", "Splitting stock failed."));
 
                 //Display error
                 SKGMainPanel::getMainPanel()->displayErrorMessage(err);
