@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -27,7 +27,13 @@
 #include <kactioncollection.h>
 #include <kstandardaction.h>
 
+/**
+ * This plugin factory.
+ */
 K_PLUGIN_FACTORY(SKGXXXPluginFactory, registerPlugin<SKGXXXPlugin>();)
+/**
+ * This plugin export.
+ */
 K_EXPORT_PLUGIN(SKGXXXPluginFactory("skrooge_xxx", "skrooge_xxx"))
 
 SKGXXXPlugin::SKGXXXPlugin(QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
@@ -38,7 +44,6 @@ SKGXXXPlugin::SKGXXXPlugin(QObject* iParent, const QVariantList& /*iArg*/) : SKG
 SKGXXXPlugin::~SKGXXXPlugin()
 {
         SKGTRACEIN(10, "SKGXXXPlugin::~SKGXXXPlugin");
-        parent=NULL;
         currentBankDocument=NULL;
 }
 
@@ -66,7 +71,7 @@ void SKGXXXPlugin::close()
         SKGTRACEIN(10, "SKGXXXPlugin::close");
 }
 
-SKGTabWidget* SKGXXXPlugin::getWidget()
+SKGTabPage* SKGXXXPlugin::getWidget()
 {
         SKGTRACEIN(10, "SKGXXXPlugin::getWidget");
         return new SKGXXXPluginWidget(currentBankDocument);
@@ -93,7 +98,7 @@ SKGError SKGXXXPlugin::savePreferences() const
 
 QString SKGXXXPlugin::title() const
 {
-        return i18n("xxx"); //TODO MUST BE CHANGED
+        return i18nc("The title", "xxx"); //TODO MUST BE CHANGED
 }
 
 QString SKGXXXPlugin::icon() const
@@ -101,14 +106,9 @@ QString SKGXXXPlugin::icon() const
         return "dialog-information";//TODO MUST BE CHANGED
 }
 
-QString SKGXXXPlugin::statusTip () const
-{
-        return i18n("xxx");//TODO MUST BE CHANGED
-}
-
 QString SKGXXXPlugin::toolTip () const
 {
-        return i18n("xxx");//TODO MUST BE CHANGED
+        return i18nc("The tool tip", "xxx");//TODO MUST BE CHANGED
 }
 
 
@@ -120,7 +120,7 @@ int SKGXXXPlugin::getOrder() const
 QStringList SKGXXXPlugin::tips() const
 {
         QStringList output;
-        output.push_back(i18n("<p>... xxx is the best plugin of the world</p>")); //TODO MUST BE CHANGED
+         output.push_back(i18nc("Description of a tips", "<p>... xxx is the best plugin of the world</p>")); //TODO MUST BE CHANGED
         return output;
 }
 
