@@ -30,7 +30,3 @@ def main():
     sendEvent("QCloseEvent", ":Untitled [modified] - skrooge_SKGMainPanel")
     waitForObject(":Question – Skrooge.Do not save_KPushButton")
     clickButton(":Question – Skrooge.Do not save_KPushButton")
-    ctx_0 = currentApplicationContext()
-    setApplicationContext(ctx_0)
-
-
