@@ -104,37 +104,7 @@ def main():
     type(":Untitled [modified] - skrooge.Processing_KMenu", "<Return>")
     
     waitForObject(":Untitled [modified] - skrooge_KTabBar")
-    type(":Untitled [modified] - skrooge_KTabBar", "<Alt+E>")
-    waitForObject(":Untitled [modified] - skrooge.Edit_KMenu")
-    type(":Untitled [modified] - skrooge.Edit_KMenu", "<Right>")
-    waitForObject(":Untitled [modified] - skrooge.View_KMenu")
-    type(":Untitled [modified] - skrooge.View_KMenu", "<Down>")
-    waitForObject(":Untitled [modified] - skrooge.View_KMenu")
-    type(":Untitled [modified] - skrooge.View_KMenu", "<Down>")
-    waitForObject(":Untitled [modified] - skrooge.View_KMenu")
-    type(":Untitled [modified] - skrooge.View_KMenu", "<Down>")
-    waitForObject(":Untitled [modified] - skrooge.View_KMenu")
-    type(":Untitled [modified] - skrooge.View_KMenu", "<Down>")
-    waitForObject(":Untitled [modified] - skrooge.View_KMenu")
-    type(":Untitled [modified] - skrooge.View_KMenu", "<Down>")
-    waitForObject(":Untitled [modified] - skrooge.View_KMenu")
-    type(":Untitled [modified] - skrooge.View_KMenu", "<Down>")
-    waitForObject(":Untitled [modified] - skrooge.View_KMenu")
-    type(":Untitled [modified] - skrooge.View_KMenu", "<Down>")
-    waitForObject(":Untitled [modified] - skrooge.View_KMenu")
-    type(":Untitled [modified] - skrooge.View_KMenu", "<Down>")
-    waitForObject(":Untitled [modified] - skrooge.View_KMenu")
-    type(":Untitled [modified] - skrooge.View_KMenu", "<Down>")
-    waitForObject(":Untitled [modified] - skrooge.View_KMenu")
-    type(":Untitled [modified] - skrooge.View_KMenu", "<Down>")
-    waitForObject(":Untitled [modified] - skrooge.View_KMenu")
-    type(":Untitled [modified] - skrooge.View_KMenu", "<Down>")
-    waitForObject(":Untitled [modified] - skrooge.View_KMenu")
-    type(":Untitled [modified] - skrooge.View_KMenu", "<Down>")
-    waitForObject(":Untitled [modified] - skrooge.View_KMenu")
-    type(":Untitled [modified] - skrooge.View_KMenu", "<Up>")
-    waitForObject(":Untitled [modified] - skrooge.View_KMenu")
-    type(":Untitled [modified] - skrooge.View_KMenu", "<Return>")
+    type(":Untitled [modified] - skrooge_KTabBar", "<Meta+V>")
     
     bookmarkAndRemoveCurrentPage()
     
@@ -166,6 +136,8 @@ def main():
     waitForObject(":Name:_KUrlComboBox_2")    
     type(":Name:_KUrlComboBox_2", "<Return>")
     
+    snooze(5)
+    
     waitForObject(":Untitled [modified] - skrooge_KTabBar")
     type(":Untitled [modified] - skrooge_KTabBar", "<Alt+F>")
     waitForObject(":Untitled [modified] - skrooge.File_KMenu")
@@ -189,16 +161,14 @@ def main():
     waitForObject(":Untitled [modified] - skrooge.Export_KMenu")
     type(":Untitled [modified] - skrooge.Export_KMenu", "<Down>")
     waitForObject(":Untitled [modified] - skrooge.Export_KMenu")
-    type(":Untitled [modified] - skrooge.Export_KMenu", "<Down>")
-    waitForObject(":Untitled [modified] - skrooge.Export_KMenu")
-    type(":Untitled [modified] - skrooge.Export_KMenu", "<Up>")
-    waitForObject(":Untitled [modified] - skrooge.Export_KMenu")
     type(":Untitled [modified] - skrooge.Export_KMenu", "<Return>")
     waitForObject(":Name:_KUrlComboBox_2")
     type(":Name:_KUrlComboBox_2", os.getenv('OUT')+"/tmp.qif")
     waitForObject(":Name:_KUrlComboBox_2")
     type(":Name:_KUrlComboBox_2", "<Return>")
     
+    snooze(5)
+    
     waitForObject(":Untitled [modified] - skrooge_SKGMainPanel")
     sendEvent("QCloseEvent", ":Untitled [modified] - skrooge_SKGMainPanel")
     waitForObject(":Question – Skrooge.Do not save_KPushButton")
